(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    365255,       9089]*)
(*NotebookOutlinePosition[    436987,      11672]*)
(*  CellTagsIndexPosition[    436869,      11665]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Rooting a genealogy", "SubsectionIcon"],

Cell[TextData[{
  "In this package, the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " represents the derived allele by a '1', and the ancestral allele by a \
'0'.  However, which allele is ancestral can only be determined if the state \
of an outgroup is known. If the ancestral state is unknown, then only an \
unrooted genealogy can be inferred. Finding the probability of the \
configuration of mutations requires that we sum over all possible ",
  StyleBox["rootings",
    FontSlant->"Italic"],
  " of this genealogy."
}], "Text"],

Cell[TextData[{
  "There are two approaches to 'rooting' a genealogy.  First, an unrooted \
genealogy can be inferred, using ",
  ButtonBox["MatrixToGenealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "[], and then the root can be placed at any point.  If ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " mutations have occurred along a the ",
  Cell[BoxData[
      \(TraditionalForm\`k' th\)]],
  " 'edge', then the root can be placed in any of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\_k\)]],
  " positions.  (The set of ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " mutations is divided into two sets, namely those on either side of the \
root).  In total, there are ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+k\((2\^n\_k - 1)\)\)]],
  " ways of rooting the genealogy.  (The -1 arises because a root to the ",
  StyleBox["left",
    FontSlant->"Italic"],
  " of all mutations on one edge is equivalent to a root to the ",
  StyleBox["right",
    FontSlant->"Italic"],
  " of all mutations on a connected edge.  The formula assumes that all \
internal nodes connect three edges)."
}], "Text"],

Cell[TextData[{
  "The second approach, explored in this section, is to make some assumption \
about which allele is ancestral.  Then 0's and 1's in the matrix can be \
swapped, such that the derived allele is represented by a `1`. With ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " mutations, there are ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " possibilities.  Most of these, however, are not be consistent with any \
genealogy.  Those that are lead to a single topology, but with a root which \
can be at any position.  In the documentation, each choice of ancestral & \
derived states is referred to as a ",
  StyleBox["rooting",
    FontSlant->"Italic"],
  "; it is represented by a list of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " 0's or 1's."
}], "Text"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Genealogies`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(SwapStates[s, S]\), \(swaps\ 0' s\ with\ 1' s\ in\ S, \ 
            thus\ changing\ which\ allele\ is\ ancestral\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SwapStates"],

Cell["\<\
A set of mutations is represented by a matrix in which each row \
shows the set of mutations carried by a leaf.This example is consistent with \
a rooted genealogy:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"S", "=", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "0"},
                {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "0"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "0"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1"}
                }], ")"}],
          (MatrixForm[ #]&)]}], ";", \(ValidMatrixQ[S]\)}]], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
This sets the '1' allele at the last 3 loci to be ancestral, and at \
the remaining loci to be derived:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S2 = SwapStates[{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1}, S]; 
    S2 // TableForm\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1", "0", "0", "0", "0", "0", "1", "1", "1", "1"},
          {"1", "1", "0", "0", "0", "0", "0", "0", "1", "1", "1"},
          {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1"},
          {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "1"},
          {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[8]//TableForm="]
}, Open  ]],

Cell["\<\
This choice of root is inconsistent with a rooted genealogy, but \
(necessarily) is consistent with an unrooted genealogy:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({ValidMatrixQ[S2], ValidMatrixQ[S2, Unrooted \[Rule] True]}\)], "Input",\

  CellLabel->"In[10]:="],

Cell[BoxData[
    \({False, True}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(PossibleRootings[
              S]\), \(lists\ all\ valid\ ways\ of\ rooting\ the\ mutations\ \
listed\ in\ S\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PossibleRootings"],

Cell["\<\
There are 132 ways of rooting the configuration of mutations \
represented by S:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[pr = PossibleRootings[S]; Length[pr]]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \({0.4499999999998181`\ Second, 132}\)], "Output",
  CellLabel->"Out[125]="]
}, Open  ]],

Cell[TextData[{
  "The result is the same as given by an exhaustive search of all ",
  Cell[BoxData[
      \(TraditionalForm\`2\^11\)]],
  " possible rootings:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      ss = Select[SetOfCombinations[11], ValidMatrixQ[SwapStates[#, S]] &]; 
      Sort[pr] \[Equal] Sort[ss]]\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \({13.75`\ Second, True}\)], "Output",
  CellLabel->"Out[128]="]
}, Open  ]],

Cell["\<\
Each element in the list specifies whether each '1' allele is \
treated as derived ('0') or ancestral ('1'):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pr // Short\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    TagBox[\({{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 1, 0, 0, 
          0, 0}, {0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
          0}, \[LeftSkeleton]127\[RightSkeleton], {1, 1, 1, 1, 1, 1, 0, 0, 0, 
          0, 0}, {1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0}}\),
      Short]], "Output",
  CellLabel->"Out[126]//Short="]
}, Open  ]],

Cell["\<\
The first possibility is to interpret all '1' alleles as being \
derived; the second ({0,0,0,0,0,0,1,0,0,0,0}) is the same, except that at \
site 7, allele '1' is treated as being ancestral.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Technicalities", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(PossibleRootings[{\[Ellipsis], {0, 1, 
                  Null, \[Ellipsis]}, \[Ellipsis]}, 
              S]\), \(expands\ the\ list\ of\ possibilities\ by\ eliminationg\
\ undetermined\ states, \ represented\ by\ Null\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PossibleRootings"],

Cell["\<\
PossibleRootings[S] works by representing undetermined sites by \
Null; the possibilities 0 or 1 are then tried in turn, and valid \
possibilities are added to the list:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PossibleRootings[{{Null, Null, Null, Null, Null, Null, Null, Null, 
          Null, Null, Null}}, S]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \({{0, Null, Null, Null, Null, Null, Null, 0, Null, Null, Null}, {1, 
        Null, Null, Null, Null, Null, Null, Null, 0, 0, 0}}\)], "Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell["\<\
In this example, the first Null is replaced by either 0 or 1; \
constraints then entail the states of some of the other sites as well.\
\>", \
"Text"],

Cell[TextData[{
  "This algorithm is less efficient than finding the unrooted genealogy \
using",
  " ",
  ButtonBox["MatrixToGenealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "[\[Ellipsis],Unrooted\[Rule]True], and then positioning the root on this \
genealogy.  However, it perhapshas the advantage that it deals solely with \
permutations of the matrix S, and does not require dealing with the \
genealogical representation explicitly."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Probabilities of different rootings", "SubsubsectionIcon"],

Cell[TextData[{
  "The probability of any particular rooted genealogy under the coalescent \
process and infinite-sites mutation is given by ",
  ButtonBox["ExactProbability",
    ButtonData:>{"Exact probability", "ExactProbability"},
    ButtonStyle->"AddOnsLink"],
  "[S,\[Theta]] where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 4  N\[VeryThinSpace]\[Mu]\)]],
  ";this is a sum over all genealogies consistent with S.  This is the \
probability of the configuration S:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ep = ExactProbability[S, \[Theta]];\)\), "\[IndentingNewLine]", 
    \(Plot[ep, {\[Theta], 0, 30}]; ep\)}], "Input",
  CellLabel->"In[193]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 5.05269e+06 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .11577 -33 -6.25 ]
[.01131 .11577 0 6.25 ]
[.01131 .21682 -33 -6.25 ]
[.01131 .21682 0 6.25 ]
[.01131 .31788 -33 -6.25 ]
[.01131 .31788 0 6.25 ]
[.01131 .41893 -33 -6.25 ]
[.01131 .41893 0 6.25 ]
[.01131 .51998 -33 -6.25 ]
[.01131 .51998 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11577 m
.03006 .11577 L
s
gsave
.01131 .11577 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .21682 m
.03006 .21682 L
s
gsave
.01131 .21682 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .31788 m
.03006 .31788 L
s
gsave
.01131 .31788 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .41893 m
.03006 .41893 L
s
gsave
.01131 .41893 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .51998 m
.03006 .51998 L
s
gsave
.01131 .51998 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.125 Mabswid
.02381 .03998 m
.02756 .03998 L
s
.02381 .06524 m
.02756 .06524 L
s
.02381 .09051 m
.02756 .09051 L
s
.02381 .14103 m
.02756 .14103 L
s
.02381 .1663 m
.02756 .1663 L
s
.02381 .19156 m
.02756 .19156 L
s
.02381 .24209 m
.02756 .24209 L
s
.02381 .26735 m
.02756 .26735 L
s
.02381 .29261 m
.02756 .29261 L
s
.02381 .34314 m
.02756 .34314 L
s
.02381 .3684 m
.02756 .3684 L
s
.02381 .39367 m
.02756 .39367 L
s
.02381 .44419 m
.02756 .44419 L
s
.02381 .46946 m
.02756 .46946 L
s
.02381 .49472 m
.02756 .49472 L
s
.02381 .54525 m
.02756 .54525 L
s
.02381 .57051 m
.02756 .57051 L
s
.02381 .59577 m
.02756 .59577 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01473 L
.03746 .01475 L
.03873 .01479 L
.03944 .01482 L
.04011 .01485 L
.04132 .01495 L
.04262 .0151 L
.04327 .01519 L
.04396 .01532 L
.04519 .01561 L
.04652 .01604 L
.04797 .01666 L
.04923 .01736 L
.05058 .01831 L
.05302 .02062 L
.05555 .02397 L
.05795 .02819 L
.06244 .03922 L
.06486 .04694 L
.06753 .05698 L
.07293 .08208 L
.08263 .14108 L
.10458 .30668 L
.1148 .38124 L
.12555 .44976 L
.13551 .50175 L
.14478 .53965 L
.15372 .56697 L
.15872 .57858 L
.16326 .58699 L
.16825 .59405 L
.17106 .59709 L
.17366 .59932 L
.17593 .60085 L
.17842 .60209 L
.17968 .60255 L
.18037 .60275 L
.18103 .60292 L
.18231 .60316 L
Mistroke
.18347 .60328 L
.18472 .60332 L
.18542 .6033 L
.18607 .60325 L
.18726 .6031 L
.18851 .60285 L
.18964 .60255 L
.19069 .60221 L
.19308 .6012 L
.19567 .59978 L
.19802 .59821 L
.20332 .59378 L
.21277 .58316 L
.22172 .57055 L
.2601 .50071 L
.30093 .41979 L
.34025 .34895 L
.37805 .29101 L
.41831 .24027 L
.45705 .20078 L
.49824 .16708 L
.53792 .14112 L
.57608 .12092 L
.61669 .10349 L
.65579 .08985 L
.69734 .07804 L
.73737 .06872 L
.77589 .06129 L
.81686 .05471 L
.85632 .04942 L
.89426 .04513 L
.93465 .04125 L
.97352 .03808 L
.97619 .03788 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[193]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00BP3oool3
000002<0oooo0`0000040?ooo`800000803oool3000000<0oooo0`00000O0?ooo`D000000`3oool2
000001l0oooo1@0000020?ooo`<000007`3oool3000000@0oooo0P0000040?ooo`00B@3oool01@00
0000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000P0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0M0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000007`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool06`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000`3oool004d0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000803oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`010?ooo`00C@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`8000000`3oool010000000oooo0?oo
o`0000030?ooo`00B@3oool4000002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000P0?ooo`040000003oool0oooo0?ooo`@000007`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000007P3oool01P000000oooo0?ooo`3oool000000?ooo`@00000
8P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0040oooo00190?ooo`030000
003oool0oooo02@0oooo0P0000040?ooo`040000003oool0oooo000001l0oooo0P0000030?ooo`03
0000003oool0oooo0200oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000001h0oooo00L000000?ooo`3oool0oooo0000003oool000000240oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000000<0oooo00190?ooo`D000008`3oool00`000000
oooo0?ooo`030?ooo`8000008@3oool010000000oooo0?ooo`3oool5000001l0oooo0`0000040?oo
o`800000803oool300000080oooo1@00000N0?ooo`<00000103oool2000000@0oooo003o0?ooob40
oooo000T0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo0?T0oooo000T
0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo0?T0oooo000N0?ooool0
00000`00000002@0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`00903oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?40oooo000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0l@3oool0
02@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3a0?ooo`00903oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?00oooo000T0?ooo`800000203oool00`000000oooo
0?ooo`3H0?oooa0000001`3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3@0?ooo`P000005`3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3;
0?ooo`D000007`3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`340?oo
o`L00000903oool002@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2k0?ooo`P0
0000:`3oool002@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2f0?ooo`D00000
<`3oool002@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2a0?ooo`D00000>03o
ool002@0oooo0P0000090?ooo`030000003oool0oooo0:`0oooo1@00000m0?ooo`00903oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0:H0oooo1@0000120?ooo`00903oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0:40oooo1@0000170?ooo`00903oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo09`0oooo1@00001<0?ooo`00903oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo09P0oooo1000001A0?ooo`00903oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo09D0oooo0`00001E0?ooo`00903oool2000000X0oooo00<000000?oo
o`3oool0T@3oool4000005P0oooo000T0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0S@3oool3000005`0oooo000T0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
RP3oool3000005l0oooo000500000080oooo00H000000?ooo`3oool0oooo0000003oool3000000@0
oooo0P00000>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Q`3oool300000680
oooo00001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`250?ooo`800000I@3oool00080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo08<0oooo0P00001W0?ooo`000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0P03oool20000
06T0oooo00001@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003@3oool2000000`0oooo00<0
00000?ooo`3oool0OP3oool2000006/0oooo00001@000000oooo0?ooo`3oool0000000P0oooo0P00
00040?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1l0?ooo`800000K@3oool000040?ooo`0000000000000000X0oooo00<000000?ooo`3oool0
0`3oool2000000P0oooo0`0000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
NP3oool2000006l0oooo000I0?ooo`@0000000@0oooo0000003oool000000`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo07P0oooo0P00001a0?ooo`007`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0M@3oool2000007<0oooo000N
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1c
0?ooo`800000M@3oool001h0oooo0`0000030?ooo`8000003@3oool00`000000oooo0?ooo`1a0?oo
o`800000M`3oool002@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo07L0oooo000T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
KP3oool2000007X0oooo000T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`1j0?ooo`00903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0N`3oool002@0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1Y0?ooo`800000OP3oool002@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo07h0oooo000T0?ooo`8000003P3oool00`000000oooo
0?ooo`1V0?ooo`800000P@3oool002@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo0840oooo000T0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`220?ooo`00903oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0680oooo0P0000250?ooo`00903oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool0Q@3oool002@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1O0?ooo`800000R03oool002@0oooo0P00000>0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0R03oool002@0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo08T0oooo000T0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2:0?ooo`000P3oool300000080
oooo00H000000?ooo`3oool0oooo0000003oool3000000@0oooo0P00000>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2:0?ooo`000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`2;0?ooo`001@0000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`2<0?ooo`0000@000000?ooo`3oool00000103oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0S@3o
ool000040?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000003@3oool2000000l0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`2>0?ooo`000P3oool2000000T0oooo0P0000040?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo08l0oooo00030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool2000000P0oooo0`0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`2@0?ooo`006@3oool4000000040?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0940oooo
000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0980oooo000N0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo09<0oooo000N0?oo
o`<000000`3oool200000100oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2D0?oo
o`00903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0U03oool002@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo09D0oooo000T0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`2F0?ooo`00903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0U`3oool002@0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo09L0oooo000T0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2H0?ooo`00903oool200000140oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`2I0?ooo`00903oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0VP3oool002@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo09/0oooo000T0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2K0?oo
o`00903oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0W03oool002@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo09d0oooo000T0?ooo`8000004@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo09h0oooo000T0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`2N0?ooo`00903oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0W`3oool000040?ooo`0000000000000000<0oooo00H000000?oo
o`3oool0oooo0000003oool3000000@0oooo0P00000>0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`2P0?ooo`0000D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`2P0?ooo`0000D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2Q0?ooo`00100000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000=0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2R0?ooo`00
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000=0?ooo`8000004P3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0:80oooo00000`3oool000000?ooo`0:0?ooo`800000103oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`2S0?ooo`000P3oool2000000X0oooo00<000000?ooo`3oool00`3oool2000000P0
oooo0`0000030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`2T0?ooo`006@3oool4000000040?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:@0oooo000O0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0:D0oooo000N0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0:H0oooo000N0?ooo`<000000`3oool2
000001<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2V0?ooo`00903oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0Y`3oool002@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0:P0
oooo000T0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`2X0?ooo`00903oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0Z@3oool002@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0:T0oooo000T0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`2Z0?ooo`00903oool2000001@0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`2[0?ooo`00903oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0Z`3oool002@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0:`0oooo000T0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2/0?ooo`00903oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0[@3oool002@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0:d0
oooo000T0?ooo`8000005@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0:h0oooo
000T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`2^0?ooo`00903oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0[`3oool000040?ooo`0000000000000000<0oooo00H000000?ooo`3oool0oooo0000
003oool3000000@0oooo0P00000>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`2`0?ooo`0000D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000=0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2`0?ooo`00
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`2a0?ooo`0000@0oooo0000000000000000103oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003@3oool2
000001L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2a0?ooo`0000D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0;80oooo00001@000000oooo0?ooo`3oool0000000P0oooo
0P0000040?ooo`040000003oool0oooo000000L0oooo0`0000030?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2b0?ooo`0000@0oooo000000000000
00002P3oool00`000000oooo0?ooo`030?ooo`8000000`3oool4000000040?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0;<0oooo000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0;<0oooo000N0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0;@0oooo
000N0?ooo`<000000`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0]03oool002@0oooo0P00000H0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0]@3oool002@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0;H0oooo000T0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`2f0?ooo`00903oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0]`3oool002@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0;L0oooo000T0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2h0?ooo`00903oool20000
01T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2h0?ooo`00903oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0^@3oool002@0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;T0oooo
000T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`2j0?ooo`00903oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0^`3oool002@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0;/0oooo000T0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`2l0?ooo`00903oool2000001X0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`2l0?ooo`00903oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0_@3oool002@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;d0oooo0000103oool00000000000000003
0?ooo`060000003oool0oooo0?ooo`000000oooo0`0000040?ooo`8000003P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0_P3oool00080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000003@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0_P3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0_`3oool00080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000003@3oool2000001/0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`2o0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0<00oooo00000`3oool00000
0000000:0?ooo`800000103oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0<00
oooo00020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool2000000<0oooo
100000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0<40oooo000O0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0<40oooo000P
0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0<80oooo000N0?ooo`<000000`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0`P3oool002@0oooo0P00000M0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0``3oool002@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0<<0oooo000T0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`340?ooo`00903oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0a03oool002@0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0<D0oooo000T0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`350?oo
o`00903oool2000001l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`360?ooo`00
903oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
aP3oool002@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0<L0oooo000T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`380?ooo`00903oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0b@3oool002@0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0<X0oooo000T0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3;0?ooo`00903oool2000002@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3<0?ooo`00903oool00`000000oooo0?ooo`0S
0?ooo`8000000`3oool200000<l0oooo000T0?ooo`030000003oool0oooo02@0oooo1@00003@0?oo
o`00903oool00`000000oooo0?ooo`3i0?ooo`00903oool00`000000oooo0?ooo`3i0?ooo`00903o
ool00`000000oooo0?ooo`3i0?ooo`00903oool00`000000oooo0?ooo`3i0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.44017, -1.31559*^-8, \
0.122614, 7.70386*^-10}}],

Cell[BoxData[
    \(\((\[Theta]\^11\ \((12795837696 + 49147392768\ \[Theta] + 
              83327119488\ \[Theta]\^2 + 81828855824\ \[Theta]\^3 + 
              51278495688\ \[Theta]\^4 + 21258840312\ \[Theta]\^5 + 
              5828942920\ \[Theta]\^6 + 1018979202\ \[Theta]\^7 + 
              103027509\ \[Theta]\^8 + 
              4589441\ \[Theta]\^9)\))\)/\((466560000\ \((1 + \[Theta])\)\^8\ \
\((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^5\ \((4 + \[Theta])\)\^4)\)\)], \
"Output",
  CellLabel->"Out[194]="]
}, Open  ]],

Cell[TextData[{
  "Although S was drawn from a random coalescent process with \[Theta]=10, \
the MLE of \[Theta],inferred from this one realisation of the process, is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\&^ = 5.06\)]],
  "; the difference in ",
  Cell[BoxData[
      \(TraditionalForm\`log[L]\)]],
  " between this and the actual value is only 0.57."
}], "Text"],

Cell["\<\
If we did not know the ancestral state of the mutations, we would \
calculate the likelihood of \[Theta] as a sum over all possible \
choices:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ept = \(ExactProbability[SwapStates[#, S], \[Theta]] &\) /@ 
          pr;\)\), "\n", 
    \(Plot[Plus @@ ept, {\[Theta], 0, 20}]; ept[\([{1, 2}]\)]\)}], "Input",
  CellLabel->"In[162]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 23087.8 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13015 -33 -6.25 ]
[.01131 .13015 0 6.25 ]
[.01131 .24559 -42 -4.5 ]
[.01131 .24559 0 4.5 ]
[.01131 .36103 -48 -4.5 ]
[.01131 .36103 0 4.5 ]
[.01131 .47647 -42 -4.5 ]
[.01131 .47647 0 4.5 ]
[.01131 .59191 -48 -4.5 ]
[.01131 .59191 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13015 m
.03006 .13015 L
s
gsave
.01131 .13015 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .24559 m
.03006 .24559 L
s
[(0.00001)] .01131 .24559 1 0 Mshowa
.02381 .36103 m
.03006 .36103 L
s
[(0.000015)] .01131 .36103 1 0 Mshowa
.02381 .47647 m
.03006 .47647 L
s
[(0.00002)] .01131 .47647 1 0 Mshowa
.02381 .59191 m
.03006 .59191 L
s
[(0.000025)] .01131 .59191 1 0 Mshowa
.125 Mabswid
.02381 .0378 m
.02756 .0378 L
s
.02381 .06089 m
.02756 .06089 L
s
.02381 .08398 m
.02756 .08398 L
s
.02381 .10707 m
.02756 .10707 L
s
.02381 .15324 m
.02756 .15324 L
s
.02381 .17633 m
.02756 .17633 L
s
.02381 .19942 m
.02756 .19942 L
s
.02381 .22251 m
.02756 .22251 L
s
.02381 .26868 m
.02756 .26868 L
s
.02381 .29177 m
.02756 .29177 L
s
.02381 .31486 m
.02756 .31486 L
s
.02381 .33794 m
.02756 .33794 L
s
.02381 .38412 m
.02756 .38412 L
s
.02381 .40721 m
.02756 .40721 L
s
.02381 .4303 m
.02756 .4303 L
s
.02381 .45338 m
.02756 .45338 L
s
.02381 .49956 m
.02756 .49956 L
s
.02381 .52265 m
.02756 .52265 L
s
.02381 .54573 m
.02756 .54573 L
s
.02381 .56882 m
.02756 .56882 L
s
.02381 .615 m
.02756 .615 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01473 L
.04327 .01474 L
.04396 .01474 L
.04519 .01476 L
.04588 .01477 L
.04652 .01479 L
.04797 .01483 L
.04925 .01488 L
.05041 .01495 L
.05175 .01504 L
.05302 .01516 L
.05415 .01529 L
.05536 .01546 L
.05753 .01586 L
.05987 .01645 L
.06244 .01736 L
.0651 .01863 L
.0679 .0204 L
.0729 .02486 L
.07569 .02818 L
.07829 .03186 L
.08418 .0425 L
.09404 .06772 L
.10458 .10451 L
.14608 .30392 L
.16688 .40218 L
.18606 .47706 L
.20474 .53236 L
.21416 .5536 L
.22453 .57212 L
.23469 .58569 L
.24397 .59445 L
.2491 .59792 L
Mistroke
.25181 .59939 L
.25469 .60068 L
.25746 .60167 L
.25997 .60236 L
.26118 .60262 L
.26249 .60286 L
.26371 .60303 L
.26487 .60316 L
.26611 .60326 L
.26725 .60331 L
.26847 .60332 L
.26916 .60331 L
.2698 .60329 L
.27086 .60323 L
.27203 .60313 L
.27325 .60299 L
.2744 .60283 L
.27702 .60233 L
.27943 .60173 L
.28484 .5999 L
.28975 .59771 L
.29512 .59478 L
.30592 .58738 L
.32557 .56972 L
.34653 .54664 L
.38808 .49418 L
.42812 .44163 L
.46664 .39322 L
.50761 .34603 L
.54706 .30547 L
.585 .27102 L
.62539 .23894 L
.66427 .21211 L
.7056 .18744 L
.74541 .16694 L
.78371 .14982 L
.82446 .13402 L
.86369 .12083 L
.90141 .10975 L
.94158 .09944 L
.97619 .09162 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[171]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00JP3oool3
000003@0oooo0`0000040?ooo`800000<03oool3000000<0oooo0`00000`0?ooo`D000000`3oool2
000000<0oooo001Y0?ooo`050000003oool0oooo0?ooo`000000=03oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000300oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo02h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`00K@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`00K@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo000000020?ooo`4000000@3o
ool10?ooo`00J@3oool4000003D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000`0?ooo`040000003oool0oooo0?ooo`@00000<03oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool006T0oooo00<000000?ooo`3oool0=@3oool2000000@0
oooo00@000000?ooo`3oool00000;`3oool2000000<0oooo00<000000?ooo`3oool0<@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool006T0oooo1@00000d
0?ooo`030000003oool0oooo00<0oooo0P00000a0?ooo`040000003oool0oooo0?ooo`D00000<03o
ool3000000@0oooo0P0000030?ooo`00o`3ooolQ0?ooo`00<`3oool00`000000oooo0?ooo`3Z0?oo
o`00<`3oool00`000000oooo0?ooo`3Z0?ooo`00<`3oool00`000000oooo0?ooo`3Z0?ooo`00;@3o
ooob00000040oooo000c0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000?ooo`0:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo000c0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`040?ooo`00<`3oool00`000000oooo0?ooo`080?ooo`80
0000h03oool003<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3M0?ooo`00<`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0=d0oooo000c0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0g03oool003<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`3L0?ooo`00<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0=`0
oooo000c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0f`3oool003<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3K0?ooo`00<`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0=/0oooo000c0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0fP3oool003<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3J0?ooo`00
<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0=X0oooo000c0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0f@3oool003<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3I0?ooo`00<`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0=T0oooo000c0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0f03oool003<0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3?0?ooo`<000001P3oool003<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3:0?ooo`D000002@3oool003<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`350?ooo`@000003P3oool003<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`300?ooo`D000004P3oool003<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`2l0?ooo`@000005`3oool003<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`2i0?ooo`<000006`3oool00100oooo0`0000030?ooo`060000003o
ool0oooo0?ooo`000000oooo0`0000040?ooo`8000003P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0;D0oooo0`00000N0?ooo`003`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2b0?ooo`<000008@3oool001<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0:l0oooo0`00000T0?ooo`004`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000d0oooo0P00000B0?ooo`030000003o
ool0oooo0:`0oooo0`00000W0?ooo`003`3oool4000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0:T0oooo0`00000Z0?ooo`003`3oool00`000000oooo0?oo
o`0:0?ooo`800000103oool010000000oooo0?ooo`0000080?ooo`8000000`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0:D0oooo0`00000]0?ooo`003`3oool5000000T0oooo00<0
00000?ooo`3oool00`3oool2000000<0oooo10000000103oool000000?ooo`0000030?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0X`3oool200000300oooo000]0?ooo`<000000`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0:00oooo0`00000b0?ooo`00;@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0WP3oool2
000003D0oooo000^0?ooo`8000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
09`0oooo0P00000g0?ooo`00<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo09P0
oooo0`00000i0?ooo`00<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo09H0oooo
0P00000l0?ooo`00<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo09@0oooo0P00
000n0?ooo`00<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0980oooo0P000010
0?ooo`00<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0900oooo0P0000120?oo
o`00<`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08d0oooo0P0000140?ooo`00
<`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08/0oooo0P0000160?ooo`00<`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08T0oooo0P0000180?ooo`00<`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08L0oooo0P00001:0?ooo`00<`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0BP3oool003<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`230?ooo`800000C@3oool003<0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`210?ooo`800000C`3oool003<0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo04l0oooo000c
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0OP3oool200000580oooo000c0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`1B0?oo
o`00<`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07X0oooo0P00001E0?ooo`00
<`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
E@3oool003<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1g0?ooo`800000F03o
ool000P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0F03oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`1c0?ooo`800000F`3oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo05/0
oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`040?ooo`800000603oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo05`0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`1M0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0P0000060?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0KP3oool200000600oooo00080?ooo`8000002P3oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0H03oool003<0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0640
oooo000c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`1R0?ooo`00<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06P0oooo0P00
001U0?ooo`00<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0I@3oool003<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo06H0oooo000c0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`1W0?ooo`00<`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool0J03oool003<0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo06T0oooo000c0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Z0?ooo`00<`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0J`3oool003<0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo06`0
oooo000c0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`1]0?ooo`00<`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool0KP3oool003<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo06l0oooo000c0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`1`0?ooo`00<`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0L@3oool003<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0780oooo000c0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1c0?ooo`00<`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0M03oool0
03<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
07D0oooo000c0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`1f0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
0P0000040?ooo`800000103oool2000000<0oooo0`0000030?ooo`<000001@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0MP3oool000050?ooo`00
0000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1g0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`1h0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`8000007P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo07T0oooo00001@3o
ool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo07X0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0N`3oool00080
oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool010000000
oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo07/0oooo000c0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`1l0?ooo`00<`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0O@3oool003<0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07h0oooo000c0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1o0?ooo`00<`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0P03oool003<0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0800
oooo000c0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`210?ooo`00<`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0PP3oool003<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo08<0oooo000c0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`240?ooo`00<`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0Q@3oool003<0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo08D0oooo000c0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`260?ooo`00<`3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0Q`3oool0
03<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
08P0oooo000c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`290?ooo`00<`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0R@3oool003<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo08X0oooo000c0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`2;0?ooo`00<`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0S03oool003<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo08`0oooo00080?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
0P3oool5000000@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo08d0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2>0?ooo`001`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0S`3o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo0P00000U0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0T03oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0T03oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0T@3oool000P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?oo
o`8000000`3oool3000000D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0980oooo000c0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`2C0?ooo`00<`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0T`3oool003<0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo09@0oooo000c0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2E0?ooo`00<`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0UP3oool003<0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo09H0
oooo000c0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`2G0?ooo`00<`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0V03oool003<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo09T0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`2J0?ooo`00<`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0VP3oool003<0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo09/0oooo000c0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2L0?ooo`00<`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0W@3oool0
03<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
09h0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`2O0?ooo`00<`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0X03oool003<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0:40oooo000c0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`2R0?ooo`00<`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0X`3oool003<0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0:@0oooo00020?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
0P3oool500000080oooo0`0000050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`2U0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool2000000l0oooo0P00002X0?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2X0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`800000<`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0:T0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0000000<000001@3oool00`000000oooo0?oo
o`0c0?ooo`800000203oool00`000000oooo0?ooo`2Z0?ooo`0000D0oooo0000003oool0oooo0000
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
00080?ooo`030000003oool0oooo03@0oooo2@00002]0?ooo`000P3oool2000000X0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000030?ooo`<000000P3oool5000000@0oooo00<00000
0?ooo`3oool0jP3oool003<0oooo00<000000?ooo`3oool0jP3oool003<0oooo00<000000?ooo`3o
ool0jP3oool003<0oooo00<000000?ooo`3oool0jP3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.43688, -3.88033*^-6, \
0.0869644, 1.79366*^-7}}],

Cell[BoxData[
    \({\((\[Theta]\^11\ \((12795837696 + 49147392768\ \[Theta] + 
                83327119488\ \[Theta]\^2 + 81828855824\ \[Theta]\^3 + 
                51278495688\ \[Theta]\^4 + 21258840312\ \[Theta]\^5 + 
                5828942920\ \[Theta]\^6 + 1018979202\ \[Theta]\^7 + 
                103027509\ \[Theta]\^8 + 
                4589441\ \[Theta]\^9)\))\)/\((466560000\ \((1 + \
\[Theta])\)\^8\ \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^5\ \((4 + \
\[Theta])\)\^4)\), \((\[Theta]\^11\ \((70228232064 + 260943980544\ \[Theta] + 
                427232957040\ \[Theta]\^2 + 404469563360\ \[Theta]\^3 + 
                243986226632\ \[Theta]\^4 + 97249433432\ \[Theta]\^5 + 
                25613445655\ \[Theta]\^6 + 4298849555\ \[Theta]\^7 + 
                417251249\ \[Theta]\^8 + 
                17847389\ \[Theta]\^9)\))\)/\((933120000\ \((1 + \
\[Theta])\)\^8\ \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^6\ \((4 + \
\[Theta])\)\^4)\)}\)], "Output",
  CellLabel->"Out[203]="]
}, Open  ]],

Cell[TextData[{
  "The MLE is almost the same, at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\&^ = 5.13\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[\(-Plus @@ ept\), {\[Theta], 5}]\)], "Input",
  CellLabel->"In[204]:="],

Cell[BoxData[
    \({\(-0.00002549416001406401`\), {\[Theta] \[Rule] 
          5.13381696273083`}}\)], "Output",
  CellLabel->"Out[204]="]
}, Open  ]],

Cell["\<\
The list of 132 possible rootings includes many equivalent \
solutions.  For example, the second and third solutions involve changing \
mutations 7 or 6, respectively; since these have the same distribution across \
the leaves, the result has the same probability:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, ExactProbability[SwapStates[#, S], 10. ]} &\) /@ 
      pr\[LeftDoubleBracket]{2, 3}\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[209]:="],

Cell[BoxData[
    \({{{0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0}, 
        1.2712484112398365`*^-7}, {{0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0}, 
        1.2712484112398365`*^-7}}\)], "Output",
  CellLabel->"Out[209]="]
}, Open  ]],

Cell[TextData[{
  "There are only 12 distinct solutions among the 132 possible rootings; the \
actual solution is fourth highest in probability, but is only 0.88 units of \
",
  Cell[BoxData[
      \(TraditionalForm\`log[L]\)]],
  " less likely:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Log[ep /. \[Theta] \[Rule] 10. ], 
      Union[Log[ept /. \[Theta] \[Rule] 10. ]]}\)], "Input",
  CellLabel->"In[213]:="],

Cell[BoxData[
    \({\(-16.536445992689316`\), {\(-27.056495082359056`\), \
\(-25.851260325790385`\), \(-22.197454350488947`\), \(-21.593184372170054`\), \
\(-19.58663705364478`\), \(-17.705833132769666`\), \(-17.65763319440341`\), \
\(-16.54199547405979`\), \(-16.536445992689316`\), \(-15.878096232340642`\), \
\(-15.863909610907752`\), \(-15.657467120616674`\)}}\)], "Output",
  CellLabel->"Out[213]="]
}, Open  ]],

Cell["\<\
This shows expressions for the probability of each of the 12 \
distinct possibilities, weighted by the number of ways they can be \
realised:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(prs = \(\((Count[ept, \ #]*#)\) &\) /@ Union[ept]\)], "Input",
  CellLabel->"In[223]:="],

Cell[BoxData[
    \({\(\[Theta]\^11\ \((23 + 6\ \[Theta])\)\)\/\(9216000\ \((1 + \
\[Theta])\)\^2\ \((2 + \[Theta])\)\^2\ \((3 + \[Theta])\)\^9\ \((4 + \
\[Theta])\)\^3\), \(\[Theta]\^11\ \((32 + 9\ \[Theta])\)\)\/\(6561000\ \((1 + \
\[Theta])\)\^2\ \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^3\ \((4 + \
\[Theta])\)\^3\), \((\[Theta]\^11\ \((5384009088 + 14808521088\ \[Theta] + 
                17853781536\ \[Theta]\^2 + 12324905568\ \[Theta]\^3 + 
                5328689976\ \[Theta]\^4 + 1477607400\ \[Theta]\^5 + 
                256625334\ \[Theta]\^6 + 25520986\ \[Theta]\^7 + 
                1112513\ \[Theta]\^8)\))\)/\((20155392000\ \((1 + \[Theta])\)\
\^2\ \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^9\ \((4 + \[Theta])\)\^3)\), \
\((7\ \[Theta]\^11\ \((12795837696 + 49147392768\ \[Theta] + 
                83327119488\ \[Theta]\^2 + 81828855824\ \[Theta]\^3 + 
                51278495688\ \[Theta]\^4 + 21258840312\ \[Theta]\^5 + 
                5828942920\ \[Theta]\^6 + 1018979202\ \[Theta]\^7 + 
                103027509\ \[Theta]\^8 + 
                4589441\ \[Theta]\^9)\))\)/\((155520000\ \((1 + \
\[Theta])\)\^8\ \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^5\ \((4 + \
\[Theta])\)\^4)\), \((7\ \[Theta]\^11\ \((23745656832 + 
                94664711168\ \[Theta] + 167041880768\ \[Theta]\^2 + 
                171192512928\ \[Theta]\^3 + 112257632656\ \[Theta]\^4 + 
                48821984632\ \[Theta]\^5 + 14074251732\ \[Theta]\^6 + 
                2591359094\ \[Theta]\^7 + 276277562\ \[Theta]\^8 + 
                12983097\ \[Theta]\^9)\))\)/\((4199040000\ \((1 + \[Theta])\)\
\^8\ \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^4\ \((4 + \[Theta])\)\^4)\), \
\((7\ \[Theta]\^11\ \((70228232064 + 260943980544\ \[Theta] + 
                427232957040\ \[Theta]\^2 + 404469563360\ \[Theta]\^3 + 
                243986226632\ \[Theta]\^4 + 97249433432\ \[Theta]\^5 + 
                25613445655\ \[Theta]\^6 + 4298849555\ \[Theta]\^7 + 
                417251249\ \[Theta]\^8 + 
                17847389\ \[Theta]\^9)\))\)/\((186624000\ \((1 + \
\[Theta])\)\^8\ \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^6\ \((4 + \
\[Theta])\)\^4)\), \((\[Theta]\^11\ \((6421204992 + 28841171968\ \[Theta] + 
                58258999168\ \[Theta]\^2 + 69713031552\ \[Theta]\^3 + 
                54737864000\ \[Theta]\^4 + 29474832896\ \[Theta]\^5 + 
                11023839792\ \[Theta]\^6 + 2827135384\ \[Theta]\^7 + 
                475469668\ \[Theta]\^8 + 47293557\ \[Theta]\^9 + 
                2108970\ \[Theta]\^10)\))\)/\((4199040000\ \((1 + \[Theta])\)\
\^8\ \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^4\ \((4 + \[Theta])\)\^4)\), \
\((\[Theta]\^11\ \((830083023360 + 2847950171136\ \[Theta] + 
                4415682936960\ \[Theta]\^2 + 4076560643904\ \[Theta]\^3 + 
                2482947279072\ \[Theta]\^4 + 1043063911440\ \[Theta]\^5 + 
                306194723352\ \[Theta]\^6 + 62036119068\ \[Theta]\^7 + 
                8302125400\ \[Theta]\^8 + 662524431\ \[Theta]\^9 + 
                23926340\ \[Theta]\^10)\))\)/\((201553920000\ \((1 + \
\[Theta])\)\^2\ \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^10\ \((4 + \
\[Theta])\)\^4)\), \((7\ \[Theta]\^11\ \((1885664738304 + 
                8695137563136\ \[Theta] + 18107180317728\ \[Theta]\^2 + 
                22473809164272\ \[Theta]\^3 + 18469037349136\ \[Theta]\^4 + 
                10551037381016\ \[Theta]\^5 + 4275388348586\ \[Theta]\^6 + 
                1228786117787\ \[Theta]\^7 + 245488031696\ \[Theta]\^8 + 
                32468961194\ \[Theta]\^9 + 2558958622\ \[Theta]\^10 + 
                91049787\ \[Theta]\^11)\))\)/\((746496000\ \((1 + \[Theta])\)\
\^8\ \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^7\ \((4 + \[Theta])\)\^4)\), \
\((7\ \[Theta]\^11\ \((46548880809984 + 257446849125888\ \[Theta] + 
                654084769730112\ \[Theta]\^2 + 
                1010591774148096\ \[Theta]\^3 + 
                1059208602444720\ \[Theta]\^4 + 
                795139953478128\ \[Theta]\^5 + 439778892605084\ \[Theta]\^6 + 
                181425941285320\ \[Theta]\^7 + 55821491837949\ \[Theta]\^8 + 
                12650873706145\ \[Theta]\^9 + 2052622377902\ \[Theta]\^10 + 
                225787000314\ \[Theta]\^11 + 15091949945\ \[Theta]\^12 + 
                462962269\ \[Theta]\^13)\))\)/\((7464960000\ \((1 + \[Theta])\
\)\^8\ \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^8\ \((4 + \
\[Theta])\)\^4)\), \((7\ \[Theta]\^11\ \((491427955929600 + 
                3185598951880704\ \[Theta] + 9607561108804800\ \[Theta]\^2 + 
                17879917995900288\ \[Theta]\^3 + 
                22958412294410928\ \[Theta]\^4 + 
                21540768623089632\ \[Theta]\^5 + 
                15253361306080692\ \[Theta]\^6 + 
                8299368326517464\ \[Theta]\^7 + 
                3497722971783303\ \[Theta]\^8 + 
                1141616225106166\ \[Theta]\^9 + 
                286175035561627\ \[Theta]\^10 + 
                54100650280014\ \[Theta]\^11 + 7465675041005\ \[Theta]\^12 + 
                709903706570\ \[Theta]\^13 + 41590704237\ \[Theta]\^14 + 
                1131686746\ \[Theta]\^15)\))\)/\((100776960000\ \((1 + \
\[Theta])\)\^8\ \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^9\ \((4 + \
\[Theta])\)\^4)\), \((\[Theta]\^11\ \((345905428866048 + 
                2601487598584320\ \[Theta] + 9208864079502336\ \[Theta]\^2 + 
                20378573714644992\ \[Theta]\^3 + 
                31574749068140544\ \[Theta]\^4 + 
                36347438262264192\ \[Theta]\^5 + 
                32184711485417184\ \[Theta]\^6 + 
                22385065450820432\ \[Theta]\^7 + 
                12376505067279644\ \[Theta]\^8 + 
                5468429281036726\ \[Theta]\^9 + 
                1929985616691302\ \[Theta]\^10 + 
                540746367509395\ \[Theta]\^11 + 
                118749145199816\ \[Theta]\^12 + 
                20001809081137\ \[Theta]\^13 + 2494534105022\ \[Theta]\^14 + 
                216988000189\ \[Theta]\^15 + 11750695672\ \[Theta]\^16 + 
                298213593\ \[Theta]\^17)\))\)/\((67184640000\ \((1 + \
\[Theta])\)\^8\ \((2 + \[Theta])\)\^10\ \((3 + \[Theta])\)\^10\ \((4 + \
\[Theta])\)\^4)\)}\)], "Output",
  CellLabel->"Out[223]="]
}, Closed]],

Cell["Only the first 4 contribute appreciably:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[prs // Evaluate, {\[Theta], 0, 20}, 
        PlotStyle \[Rule] {Black, Purple, Blue, Green, Orange, Red, Maroon}, 
        PlotRange \[Rule] {{0, 20}, {0, 10\^\(-5\)}}];\)\)], "Input",
  CellLabel->"In[227]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.05 0 61803.4 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -33 -6.25 ]
[-0.0125 .12361 0 6.25 ]
[-0.0125 .24721 -33 -6.25 ]
[-0.0125 .24721 0 6.25 ]
[-0.0125 .37082 -33 -6.25 ]
[-0.0125 .37082 0 6.25 ]
[-0.0125 .49443 -33 -6.25 ]
[-0.0125 .49443 0 6.25 ]
[-0.0125 .61803 -42 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(2.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(7.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(12.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(17.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
0 .61803 m
.00625 .61803 L
s
[(0.00001)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02463 0 L
.02537 0 L
.02671 0 L
.02793 0 L
.02924 0 L
.03067 0 L
.03185 0 L
.03316 0 L
.03453 0 L
.03581 0 L
.0381 0 L
.03939 0 L
.04057 0 L
.04314 0 L
.04459 0 L
.0459 0 L
.04845 0 L
.05086 0 L
.05367 0 L
.05626 0 L
.05911 0 L
.06212 0 L
.0677 0 L
.07292 0 L
.07865 0 L
.08481 0 L
.09545 0 L
Mistroke
.10704 0 L
.12815 0 L
.17088 0 L
.21202 0 L
.23304 0 L
.25574 0 L
.27769 0 L
.28813 0 L
.29786 0 L
.30823 0 L
.31767 0 L
.32815 0 L
.3336 0 L
.33938 0 L
.34434 0 L
.34982 0 L
.35221 0 L
.35479 0 L
.35721 0 L
.35946 0 L
.36074 0 L
.36211 0 L
.36289 0 L
.36363 0 L
.36501 0 L
.36572 0 L
.36647 0 L
.36781 0 L
.36856 0 L
.36926 0 L
.37002 0 L
.37085 0 L
.37219 0 L
.37364 0 L
.3763 0 L
.38127 0 L
.38635 0 L
.39113 0 L
.40201 0 L
.42406 0 L
.46465 0 L
.50781 0 L
.54938 0 L
.58936 0 L
.63192 0 L
.67288 0 L
.71642 0 L
.75837 0 L
.79872 0 L
.84165 0 L
Mistroke
.88299 0 L
.92274 0 L
.96506 0 L
1 0 L
Mfstroke
.628 .126 .941 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02463 0 L
.02537 0 L
.02671 0 L
.02793 0 L
.02924 0 L
.03067 0 L
.03185 0 L
.03316 0 L
.03453 0 L
.03581 0 L
.0381 0 L
.04057 0 L
.04335 0 L
.04594 0 L
.04878 0 L
.05181 0 L
.055 0 L
.05801 0 L
.06365 0 L
.06893 0 L
.0738 0 L
.08481 0 L
.09499 0 L
.10451 0 L
.12618 0 L
.16695 0 L
.18768 0 L
Mistroke
.21029 0 L
.23195 0 L
.25204 0 L
.26316 0 L
.27363 0 L
.28303 0 L
.28832 0 L
.29318 0 L
.29813 0 L
.3009 0 L
.30343 0 L
.30578 0 L
.30711 0 L
.30834 0 L
.30941 0 L
.31059 0 L
.31183 0 L
.31298 0 L
.31425 0 L
.31497 0 L
.31564 0 L
.317 0 L
.31844 0 L
.32106 0 L
.32344 0 L
.32923 0 L
.33469 0 L
.34493 0 L
.35575 0 L
.37514 0 L
.41498 0 L
.45739 0 L
.49821 0 L
.5416 0 L
.58341 0 L
.62362 0 L
.66641 0 L
.7076 0 L
.74721 0 L
.78938 0 L
.82997 0 L
.87314 0 L
.91471 0 L
.95469 0 L
.99724 0 L
1 0 L
Mfstroke
0 0 1 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02463 0 L
.02537 0 L
.02671 0 L
.02793 0 L
.02924 0 L
.03067 0 L
.03185 0 L
.03316 0 L
.03453 0 L
.03581 0 L
.0381 0 L
.04057 0 L
.04335 0 L
.04594 0 L
.04878 0 L
.05181 0 L
.055 0 L
.05801 0 L
.06365 0 L
.06893 0 L
.0738 0 L
.08481 0 L
.09499 0 L
.10451 0 L
.12618 0 L
.16695 1e-05 L
.18768 1e-05 L
Mistroke
.21029 1e-05 L
.23195 2e-05 L
.25204 2e-05 L
.26316 2e-05 L
.27363 2e-05 L
.28303 2e-05 L
.28832 2e-05 L
.29318 2e-05 L
.29813 2e-05 L
.30085 2e-05 L
.30343 2e-05 L
.30582 2e-05 L
.30709 2e-05 L
.30843 2e-05 L
.30955 2e-05 L
.3108 2e-05 L
.31192 2e-05 L
.31298 2e-05 L
.31425 2e-05 L
.31497 2e-05 L
.31564 2e-05 L
.317 2e-05 L
.31775 2e-05 L
.31844 2e-05 L
.31968 2e-05 L
.32101 2e-05 L
.32344 2e-05 L
.32629 2e-05 L
.3293 2e-05 L
.33469 2e-05 L
.34463 2e-05 L
.35529 2e-05 L
.37453 2e-05 L
.41793 2e-05 L
.45973 2e-05 L
.49994 1e-05 L
.54273 1e-05 L
.58392 1e-05 L
.62353 1e-05 L
.66571 1e-05 L
.7063 1e-05 L
.74946 1e-05 L
.79103 1e-05 L
.83101 1e-05 L
.87357 1e-05 L
.91453 0 L
.95807 0 L
1 0 L
Mfstroke
0 1 0 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 1e-05 L
.02115 1e-05 L
.02245 1e-05 L
.02317 2e-05 L
.02384 2e-05 L
.02537 3e-05 L
.02671 5e-05 L
.02793 6e-05 L
.02933 9e-05 L
.03067 .00012 L
.03186 .00016 L
.03313 .00021 L
.03541 .00032 L
.03786 .00048 L
.04057 .00074 L
.04336 .00109 L
.0463 .00157 L
.05155 .00279 L
.05448 .0037 L
.0572 .0047 L
.06339 .00758 L
.07374 .01437 L
.08481 .02418 L
.12838 .07644 L
.15022 .10171 L
.17036 .1207 L
.18998 .13452 L
.19987 .13975 L
.21075 .14424 L
.21623 .14603 L
.22142 .14746 L
.22614 .14854 L
Mistroke
.23117 .14947 L
.23662 .15024 L
.23905 .15051 L
.24167 .15074 L
.24328 .15086 L
.24476 .15096 L
.24615 .15103 L
.24767 .15109 L
.24904 .15114 L
.25032 .15117 L
.25167 .15119 L
.25242 .15119 L
.25311 .15119 L
.25435 .15119 L
.25552 .15118 L
.2568 .15115 L
.25817 .15112 L
.25954 .15107 L
.26098 .15101 L
.26355 .15086 L
.26815 .15052 L
.27319 .15002 L
.2845 .14846 L
.295 .14655 L
.33605 .13611 L
.37968 .12239 L
.42172 .10872 L
.46216 .09619 L
.50518 .08402 L
.54661 .0736 L
.58645 .06477 L
.62886 .05657 L
.66968 .04973 L
.71307 .04345 L
.75488 .03824 L
.79509 .0339 L
.83788 .0299 L
.87907 .02657 L
.91868 .02378 L
.96085 .02118 L
1 .01906 L
Mfstroke
1 .5 0 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02537 0 L
.02671 0 L
.02793 1e-05 L
.02933 1e-05 L
.03067 1e-05 L
.03186 2e-05 L
.03313 2e-05 L
.03541 3e-05 L
.03786 5e-05 L
.04057 8e-05 L
.04336 .00011 L
.0463 .00016 L
.05155 .00029 L
.05448 .00038 L
.0572 .00048 L
.06339 .00077 L
.07374 .00147 L
.08481 .00247 L
.12838 .00783 L
.15022 .01042 L
.17036 .01238 L
.18998 .01381 L
.19987 .01435 L
.21075 .01482 L
.21623 .01501 L
.22142 .01516 L
.22614 .01527 L
Mistroke
.23117 .01537 L
.23662 .01545 L
.24167 .0155 L
.24476 .01553 L
.24628 .01554 L
.24767 .01554 L
.24892 .01555 L
.25029 .01555 L
.25166 .01556 L
.25241 .01556 L
.25311 .01556 L
.25444 .01556 L
.25511 .01556 L
.25585 .01556 L
.25716 .01555 L
.25838 .01555 L
.25982 .01555 L
.26114 .01554 L
.26411 .01553 L
.26654 .01551 L
.26919 .01549 L
.27452 .01543 L
.28463 .01529 L
.29402 .01512 L
.33507 .01407 L
.3787 .01267 L
.42073 .01127 L
.46118 .00998 L
.5042 .00873 L
.54563 .00765 L
.58546 .00673 L
.62787 .00588 L
.66869 .00518 L
.71209 .00452 L
.75389 .00398 L
.7941 .00353 L
.83689 .00312 L
.87809 .00277 L
.91769 .00248 L
.95987 .00221 L
1 .00198 L
Mfstroke
1 0 0 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 1e-05 L
.01975 1e-05 L
.02043 2e-05 L
.02115 3e-05 L
.02245 4e-05 L
.02317 5e-05 L
.02384 6e-05 L
.02537 .0001 L
.02671 .00015 L
.02793 .0002 L
.02933 .00028 L
.03067 .00038 L
.03186 .0005 L
.03313 .00064 L
.03541 .00099 L
.03786 .00151 L
.04057 .00229 L
.04336 .00339 L
.0463 .00491 L
.05155 .00874 L
.05448 .01158 L
.0572 .01473 L
.06339 .0238 L
.07374 .04522 L
.08481 .07629 L
.12838 .24268 L
.15022 .32359 L
.17036 .38466 L
.18998 .42928 L
.19987 .44624 L
.21075 .46087 L
.21623 .46674 L
.22142 .47143 L
.22614 .47499 L
Mistroke
.23117 .47809 L
.23662 .48067 L
.24167 .48238 L
.24476 .48313 L
.24628 .48341 L
.24767 .48363 L
.24892 .48378 L
.25029 .48391 L
.25166 .484 L
.25241 .48404 L
.25311 .48406 L
.25444 .48407 L
.25511 .48406 L
.25585 .48404 L
.25716 .48398 L
.25838 .48389 L
.25982 .48375 L
.26114 .48358 L
.26411 .4831 L
.26654 .48259 L
.26919 .48191 L
.27452 .4802 L
.28463 .47579 L
.29402 .47051 L
.33507 .43785 L
.3787 .39429 L
.42073 .35064 L
.46118 .31046 L
.5042 .27136 L
.54563 .23781 L
.58546 .20936 L
.62787 .18291 L
.66869 .16084 L
.71209 .14057 L
.75389 .12374 L
.7941 .10972 L
.83689 .09679 L
.87809 .08602 L
.91769 .07697 L
.95987 .06856 L
1 .06157 L
Mfstroke
.69 .188 .377 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02537 0 L
.02671 0 L
.02793 0 L
.02933 0 L
.03067 0 L
.03186 0 L
.03313 0 L
.03541 0 L
.03786 0 L
.04057 0 L
.04336 0 L
.0463 0 L
.05155 1e-05 L
.05448 1e-05 L
.0572 1e-05 L
.06339 2e-05 L
.07374 3e-05 L
.08481 5e-05 L
.12838 .00016 L
.15022 .00021 L
.17036 .00025 L
.18998 .00029 L
.19987 .0003 L
.21075 .00031 L
.22142 .00032 L
.23117 .00032 L
.23656 .00032 L
Mistroke
.2394 .00032 L
.24243 .00033 L
.24533 .00033 L
.24797 .00033 L
.25062 .00033 L
.25311 .00033 L
.25433 .00033 L
.25565 .00033 L
.25688 .00033 L
.25801 .00033 L
.25934 .00033 L
.26008 .00033 L
.26077 .00033 L
.26204 .00033 L
.26339 .00033 L
.26467 .00033 L
.26605 .00033 L
.26855 .00033 L
.27151 .00033 L
.27423 .00033 L
.28369 .00032 L
.29364 .00032 L
.31441 .00031 L
.33371 .0003 L
.37476 .00027 L
.41839 .00025 L
.46043 .00022 L
.50087 .00019 L
.54389 .00017 L
.58532 .00015 L
.62515 .00013 L
.66757 .00011 L
.70839 .0001 L
.75178 9e-05 L
.79359 8e-05 L
.8338 7e-05 L
.87658 6e-05 L
.91778 6e-05 L
.95738 5e-05 L
.99956 4e-05 L
1 4e-05 L
Mfstroke
0 0 0 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02463 0 L
.02537 0 L
.02671 0 L
.02793 0 L
.02924 0 L
.03067 0 L
.03185 0 L
.03316 0 L
.03453 0 L
.03581 0 L
.0381 0 L
.03939 0 L
.04057 0 L
.04314 0 L
.0459 0 L
.0485 0 L
.05086 0 L
.05364 0 L
.05665 0 L
.06212 0 L
.06485 0 L
.06785 0 L
.07392 0 L
.07955 0 L
.08481 0 L
.09574 0 L
.10611 0 L
Mistroke
.12557 1e-05 L
.16573 2e-05 L
.18816 2e-05 L
.20846 2e-05 L
.2299 3e-05 L
.2496 3e-05 L
.26985 3e-05 L
.2805 3e-05 L
.29173 3e-05 L
.30171 3e-05 L
.3073 3e-05 L
.31239 3e-05 L
.31714 3e-05 L
.31981 3e-05 L
.32229 3e-05 L
.32445 3e-05 L
.32568 3e-05 L
.32683 3e-05 L
.32805 3e-05 L
.32916 3e-05 L
.33037 3e-05 L
.33165 3e-05 L
.33296 3e-05 L
.33369 3e-05 L
.33437 3e-05 L
.33558 3e-05 L
.33692 3e-05 L
.33925 3e-05 L
.3417 3e-05 L
.34725 3e-05 L
.35242 3e-05 L
.36173 3e-05 L
.37172 3e-05 L
.394 3e-05 L
.41512 3e-05 L
.45533 3e-05 L
.49812 3e-05 L
.53931 2e-05 L
.57892 2e-05 L
.6211 2e-05 L
.66169 2e-05 L
.70485 2e-05 L
.74642 1e-05 L
.7864 1e-05 L
.82896 1e-05 L
.86992 1e-05 L
.91346 1e-05 L
.9554 1e-05 L
.99576 1e-05 L
1 1e-05 L
Mistroke
Mfstroke
.628 .126 .941 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 1e-05 L
.01839 1e-05 L
.01975 2e-05 L
.02043 2e-05 L
.02115 3e-05 L
.02245 5e-05 L
.02317 6e-05 L
.02384 7e-05 L
.02537 .00012 L
.02671 .00017 L
.02793 .00023 L
.02933 .00033 L
.03067 .00044 L
.03186 .00057 L
.03313 .00074 L
.03541 .00115 L
.03786 .00175 L
.04057 .00266 L
.04336 .00394 L
.0463 .00571 L
.05155 .01021 L
.05448 .01355 L
.0572 .01726 L
.06339 .02797 L
.07374 .0534 L
.08481 .09051 L
.12838 .29184 L
.15022 .39111 L
.17036 .46677 L
.18998 .52265 L
.19987 .54412 L
.21075 .56283 L
.22142 .57655 L
.23117 .5854 L
.23656 .58891 L
Mistroke
.2394 .59039 L
.24243 .59169 L
.24533 .59269 L
.24797 .59338 L
.24924 .59365 L
.25062 .59389 L
.2519 .59407 L
.25311 .5942 L
.25442 .59429 L
.25561 .59434 L
.25689 .59435 L
.25762 .59434 L
.25829 .59432 L
.2594 .59426 L
.26063 .59417 L
.26191 .59403 L
.26312 .59386 L
.26587 .59336 L
.2684 .59275 L
.27409 .5909 L
.27924 .58869 L
.28487 .58572 L
.29622 .57824 L
.31685 .56039 L
.33886 .53706 L
.38249 .48406 L
.42452 .43097 L
.46497 .38207 L
.50799 .3344 L
.54942 .29344 L
.58925 .25865 L
.63166 .22626 L
.67248 .19918 L
.71588 .17427 L
.75768 .15357 L
.7979 .13629 L
.84068 .12035 L
.88188 .10704 L
.92148 .09586 L
.96366 .08545 L
1 .07756 L
Mfstroke
0 0 1 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 1e-05 L
.02043 1e-05 L
.02115 1e-05 L
.02245 2e-05 L
.02317 3e-05 L
.02384 3e-05 L
.02537 5e-05 L
.02671 7e-05 L
.02793 .0001 L
.02933 .00014 L
.03067 .00019 L
.03186 .00025 L
.03313 .00032 L
.03541 .00049 L
.03786 .00076 L
.04057 .00116 L
.04336 .00171 L
.0463 .00249 L
.0488 .00334 L
.05155 .00447 L
.05768 .00792 L
.06339 .01238 L
.07374 .02381 L
.08481 .04064 L
.12838 .13394 L
.15022 .181 L
.17036 .21743 L
.18998 .24482 L
.19987 .25553 L
.21075 .26501 L
.22142 .27212 L
.23117 .27688 L
.23656 .27884 L
Mistroke
.24243 .28048 L
.24511 .28107 L
.24797 .28158 L
.25042 .28194 L
.25311 .28224 L
.25453 .28236 L
.25585 .28245 L
.25725 .28253 L
.25804 .28256 L
.25875 .28258 L
.26003 .2826 L
.26142 .28261 L
.26273 .28259 L
.26394 .28256 L
.26461 .28254 L
.26533 .28251 L
.26664 .28243 L
.26961 .28221 L
.27276 .28187 L
.27563 .28148 L
.28057 .28063 L
.28596 .27946 L
.29682 .27642 L
.31746 .26859 L
.33947 .25807 L
.3831 .23365 L
.42513 .2088 L
.46558 .18569 L
.5086 .163 L
.55002 .14339 L
.58986 .12666 L
.63227 .11102 L
.67309 .0979 L
.71649 .08581 L
.75829 .07573 L
.7985 .06729 L
.84129 .0595 L
.88249 .05298 L
.92209 .04749 L
.96427 .04238 L
1 .03855 L
Mfstroke
0 1 0 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02537 1e-05 L
.02671 1e-05 L
.02793 1e-05 L
.02933 2e-05 L
.03067 3e-05 L
.03186 3e-05 L
.03313 4e-05 L
.03541 7e-05 L
.03786 .00011 L
.04057 .00016 L
.04336 .00024 L
.0463 .00035 L
.0488 .00047 L
.05155 .00064 L
.05768 .00114 L
.06339 .00179 L
.06881 .0026 L
.07374 .00349 L
.08481 .00602 L
.10495 .01216 L
.12679 .01995 L
.14725 .02712 L
.16975 .03395 L
.19113 .03899 L
.21113 .04235 L
.22206 .04367 L
.23243 .04461 L
Mistroke
.24174 .04522 L
.24701 .04547 L
.25189 .04565 L
.2545 .04573 L
.25724 .04579 L
.25868 .04582 L
.26025 .04584 L
.2617 .04586 L
.26302 .04587 L
.26436 .04589 L
.26563 .04589 L
.26698 .0459 L
.26773 .0459 L
.26843 .0459 L
.2696 .0459 L
.27088 .04589 L
.27223 .04588 L
.27348 .04587 L
.27588 .04585 L
.2784 .04581 L
.2829 .04572 L
.28774 .04559 L
.29303 .04542 L
.30385 .04495 L
.31367 .04442 L
.33568 .04294 L
.37771 .03941 L
.41816 .03566 L
.46118 .03169 L
.50261 .0281 L
.54244 .02495 L
.58485 .02194 L
.62567 .01939 L
.66907 .01701 L
.71087 .01502 L
.75108 .01335 L
.79387 .01179 L
.83507 .01049 L
.87467 .0094 L
.91685 .00838 L
.95744 .00751 L
1 .00672 L
Mfstroke
1 .5 0 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02537 0 L
.02671 0 L
.02793 0 L
.02933 0 L
.03067 0 L
.03186 0 L
.03313 0 L
.03541 0 L
.03786 0 L
.04057 0 L
.04336 1e-05 L
.0463 1e-05 L
.0488 1e-05 L
.05155 2e-05 L
.05451 3e-05 L
.05768 4e-05 L
.06339 6e-05 L
.06916 8e-05 L
.07461 .00012 L
.08481 .0002 L
.10582 .00043 L
.1252 .00069 L
.16657 .00126 L
.18736 .00149 L
.20635 .00166 L
.22677 .00179 L
.23803 .00184 L
Mistroke
.24871 .00188 L
.2588 .00191 L
.26444 .00192 L
.26955 .00193 L
.27433 .00193 L
.27703 .00194 L
.2795 .00194 L
.28168 .00194 L
.28291 .00194 L
.28406 .00194 L
.28527 .00194 L
.28638 .00194 L
.28766 .00194 L
.28887 .00194 L
.29007 .00194 L
.29136 .00194 L
.29258 .00194 L
.2937 .00194 L
.2963 .00194 L
.29903 .00194 L
.30418 .00193 L
.30981 .00193 L
.31985 .00191 L
.32917 .0019 L
.35069 .00184 L
.37022 .00179 L
.41226 .00164 L
.4527 .0015 L
.49572 .00134 L
.53715 .0012 L
.57698 .00107 L
.6194 .00095 L
.66022 .00085 L
.70361 .00075 L
.74542 .00067 L
.78563 .0006 L
.82841 .00053 L
.86961 .00048 L
.90921 .00043 L
.95139 .00039 L
.99198 .00035 L
1 .00034 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[227]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00@@3oool5000000<0oooo00<000000?ooo`3oool0
0P3oool3000001@0oooo0`00000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool300000140oooo0`0000040?ooo`8000003`3oool300000080oooo1@0000030?ooo`030000
003oool0oooo0080oooo0`00000>0?ooo`<000000`3oool3000000l0oooo0`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3000000h0oooo1@0000030?ooo`800000
0`3oool00480oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool000000180
oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo0000000A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo0000000>0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0
000000h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`00@`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00140?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool100000040oooo0@3oool00440oooo00D000000?ooo`3o
ool0oooo000000070?ooo`@000004`3oool4000001P0oooo00<000000?ooo`3oool01@3oool40000
0180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000?0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`@000003`3oool010000000oooo0?oo
o`3oool400000100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`@00000
3P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00440
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool04P3oool2
000000@0oooo00@000000?ooo`3oool000003P3oool2000000<0oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo00l0oooo0P0000030?ooo`030000003oool0oooo0100oooo
0P0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`00@P3oool30000
00P0oooo1@00000B0?ooo`D000004`3oool5000000L0oooo1@00000A0?ooo`030000003oool0oooo
00<0oooo0P00000@0?ooo`030000003oool0oooo0080oooo0`0000080?ooo`D000003P3oool01000
0000oooo0?ooo`3oool5000000l0oooo00@000000?ooo`3oool0oooo1@0000070?ooo`D000003P3o
ool3000000@0oooo0P0000030?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00;03oooo^0?mo00H0oooo000/0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool0102P8?00003o0000o`00o`030?ooo`@00?l00P3oool50?mo00030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3ooom50?mo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`0000000?l0003o0004003o00H0oooo000/0?ooo`030000003o
ool0oooo00X0oooo00<0X23`0000o`00o`000P00o`040?ooo`<00?l0103oool;0?mo03L0oooo9`3o
O`0k0?ooobL00?l0303oool002`0oooo00<000000?ooo`3oool02P3oool01P2P8?00o`000000o`00
0?l0oooo003o00H0oooo0P00o`0=0?ooocL0ogl0A03ooolN003o03<0oooo000/0?ooo`030000003o
ool0oooo00/0oooo00D0X23`0?ooo`3oool0003o003o00080?ooo`<00?l0LP3ooolC003o04D0oooo
1P00o`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`060:0Pl03o0000oooo0?ooo`000?l0
0?l02P3oool4003o06@0oooo2P00o`150?oooa<00?l0303oool002`0oooo00<000000?ooo`3oool0
303oool01P2P8?00oooo0?ooo`000?l0oooo003o00d0oooo1000o`1<0?oooa@00?l0A@3oool:003o
01l0oooo000/0?ooo`8000003@3oool01P2P8?00o`000?ooo`3oool0003o003o0140oooo0`00o`0o
0?ooo`X00?l0C`3oool:003o02T0oooo000/0?ooo`030000003oool0oooo00d0oooo00H0X23`0?l0
003oool0003o0?ooo`00o`0C0?ooo`@00?l0<P3oool9003o0500oooo2@00o`0c0?ooo`00;03oool0
0`000000oooo0?ooo`0=0?ooo`070:0Pl03o0000oooo0?ooo`000?l0oooo003o000F0?ooo`@00?l0
903oool:003o04l0oooo2P00o`0a0?ooo`D0003o1P3oool002`0oooo00<000000?ooo`3oool03P3o
ool0102P8?00o`000?ooo`000?l20?ooo`03003o003oool0oooo01L0oooo2P00o`0<0?ooo`h00?l0
DP3oool7003o0340oooo2P000?l;0?ooo`00;03oool00`000000oooo0?ooo`0>0?ooo`050:0Pl03o
0000oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`0P0?ooo``00?l0F`3oool5003o02l0oooo
2@000?lE0?ooo`00;03oool00`000000oooo0?ooo`0?0?ooo`040:0Pl03oool0oooo0000o`<0oooo
00<00?l00?ooo`3oool0OP3oool8003o02d0oooo1`000?lN0?ooo`00;03oool00`000000oooo0?oo
o`0?0?ooo`050:0Pl03o0000oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`1f0?ooo`L00?l0
<03oool50000obD0oooo000/0?ooo`800000403oool01@2P8?00o`000?ooo`3oool0003o00@0oooo
00<00?l00?ooo`3oool0L03oool5003o0380oooo1@000?lQ0?ooo`<0o`001P3oool002`0oooo00<0
00000?ooo`3oool0403oool01@2P8?00oooo0?ooo`3oool0003o00@0oooo00<00?l00?ooo`3oool0
JP3oool5003o0380oooo1@000?lQ0?ooo`D0o`002@3oool002`0oooo00<000000?ooo`3oool0403o
ool01@2P8?00oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool0I03oool5003o0380oooo
1@000?lQ0?ooo`D0o`003P3oool002`0oooo00<000000?ooo`3oool0403oool00`2P8?00o`000?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool0G`3oool4003o0380oooo1@00
0?lQ0?ooo`D0o`004`3oool002`0oooo00<000000?ooo`3oool0403oool00`2P8?00o`000?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0F`3oool3003o0340oooo1@000?lQ
0?ooo`D0o`003`3oool30:0Pl0H0oooo000/0?ooo`030000003oool0oooo0100oooo00<0X23`0?l0
003oool00`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo05P0oooo0`00o`0_0?oo
o`D0003o8@3oool50?l000l0oooo1@2P8?090?ooo`00;03oool00`000000oooo0?ooo`0A0?ooo`03
0:0Pl03oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`1C0?ooo`@0
0?l0;P3oool40000ob80oooo103o000@0?ooo`@0X23`3P3oool002`0oooo00<000000?ooo`3oool0
4@3oool00`2P8?00o`000?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0
C`3oool3003o02h0oooo10000?lS0?ooo`<0o`003`3oool50:0Pl180oooo000/0?ooo`8000004P3o
ool00`2P8?00o`000?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool0B`3o
ool3003o02h0oooo0`000?lT0?ooo`<0o`003P3oool40:0Pl1L0oooo000/0?ooo`030000003oool0
oooo0140oooo00<0X23`0?l0003oool0103oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0
oooo04H0oooo1000o`0^0?ooo`<0003o8`3oool40?l000h0oooo0`2P8?0K0?ooo`00;03oool00`00
0000oooo0?ooo`0B0?ooo`030:0Pl03o0000oooo00<0oooo00<0003o0?ooo`3oool01P3oool2003o
0440oooo1@00o`0_0?ooo`<0003o8`3oool30?l000l0oooo0`2P8?0N0?ooo`00;03oool00`000000
oooo0?ooo`0B0?ooo`030:0Pl03o0000oooo00@0oooo00<0003o0?ooo`3oool01`3oool00`00o`00
oooo0?ooo`0j0?ooo`@00?l0<@3oool30000ob<0oooo0`3o000>0?ooo`@0X23`8@3oool000T0oooo
1@0000020?ooo`060000003oool0oooo0?ooo`000000oooo0`0000040?ooo`8000003@3oool00`00
0000oooo0?ooo`0B0?ooo`030:0Pl03o0000oooo00@0oooo00<0003o0?ooo`3oool0203oool00`00
o`00oooo0?ooo`0f0?ooo`<00?l0<P3oool30000ob80oooo103o000>0?ooo`<0X23`9@3oool000X0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0B0?ooo`030:0Pl03o0000
oooo00D0oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`0c0?ooo`800?l0<P3oool3
0000ob80oooo0`3o000?0?ooo`<0X23`:03oool000/0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000303oool0
0`000000oooo0?ooo`0B0?ooo`030:0Pl03oool0o`0000D0oooo00<0003o0?ooo`3oool02@3oool0
0`00o`00oooo0?ooo`0_0?ooo`<00?l0<P3oool20000ob80oooo0`3o000?0?ooo`<0X23`:`3oool0
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000303oool3000001<0oooo00<0X23`0?l0003oool01@3oool0
0`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo02/0oooo0`00o`0b0?ooo`<0003o8@3oool3
0?l000l0oooo0`2P8?0^0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
303oool00`000000oooo0?ooo`0C0?ooo`030:0Pl03o0000oooo00D0oooo00<0003o0?ooo`3oool0
2P3oool00`00o`00oooo0?ooo`0W0?ooo`<00?l0<`3oool20000ob80oooo0P3o000@0?ooo`80X23`
<@3oool000T0oooo00D000000?ooo`3oool0oooo000000080?ooo`800000103oool010000000oooo
0?ooo`0000080?ooo`8000000P3oool00`000000oooo0?ooo`0C0?ooo`030:0Pl03oool0o`0000H0
oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo0?ooo`0S0?ooo`<00?l0<`3oool30000ob40
oooo0`3o000?0?ooo`<0X23`<`3oool000X0oooo0`00000:0?ooo`030000003oool0oooo00<0oooo
0P0000030?ooo`@0000000@0oooo0000003oool000000P3oool00`000000oooo0?ooo`0C0?ooo`03
0:0Pl03oool0o`0000H0oooo00<0003o0?ooo`3oool02`3oool3003o01h0oooo1000o`0d0?ooo`80
003o8P3oool20?l00100oooo0P2P8?0f0?ooo`009`3oool300000080oooo00<000000?ooo`3oool0
503oool00`2P8?00o`000?ooo`060?ooo`030000o`3oool0oooo00d0oooo0P00o`0G0?ooo`D00?l0
=@3oool30000ob80oooo0P3o000?0?ooo`<0X23`>03oool002L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0D0?ooo`030:0Pl03o0000oooo00H0oooo00<0003o0?ooo`3oool03`3o
ool3003o0100oooo1000o`0h0?ooo`80003o8`3oool20?l000l0oooo0P2P8?0k0?ooo`00:03oool2
00000080oooo00<000000?ooo`3oool0503oool00`2P8?00oooo0?l000060?ooo`030000o`3oool0
oooo0180oooo4000o`0j0?ooo`80003o8P3oool30?l000h0oooo0`2P8?0m0?ooo`00;03oool20000
01D0oooo00<0X23`0?ooo`3o00001`3oool00`000?l0oooo0?ooo`0H0?ooo`03003o003oool0oooo
03d0oooo0`000?lR0?ooo`80o`003`3oool20:0Pl400oooo000/0?ooo`030000003oool0oooo01D0
oooo00<0X23`0?l0003oool01P3oool00`000?l0oooo0?ooo`1F0?ooo`80003o8`3oool20?l000l0
oooo0P2P8?120?ooo`00;03oool00`000000oooo0?ooo`0E0?ooo`030:0Pl03oool0o`0000L0oooo
00<0003o0?ooo`3oool0D`3oool20000ob<0oooo0P3o000?0?ooo`80X23`A03oool002`0oooo00<0
00000?ooo`3oool05@3oool00`2P8?00oooo0?l000070?ooo`030000o`3oool0oooo0540oooo0P00
0?lS0?ooo`80o`003`3oool20:0Pl4H0oooo000/0?ooo`030000003oool0oooo01D0oooo00<0X23`
0?ooo`3o0000203oool00`000?l0oooo0?ooo`1>0?ooo`80003o8`3oool20?l000l0oooo0P2P8?18
0?ooo`00;03oool00`000000oooo0?ooo`0E0?ooo`030:0Pl03oool0o`0000P0oooo00<0003o0?oo
o`3oool0C@3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo00d0oooo0P2P8?1:0?oo
o`00;03oool00`000000oooo0?ooo`0F0?ooo`030:0Pl03oool0o`0000L0oooo00<0003o0?ooo`3o
ool0B`3oool20000ob<0oooo0P3o000>0?ooo`80X23`C03oool002`0oooo00<000000?ooo`3oool0
5P3oool00`2P8?00oooo0?l000080?ooo`030000o`3oool0oooo04P0oooo0P000?lS0?ooo`80o`00
3`3oool00`2P8?00oooo0?ooo`1<0?ooo`00;03oool2000001L0oooo00<0X23`0?ooo`3o0000203o
ool00`000?l0oooo0?ooo`160?ooo`80003o8`3oool20?l000l0oooo0P2P8?1?0?ooo`00;03oool0
0`000000oooo0?ooo`0F0?ooo`030:0Pl03oool0o`0000T0oooo00<0003o0?ooo`3oool0@`3oool2
0000ob@0oooo00<0o`000?ooo`3oool03@3oool20:0Pl540oooo000/0?ooo`030000003oool0oooo
01L0oooo00<0X23`0?ooo`3o00002@3oool00`000?l0oooo0?ooo`100?ooo`80003o903oool20?l0
00l0oooo00<0X23`0?ooo`3oool0D@3oool002`0oooo00<000000?ooo`3oool05`3oool00`2P8?00
oooo0?l000090?ooo`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool08P3oool20?l000l0
oooo0P2P8?1D0?ooo`00;03oool00`000000oooo0?ooo`0G0?ooo`030:0Pl03oool0o`0000X0oooo
00<0003o0?ooo`3oool0?03oool20000ob@0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo
0?ooo`1D0?ooo`00;03oool00`000000oooo0?ooo`0G0?ooo`040:0Pl03oool0oooo0?l000T0oooo
00<0003o0?ooo`3oool0>P3oool20000ob@0oooo0P3o000?0?ooo`80X23`E`3oool002`0oooo00<0
00000?ooo`3oool0603oool00`2P8?00oooo0?l0000:0?ooo`030000o`3oool0oooo03L0oooo0P00
0?lU0?ooo`030?l0003oool0oooo00h0oooo00<0X23`0?ooo`3oool0E`3oool002`0oooo0P00000I
0?ooo`030:0Pl03oool0o`0000/0oooo00<0003o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0S
0?ooo`80o`003`3oool20:0Pl5X0oooo000/0?ooo`030000003oool0oooo01P0oooo00<0X23`0?oo
o`3o00002`3oool00`000?l0oooo0?ooo`0c0?ooo`80003o9@3oool00`3o0000oooo0?ooo`0>0?oo
o`030:0Pl03oool0oooo05X0oooo000/0?ooo`030000003oool0oooo01P0oooo00@0X23`0?ooo`3o
ool0o`002`3oool00`000?l0oooo0?ooo`0`0?ooo`80003o9P3oool00`3o0000oooo0?ooo`0=0?oo
o`80X23`G@3oool002`0oooo00<000000?ooo`3oool0603oool0102P8?00oooo0?ooo`3o000;0?oo
o`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool0903oool20?l000l0oooo00<0X23`0?oo
o`3oool0G@3oool000/0oooo0`0000020?ooo`060000003oool0oooo0?ooo`000000oooo0`000004
0?ooo`8000003@3oool00`000000oooo0?ooo`0I0?ooo`030:0Pl03oool0o`0000`0oooo00<0003o
0?ooo`3oool0;03oool20000obH0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo0?ooo`1N
0?ooo`00303oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo01T0oooo00@0X23`
0?ooo`3oool0o`00303oool00`000?l0oooo0?ooo`0Y0?ooo`80003o9P3oool20?l00100oooo00<0
X23`0?ooo`3oool0G`3oool000T0oooo1@0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo01T0oooo00@0
X23`0?ooo`3oool0o`00303oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo02D0oooo
00<0o`000?ooo`3oool03P3oool20:0Pl680oooo00090?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000`0
oooo0`00000I0?ooo`040:0Pl03oool0oooo0?l000d0oooo0P000?lV0?ooo`80003o9`3oool00`3o
0000oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo0680oooo000:0?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000303oool00`000000oooo0?ooo`0J0?ooo`030:0Pl03oool0o`0000l0oooo00<0003o
0?ooo`3oool08@3oool20000obP0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo0?ooo`1S
0?ooo`002`3oool2000000T0oooo0P0000040?ooo`040000003oool0oooo000000P0oooo0P000002
0?ooo`030000003oool0oooo01X0oooo00@0X23`0?ooo`3oool0o`003`3oool00`000?l0oooo0?oo
o`0O0?ooo`030000o`3oool0oooo02H0oooo0P3o000@0?ooo`030:0Pl03oool0oooo06@0oooo000<
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool2000000<0oooo10000000
103oool000000?ooo`0000020?ooo`030000003oool0oooo01X0oooo00@0X23`0?ooo`3oool0o`00
403oool00`000?l0oooo0?ooo`0L0?ooo`80003o:03oool00`3o0000oooo0?ooo`0>0?ooo`80X23`
I`3oool002L0oooo0`0000020?ooo`030000003oool0oooo01X0oooo00@0X23`0?ooo`3oool0o`00
4@3oool20000oaT0oooo0`000?lY0?ooo`030?l0003oool0oooo00h0oooo00<0X23`0?ooo`3oool0
I`3oool002L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030:0Pl03o
ool0o`0001<0oooo00<0003o0?ooo`3oool04`3oool30000ob/0oooo00<0o`000?ooo`3oool03P3o
ool00`2P8?00oooo0?ooo`1X0?ooo`00:03oool200000080oooo00<000000?ooo`3oool06`3oool0
102P8?00oooo0?ooo`3o000C0?ooo`80003o4@3oool20000ob`0oooo0P3o000@0?ooo`030:0Pl03o
ool0oooo06T0oooo000/0?ooo`800000703oool0102P8?00oooo0?ooo`3o000E0?ooo`030000o`3o
ool0oooo00`0oooo0P000?l]0?ooo`030?l0003oool0oooo00h0oooo0P2P8?1/0?ooo`00;03oool0
0`000000oooo0?ooo`0K0?ooo`040:0Pl03oool0oooo0?l001H0oooo1P000?l00`3oool0003o0000
o`050000obh0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo0?ooo`1/0?ooo`00;03oool0
0`000000oooo0?ooo`0K0?ooo`050:0Pl03oool0oooo0?ooo`3o00006P3oool30000oc<0oooo00<0
o`000?ooo`3oool03P3oool00`2P8?00oooo0?ooo`1]0?ooo`00;03oool00`000000oooo0?ooo`0L
0?ooo`040:0Pl03oool0oooo0?l004l0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo0?oo
o`1^0?ooo`00;03oool00`000000oooo0?ooo`0L0?ooo`040:0Pl03oool0oooo0?l004h0oooo00<0
o`000?ooo`3oool03P3oool00`2P8?00oooo0?ooo`1_0?ooo`00;03oool00`000000oooo0?ooo`0L
0?ooo`040:0Pl03oool0oooo0?l004d0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo0?oo
o`1`0?ooo`00;03oool00`000000oooo0?ooo`0L0?ooo`050:0Pl03oool0oooo0?ooo`3o0000B`3o
ool00`3o0000oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo0740oooo000/0?ooo`030000003oool0
oooo01d0oooo00@0X23`0?ooo`3oool0o`00BP3oool00`3o0000oooo0?ooo`0>0?ooo`030:0Pl03o
ool0oooo0780oooo000/0?ooo`8000007P3oool0102P8?00oooo0?ooo`3o00190?ooo`030?l0003o
ool0oooo00h0oooo00<0X23`0?ooo`3oool0L`3oool002`0oooo00<000000?ooo`3oool07@3oool0
102P8?00oooo0?ooo`3o00190?ooo`030?l0003oool0oooo00d0oooo00<0X23`0?ooo`3oool0M03o
ool002`0oooo00<000000?ooo`3oool07@3oool01@2P8?00oooo0?ooo`3oool0o`0004L0oooo00<0
o`000?ooo`3oool03@3oool00`2P8?00oooo0?ooo`1e0?ooo`00;03oool00`000000oooo0?ooo`0M
0?ooo`050:0Pl03oool0oooo0?ooo`3o0000AP3oool00`3o0000oooo0?ooo`0=0?ooo`030:0Pl03o
ool0oooo07H0oooo000/0?ooo`030000003oool0oooo01h0oooo00@0X23`0?ooo`3oool0o`00A@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030:0Pl03oool0oooo07L0oooo000/0?ooo`030000003oool0
oooo01h0oooo00D0X23`0?ooo`3oool0oooo0?l000130?ooo`030?l0003oool0oooo00d0oooo00<0
X23`0?ooo`3oool0N03oool002`0oooo00<000000?ooo`3oool07P3oool01@2P8?00oooo0?ooo`3o
ool0o`000480oooo00<0o`000?ooo`3oool03@3oool00`2P8?00oooo0?ooo`1i0?ooo`00;03oool2
000001l0oooo00D0X23`0?ooo`3oool0oooo0?l000110?ooo`030?l0003oool0oooo00h0oooo00<0
X23`0?ooo`3oool0N@3oool002`0oooo00<000000?ooo`3oool07`3oool01@2P8?00oooo0?ooo`3o
ool0o`0003l0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo0?ooo`1j0?ooo`00;03oool0
0`000000oooo0?ooo`0O0?ooo`050:0Pl03oool0oooo0?ooo`3o0000?P3oool00`3o0000oooo0?oo
o`0>0?ooo`030:0Pl03oool0oooo07/0oooo000/0?ooo`030000003oool0oooo01l0oooo00D0X23`
0?ooo`3oool0oooo0?l0000m0?ooo`030?l0003oool0oooo00h0oooo00<0X23`0?ooo`3oool0O03o
ool000X0oooo0`0000030?ooo`060000003oool0oooo0?ooo`000000oooo0`0000040?ooo`800000
3@3oool00`000000oooo0?ooo`0O0?ooo`030:0Pl03oool0oooo0080oooo00<0o`000?ooo`3oool0
>@3oool00`3o0000oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo07d0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0O0?ooo`030:0Pl03oool0oooo0080
oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo07h0
oooo00090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0P0?oo
o`050:0Pl03oool0oooo0?ooo`3o0000>@3oool00`3o0000oooo0?ooo`0>0?ooo`030:0Pl03oool0
oooo07l0oooo00090?ooo`@00000103oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000303oool300000200oooo00<0X23`0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo00h0oooo00<0X23`0?ooo`3oool0P03oool0
00T0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0200oooo00<0
X23`0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0d0?ooo`030?l0003oool0oooo00h0oooo00<0
X23`0?ooo`3oool0P@3oool000X0oooo00<000000?ooo`3oool02@3oool2000000@0oooo00@00000
0?ooo`3oool00000203oool200000080oooo00<000000?ooo`3oool0803oool00`2P8?00oooo0?oo
o`020?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool03P3oool00`2P8?00oooo0?oo
o`220?ooo`002`3oool2000000X0oooo00<000000?ooo`3oool00`3oool2000000<0oooo10000000
103oool000000?ooo`0000020?ooo`030000003oool0oooo0200oooo00<0X23`0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0a0?ooo`030?l0003oool0oooo00h0oooo00<0X23`0?ooo`3oool0P`3o
ool002L0oooo0`0000020?ooo`030000003oool0oooo0240oooo00<0X23`0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0`0?ooo`030?l0003oool0oooo00l0oooo00<0X23`0?ooo`3oool0P`3oool0
02L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030:0Pl03oool0oooo
0080oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0?0?ooo`030:0Pl03oool0oooo
08@0oooo000X0?ooo`8000000P3oool00`000000oooo0?ooo`0Q0?ooo`030:0Pl03oool0oooo00<0
oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0?0?ooo`030:0Pl03oool0oooo08D0
oooo000/0?ooo`030000003oool0oooo0240oooo00<0X23`0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0/0?ooo`030?l0003oool0oooo00l0oooo00<0X23`0?ooo`3oool0QP3oool002`0oooo0P00
000S0?ooo`030:0Pl03oool0oooo0080oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?oo
o`0@0?ooo`030:0Pl03oool0oooo08H0oooo000/0?ooo`030000003oool0oooo0280oooo00<0X23`
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0X23`
0?ooo`3oool0Q`3oool002`0oooo00<000000?ooo`3oool08P3oool00`2P8?00oooo0?ooo`030?oo
o`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`2P8?00oooo0?ooo`280?oo
o`00;03oool00`000000oooo0?ooo`0S0?ooo`030:0Pl03oool0oooo00<0oooo00<0o`000?ooo`3o
ool09P3oool00`3o0000oooo0?ooo`0@0?ooo`030:0Pl03oool0oooo08T0oooo000/0?ooo`030000
003oool0oooo02<0oooo00<0X23`0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0
003oool0oooo0140oooo00<0X23`0?ooo`3oool0R@3oool002`0oooo00<000000?ooo`3oool08`3o
ool00`2P8?00oooo0?ooo`030?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool04@3o
ool00`2P8?00oooo0?ooo`2:0?ooo`00;03oool00`000000oooo0?ooo`0S0?ooo`030:0Pl03oool0
oooo00@0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0A0?ooo`030:0Pl03oool0
oooo08/0oooo000/0?ooo`8000009@3oool00`2P8?00oooo0?ooo`030?ooo`030?l0003oool0oooo
0240oooo00<0o`000?ooo`3oool04@3oool00`2P8?00oooo0?ooo`2<0?ooo`00;03oool00`000000
oooo0?ooo`0T0?ooo`030:0Pl03oool0oooo00@0oooo00<0o`000?ooo`3oool07P3oool20?l001@0
oooo00<0X23`0?ooo`3oool0S03oool002`0oooo00<000000?ooo`3oool0903oool00`2P8?00oooo
0?ooo`050?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool04`3oool00`2P8?00oooo
0?ooo`2=0?ooo`00;03oool00`000000oooo0?ooo`0T0?ooo`030:0Pl03oool0oooo00H0oooo00<0
o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0C0?ooo`030:0Pl03oool0oooo08h0oooo000/
0?ooo`030000003oool0oooo02D0oooo00<0X23`0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0I
0?ooo`030?l0003oool0oooo01<0oooo00<0X23`0?ooo`3oool0S`3oool002`0oooo00<000000?oo
o`3oool09@3oool00`2P8?00oooo0?ooo`060?ooo`030?l0003oool0oooo01H0oooo0P3o000E0?oo
o`030:0Pl03oool0oooo0900oooo000/0?ooo`030000003oool0oooo02D0oooo00<0X23`0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo01@0oooo00<0X23`0?ooo`3o
ool0T@3oool002`0oooo0P00000W0?ooo`030:0Pl03oool0oooo00H0oooo00<0o`000?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`0E0?ooo`030:0Pl03oool0oooo0940oooo000/0?ooo`030000003o
ool0oooo02H0oooo00<0X23`0?ooo`3oool01`3oool20?l00180oooo00<0o`000?ooo`3oool05@3o
ool00`2P8?00oooo0?ooo`2B0?ooo`00;03oool00`000000oooo0?ooo`0V0?ooo`030:0Pl03oool0
oooo00T0oooo00<0o`000?ooo`3oool03@3oool20?l001L0oooo00<0X23`0?ooo`3oool0T`3oool0
02`0oooo00<000000?ooo`3oool09P3oool00`2P8?00oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00X0oooo0P3o000H0?ooo`030:0Pl03oool0oooo09@0oooo000:0?ooo`<000000`3oool01P000000
oooo0?ooo`3oool000000?ooo`<00000103oool2000000d0oooo00<000000?ooo`3oool09`3oool0
0`2P8?00oooo0?ooo`0:0?ooo`80o`00203oool20?l001T0oooo00<0X23`0?ooo`3oool0U@3oool0
00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo02L0oooo00<0
X23`0?ooo`3oool0303oool80?l001X0oooo00<0X23`0?ooo`3oool0UP3oool000T0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo02L0oooo00<0X23`0?ooo`3oool0
;P3oool00`2P8?00oooo0?ooo`2F0?ooo`002P3oool3000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0
:03oool00`2P8?00oooo0?ooo`0/0?ooo`030:0Pl03oool0oooo09L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000<0?ooo`<00000:03oool00`2P8?00oooo0?ooo`0[0?oo
o`030:0Pl03oool0oooo09P0oooo00090?ooo`050000003oool0oooo0?ooo`000000203oool20000
00@0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0X0?ooo`030:0Pl03oool0
oooo02X0oooo00<0X23`0?ooo`3oool0V@3oool000X0oooo0`00000:0?ooo`030000003oool0oooo
00<0oooo0P0000090?ooo`8000000P3oool00`000000oooo0?ooo`0Y0?ooo`030:0Pl03oool0oooo
02P0oooo00<0X23`0?ooo`3oool0VP3oool00280oooo10000000103oool000000?ooo`0000020?oo
o`030000003oool0oooo02T0oooo00<0X23`0?ooo`3oool09`3oool00`2P8?00oooo0?ooo`2K0?oo
o`009`3oool300000080oooo00<000000?ooo`3oool0:@3oool00`2P8?00oooo0?ooo`0V0?ooo`03
0:0Pl03oool0oooo09`0oooo000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
:P3oool00`2P8?00oooo0?ooo`0U0?ooo`030:0Pl03oool0oooo09`0oooo000X0?ooo`8000000P3o
ool00`000000oooo0?ooo`0Z0?ooo`030:0Pl03oool0oooo02@0oooo00<0X23`0?ooo`3oool0W@3o
ool002`0oooo0P00000[0?ooo`030:0Pl03oool0oooo02<0oooo00<0X23`0?ooo`3oool0WP3oool0
02`0oooo00<000000?ooo`3oool0:`3oool00`2P8?00oooo0?ooo`0Q0?ooo`030:0Pl03oool0oooo
09l0oooo000/0?ooo`030000003oool0oooo02`0oooo00<0X23`0?ooo`3oool07`3oool00`2P8?00
oooo0?ooo`2P0?ooo`00;03oool00`000000oooo0?ooo`0/0?ooo`030:0Pl03oool0oooo01h0oooo
00<0X23`0?ooo`3oool0X@3oool002`0oooo00<000000?ooo`3oool0;@3oool00`2P8?00oooo0?oo
o`0L0?ooo`030:0Pl03oool0oooo0:80oooo000/0?ooo`030000003oool0oooo02d0oooo00<0X23`
0?ooo`3oool06`3oool00`2P8?00oooo0?ooo`2S0?ooo`00;03oool00`000000oooo0?ooo`0^0?oo
o`030:0Pl03oool0oooo01T0oooo00<0X23`0?ooo`3oool0Y03oool002`0oooo0P00000_0?ooo`03
0:0Pl03oool0oooo01P0oooo00<0X23`0?ooo`3oool0Y@3oool002`0oooo00<000000?ooo`3oool0
;P3oool00`2P8?00oooo0?ooo`0F0?ooo`80X23`Z03oool002`0oooo00<000000?ooo`3oool0;`3o
ool00`2P8?00oooo0?ooo`0D0?ooo`030:0Pl03oool0oooo0:P0oooo000/0?ooo`030000003oool0
oooo0300oooo00<0X23`0?ooo`3oool04P3oool00`2P8?00oooo0?ooo`2Y0?ooo`00;03oool00`00
0000oooo0?ooo`0a0?ooo`030:0Pl03oool0oooo0100oooo00<0X23`0?ooo`3oool0ZP3oool002`0
oooo00<000000?ooo`3oool0<P3oool00`2P8?00oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo0:/0
oooo000/0?ooo`030000003oool0oooo03<0oooo00<0X23`0?ooo`3oool0303oool00`2P8?00oooo
0?ooo`2/0?ooo`00;03oool2000003D0oooo00<0X23`0?ooo`3oool02@3oool20:0Pl:l0oooo000/
0?ooo`030000003oool0oooo03D0oooo0`2P8?060?ooo`80X23`/@3oool002`0oooo00<000000?oo
o`3oool0=`3oool70:0Pl;<0oooo000/0?ooo`030000003oool0oooo0?40oooo000/0?ooo`030000
003oool0oooo0?40oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0l@3o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0l@3oool000050?ooo`000000oooo
0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0l@3oool000050?ooo`000000oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo0`00003a0?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0m`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`800000n@3oool00080oooo0P00000:0?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`3g0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.80871, -1.31967*^-6, \
0.0847289, 6.85471*^-8}}]
}, Open  ]],

Cell["This is the genealogy inferred from S:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = 
        MatrixToGenealogy[S, {a, b, c, d, e}, 
          Range[11]];\)\), "\[IndentingNewLine]", 
    \(Show[PlotGenealogy[g]]; g\)}], "Input",
  CellLabel->"In[256]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[256]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[BoxData[
    \(Node[
      1, {0, {}}, {Node[
          2, {0, {1, 2}}, {Node[a, {0, {1, 2, 8}}, {}], 
            Node[b, {0, {1, 2}}, {}]}], 
        Node[3, {0, {3, 4, 5, 6, 7}}, {Node[c, {0, {3, 4, 5, 6, 7, 9}}, {}], 
            Node[4, {0, {3, 4, 5, 6, 7, 10}}, {Node[
                  d, {0, {3, 4, 5, 6, 7, 10}}, {}], 
                Node[e, {0, {3, 4, 5, 6, 7, 10, 11}}, {}]}]}]}]\)], "Output",
  CellLabel->"Out[257]="]
}, Open  ]],

Cell["\<\
All possibilities have the same topology.  They  differ only in the \
location of the root, and the distribution of mutations around the root.  In \
this example, the least likely rootings have a differnt position of the root:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = 
        MatrixToGenealogy[
          SwapStates[pr\[LeftDoubleBracket]34\[RightDoubleBracket], S], {a, 
            b, c, d, e}, Range[11]];\)\), "\[IndentingNewLine]", 
    \(Show[PlotGenealogy[g]]; g\)}], "Input",
  CellLabel->"In[260]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .51503 m
.41667 .41202 L
s
.5 .51503 m
.83333 .10301 L
s
.25 .20601 m
.16667 .10301 L
s
.25 .20601 m
.33333 .10301 L
s
.33333 .30902 m
.25 .20601 L
s
.33333 .30902 m
.5 .10301 L
s
.41667 .41202 m
.33333 .30902 L
s
.41667 .41202 m
.66667 .10301 L
s
[(1)] .46667 .53563 0 0 Mshowa
[(2)] .21667 .22661 0 0 Mshowa
[(3)] .3 .32962 0 0 Mshowa
[(4)] .38333 .43262 0 0 Mshowa
gsave
.16667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[260]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo
000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00340oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo0340oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0<P3oool003<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0c0?ooo`00=03o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03<0oooo000e0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0e0?ooo`00=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03H0
oooo000g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0=`3oool003P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0g0?ooo`00>@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0>@3oool003X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0j0?ooo`00
>`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03/0oooo000l0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0l0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
03d0oooo000n0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0?P3oool003l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0o0?ooo`00@03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0@03oool00440oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`110?oo
o`00@P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0480oooo00130?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0@`3oool004@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`140?ooo`00A03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo04@0oooo00150?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0A@3oool004H0oooo00<000000?oo
o`000000;`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0AP3oool004L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0A`3oool004L0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
B03oool004P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0B03oool003/0oooo1@0000090?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo04T0oooo000l0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0BP3oool0
03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1;0?ooo`00?P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo04`0oooo000k0?ooo`050000003oool0oooo0?ooo`00
0000303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`1<0?ooo`00>`3oool01@000000oooo0?ooo`3oool0000000d0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0C@3oool003`0oooo0`00000?0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04h0oooo
001?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0500oooo001A0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0500oooo001A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0540oooo001B0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0580oooo001C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05<0oooo001D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo05@0oooo001E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo05@0oooo001E0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05D0
oooo001F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo05H0oooo001G0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05L0oooo001H
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo05P0oooo001I0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05P0oooo001J0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo05T0oooo001J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05X0oooo001K0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo05/0oooo001L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05`0oooo001M0?ooo`050000003oool0oooo
0?ooo`000000;`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05`0oooo001N0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1M0?oo
o`00G`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo05l0oooo001P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`1P0?ooo`00E03oool3000000X0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0640oooo001C0?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0H@3oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0HP3oool005D0oooo0P00000<0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1S0?ooo`00
E`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`1T0?ooo`00D`3oool01@000000oooo0?ooo`3oool0000000d0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06D0oooo
001D0?ooo`<000003`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0I@3oool006L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo06H0oooo001W0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`1W0?ooo`00J03oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0J03oool006T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06T0oooo001Z0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1Y0?ooo`00J`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0JP3oool0
06/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
06/0oooo001/0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`1/0?ooo`00K@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0K@3oool006h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo06d0oooo001_0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`1^0?ooo`00K`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0K`3oool00700oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0700oooo001a0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1a0?ooo`00LP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0L@3o
ool007<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0780oooo001c0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1c0?ooo`00M03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0M03oool007D0oooo00D000000?ooo`3oool0oooo0000000^0?ooo`03
0000003oool0oooo07D0oooo001f0?ooo`030000003oool0000002l0oooo00<000000?ooo`3oool0
M@3oool007L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1f0?ooo`00M`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo07L0oooo001h0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0N03oool006d0oooo0`0000090?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0N@3oool006h0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo07T0oooo001[0?ooo`D000002`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo07X0oooo001[0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1k0?ooo`00K03oool00`000000oooo0000000=
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0O03oool006d0oooo0P00000>0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0O@3oool006h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07d0oooo001o0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0OP3oool00800oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1o0?ooo`00P@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0800oooo00210?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0P@3oool00880
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`220?ooo`00P`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0880oooo00240?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0P`3oool008D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`24
0?ooo`00Q@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo08D0oooo00260?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0QP3oool008L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`260?ooo`00R03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo08L0oooo00290?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0R03oool0
08X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`290?ooo`00RP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08X0oooo002;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0RP3oool008`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`2;0?ooo`00S@3oool01@000000oooo0?ooo`3oool0000008h0oooo002>0?ooo`030000003oool0
000008l0oooo002?0?ooo`030000003oool0oooo08h0oooo003o0?ooob40oooo003o0?ooob40oooo
00230?ooo`<00000VP3oool008@0oooo00<000000?ooo`3oool0V@3oool008@0oooo00<000000?oo
o`3oool0V@3oool008@0oooo00<000000?ooo`3oool0V@3oool008@0oooo00<000000?ooo`3oool0
V@3oool008<0oooo0P00002K0?ooo`00Q03oool00`000000oooo0?ooo`2I0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0339103}}],

Cell[BoxData[
    \(Node[
      1, {0, {}}, {Node[
          4, {0, {11}}, {Node[
              3, {0, {10, 11}}, {Node[
                  2, {0, {1, 2, 3, 4, 5, 6, 7, 10, 11}}, {Node[
                      a, {0, {1, 2, 3, 4, 5, 6, 7, 8, 10, 11}}, {}], 
                    Node[b, {0, {1, 2, 3, 4, 5, 6, 7, 10, 11}}, {}]}], 
                Node[c, {0, {9, 10, 11}}, {}]}], Node[d, {0, {11}}, {}]}], 
        Node[e, {0, {}}, {}]}]\)], "Output",
  CellLabel->"Out[261]="]
}, Open  ]],

Cell["\<\
In this example, the only possible rootings all give the same \
topology, and (sometimes) a different root:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\((g = 
              MatrixToGenealogy[
                SwapStates[pr\[LeftDoubleBracket]#\[RightDoubleBracket], 
                  S], {a, b, c, d, e}, Range[11]]; \[IndentingNewLine]Show[
              PlotGenealogy[g]])\) &\) /@ {1, 2, 4, 8, 16, 32, 33, 34, 35, 
          36, 100, 101};\)\)], "Input",
  CellLabel->"In[262]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.154508 0.154508 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .46353 m
.25 .30902 L
s
.5 .46353 m
.5 .15451 L
s
.5 .46353 m
.75 .30902 L
s
.25 .30902 m
.16667 .15451 L
s
.25 .30902 m
.33333 .15451 L
s
.75 .30902 m
.66667 .15451 L
s
.75 .30902 m
.83333 .15451 L
s
[(1)] .46667 .49443 0 0 Mshowa
[(2)] .21667 .33992 0 0 Mshowa
[(3)] .71667 .33992 0 0 Mshowa
gsave
.16667 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000
;@3oool4000002/0oooo0`00000a0?ooo`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000
003oool0oooo000002/0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo
000002/0oooo00<000000?ooo`3oool0<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo
000002/0oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03o
ool002d0oooo00@000000?ooo`3oool00000;03oool010000000oooo0?ooo`00000[0?ooo`050000
003oool0oooo0?ooo`000000:`3oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo
0?ooo`000000<03oool002h0oooo0P00000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?oo
o`<00000<@3oool005d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00
G03oool200000600oooo0P00001P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo
000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00340oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0300oooo000b0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0<@3oool00380oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0a0?ooo`00<`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000c0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0<P3oool003@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0c0?ooo`00=03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03<0
oooo000e0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0=03oool003D0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo03D0oooo000g0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0=P3oool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00
>03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
03P0oooo000j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>@3oool003X0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`00>`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo03X0oooo000k0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0>P3oool003`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0k0?oo
o`00?03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03/0oooo000m0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0?03oool003d0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0l0?ooo`00?P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo03d0oooo000n0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?@3oool003l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo03h0oooo00100?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0?`3oool00400oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0o
0?ooo`00@@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00120?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0@@3oool00480oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`110?ooo`00@`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0480oooo00130?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool0
04@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`130?ooo`00A03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo04<0oooo00150?ooo`050000003oool0oooo0?ooo`00
0000A@3oool00`000000oooo0?ooo`130?ooo`050000003oool0oooo0?ooo`000000AP3oool004D0
oooo00D000000?ooo`3oool0oooo000000150?ooo`030000003oool0oooo04<0oooo00D000000?oo
o`3oool0oooo000000160?ooo`00AP3oool00`000000oooo000000160?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`000000A`3oool004H0oooo00<000000?ooo`000000AP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0000004L0oooo00170?ooo`800000AP3oool00`000000oooo
0?ooo`140?ooo`800000B03oool004T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo04P0oooo001:0?ooo`800000@`3oool00`000000oooo0?ooo`11
0?ooo`800000B`3oool004`0oooo0P0000110?ooo`030000003oool0oooo03l0oooo0P00001=0?oo
o`00CP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0C@3oool004l0oooo0P00000n0?ooo`030000003oool0oooo03`0oooo0P00001@0?ooo`00>`3o
ool500000140oooo0P00000l0?ooo`030000003oool0oooo03T0oooo0`00001B0?ooo`00?03oool0
10000000oooo0?ooo`00000C0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03o
ool200000080oooo00<000000?ooo`3oool0C`3oool003d0oooo00<000000?ooo`3oool0503oool2
000003T0oooo00<000000?ooo`3oool0=`3oool2000000<0oooo00<000000?ooo`3oool0C`3oool0
03h0oooo00<000000?ooo`3oool05@3oool2000003L0oooo00<000000?ooo`3oool0=@3oool20000
00<0oooo0P00001B0?ooo`00>`3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0C`3oool003/0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`800000=03oool00`00
0000oooo0?ooo`0b0?ooo`800000103oool01@000000oooo0?ooo`3oool000000540oooo000l0?oo
o`<00000703oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool01@3oool300000580oooo001L0?ooo`800000<@3oool00`000000oooo0?ooo`0_0?ooo`80
0000G@3oool005h0oooo0P00000_0?ooo`030000003oool0oooo02d0oooo0P00001O0?ooo`00H03o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G`3o
ool00640oooo0P00000/0?ooo`030000003oool0oooo02X0oooo0P00001R0?ooo`00H`3oool20000
02X0oooo00<000000?ooo`3oool0:03oool2000006@0oooo001U0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1T0?ooo`00IP3oool2000002L0oooo
00<000000?ooo`3oool09@3oool2000006L0oooo001X0?ooo`8000009@3oool00`000000oooo0?oo
o`0S0?ooo`800000J@3oool006X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo06T0oooo001[0?ooo`8000008P3oool00`000000oooo0?ooo`0P0?oo
o`800000K03oool006d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo06`0oooo001^0?ooo`8000007`3oool00`000000oooo0?ooo`0M0?ooo`800000
K`3oool00700oooo0P00000M0?ooo`030000003oool0oooo01/0oooo0P00001a0?ooo`00LP3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0L@3oool0
07<0oooo0P00000J0?ooo`030000003oool0oooo01P0oooo0P00001d0?ooo`00M@3oool2000001P0
oooo00<000000?ooo`3oool05P3oool2000007H0oooo001g0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1f0?ooo`00N03oool2000001D0oooo00<0
00000?ooo`3oool04`3oool2000007T0oooo001j0?ooo`8000004`3oool00`000000oooo0?ooo`0A
0?ooo`800000N`3oool007`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo07/0oooo001m0?ooo`800000403oool00`000000oooo0?ooo`0>0?ooo`80
0000OP3oool007l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo07h0oooo00200?ooo`8000003@3oool00`000000oooo0?ooo`0;0?ooo`800000P@3o
ool00880oooo0P00000;0?ooo`030000003oool0oooo00T0oooo0P0000230?ooo`00Q03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P`3oool008D0
oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P0000260?ooo`00Q`3oool2000000H0oooo
00<000000?ooo`3oool0103oool2000008P0oooo00290?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`280?ooo`00RP3oool2000000<0oooo00@00000
0?ooo`3oool0oooo0P00002;0?ooo`00S03oool2000000030?ooo`000000oooo00800000S@3oool0
08h0oooo0`00002?0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P`3o
ool3000009X0oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo
09T0oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo
00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3oool0V@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00002, \
0.0209577, 0.022607}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.33333 .37082 L
s
.5 .49443 m
.66667 .12361 L
s
.5 .49443 m
.83333 .12361 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.33333 .37082 m
.25 .24721 L
s
.33333 .37082 m
.5 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .3 .39554 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0<P3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0c0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03@0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=@3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo03L0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0>03o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0h0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo03T0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0>P3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0k0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03`0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0?@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0n0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo03l0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
@03oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`100?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0440oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0@P3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`130?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04@0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0A@3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`160?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo04L0oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0B03oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`190?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04T0oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0BP3oool004D0oooo00D000000?ooo`3oool0oooo0000000`
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1;
0?ooo`00A@3oool01@000000oooo0?ooo`3oool0000002l0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04`0oooo00160?ooo`030000003oool00000
02l0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
04d0oooo00170?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo00170?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04l0oooo
00180?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0500oooo00190?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0540oooo00190?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0580oooo000k0?ooo`D000002P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`00
?03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0oooo000m0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0E03oool003h0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1E0?ooo`00>`3oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0EP3oool003/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo05L0oooo000l0?ooo`<000003`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1H0?ooo`00C`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1I0?ooo`00C`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1J0?ooo`00D03oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1J0?ooo`00D@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1K0?ooo`00D@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1L
0?ooo`00DP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`1M0?ooo`00D`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1N0?ooo`00
D`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1O0?ooo`00E03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1P0?ooo`00E@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`1Q0?ooo`00E@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1R0?ooo`00EP3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1S0?ooo`00E`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00E`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1T0?ooo`00F03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1U0?ooo`00F@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1V0?oo
o`00F@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`1W0?ooo`00FP3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1X0?ooo`00F`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1Y0?ooo`00F`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1Z0?ooo`00G03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1[0?ooo`00G@3oool01@000000oooo0?ooo`3oool0000003h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1[0?ooo`00G@3oool01@000000oooo0?ooo`3oool00000
03h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1/0?ooo`00GP3oool00`000000
oooo0000000o0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0K@3oool005l0oooo
0P00000n0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0KP3oool00640oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06l0oooo001R
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1`
0?ooo`00H`3oool2000003T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1a0?oo
o`00E03oool3000000h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0780oooo001C0?ooo`050000003oool0oooo0?ooo`0000003P3oool2000003D0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1c0?ooo`00E`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1d0?ooo`00E@3oool200000180oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo07@0oooo001G0?ooo`030000003oool0oooo0100oooo0P00000_
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0M@3oool005<0oooo00D000000?oo
o`3oool0oooo0000000D0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1f0?ooo`00E03oool3000001H0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo07L0oooo001^0?ooo`800000:P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo07P0oooo001`0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1i0?ooo`00L@3oool2000002H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1j0?ooo`00L`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0N`3oool007@0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07`0oooo001e0?ooo`80
00008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07d0oooo001g0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1m0?ooo`00N03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0OP3o
ool007T0oooo0P00000K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0O`3oool0
07/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0800oooo001l0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`210?ooo`00O@3oool2000001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`220?ooo`00O`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0P`3oool00800oooo0P00000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0Q03oool00880oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0
000008L0oooo00230?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`250?ooo`00Q03oool2000000d0oooo00D000000?ooo`3oool0oooo000000280?oo
o`00QP3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000R@3oool008L0
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00002:0?ooo`00R03oool2000000L0
oooo00@000000?ooo`3oool00000R`3oool008X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0000002<0?ooo`00R`3oool2000000@0oooo0P00002=0?ooo`00S@3oool00`000000oooo0?oo
o`02000008h0oooo002>0?ooo`030000003oool0000008l0oooo002?0?ooo`030000003oool0oooo
08h0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00230?oo
o`<00000VP3oool008@0oooo00<000000?ooo`3oool0V@3oool008@0oooo00<000000?ooo`3oool0
V@3oool008@0oooo00<000000?ooo`3oool0V@3oool008@0oooo00<000000?ooo`3oool0V@3oool0
08<0oooo0P00002K0?ooo`00Q03oool00`000000oooo0?ooo`2I0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .51503 m
.41667 .41202 L
s
.5 .51503 m
.83333 .10301 L
s
.25 .20601 m
.16667 .10301 L
s
.25 .20601 m
.33333 .10301 L
s
.33333 .30902 m
.25 .20601 L
s
.33333 .30902 m
.5 .10301 L
s
.41667 .41202 m
.33333 .30902 L
s
.41667 .41202 m
.66667 .10301 L
s
[(1)] .46667 .53563 0 0 Mshowa
[(2)] .21667 .22661 0 0 Mshowa
[(3)] .3 .32962 0 0 Mshowa
[(4)] .38333 .43262 0 0 Mshowa
gsave
.16667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo
000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00340oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo0340oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0<P3oool003<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0c0?ooo`00=03o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03<0oooo000e0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0e0?ooo`00=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03H0
oooo000g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0=`3oool003P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0g0?ooo`00>@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0>@3oool003X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0j0?ooo`00
>`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03/0oooo000l0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0l0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
03d0oooo000n0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0?P3oool003l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0o0?ooo`00@03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0@03oool00440oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`110?oo
o`00@P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0480oooo00130?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0@`3oool004@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`140?ooo`00A03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo04@0oooo00150?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0A@3oool004H0oooo00<000000?oo
o`000000;`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0AP3oool004L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0A`3oool004L0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
B03oool004P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0B03oool003/0oooo1@0000090?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo04T0oooo000l0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0BP3oool0
03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1;0?ooo`00?P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo04`0oooo000k0?ooo`050000003oool0oooo0?ooo`00
0000303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`1<0?ooo`00>`3oool01@000000oooo0?ooo`3oool0000000d0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0C@3oool003`0oooo0`00000?0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04h0oooo
001?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0500oooo001A0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0500oooo001A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0540oooo001B0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0580oooo001C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05<0oooo001D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo05@0oooo001E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo05@0oooo001E0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05D0
oooo001F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo05H0oooo001G0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05L0oooo001H
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo05P0oooo001I0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05P0oooo001J0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo05T0oooo001J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05X0oooo001K0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo05/0oooo001L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05`0oooo001M0?ooo`050000003oool0oooo
0?ooo`000000;`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05`0oooo001N0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1M0?oo
o`00G`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0GP3oool005l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo05l0oooo001P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`1P0?ooo`00E03oool3000000X0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0640oooo001C0?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0H@3oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0HP3oool005D0oooo0P00000<0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1S0?ooo`00
E`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`1T0?ooo`00D`3oool01@000000oooo0?ooo`3oool0000000d0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06D0oooo
001D0?ooo`<000003`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0I@3oool006L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo06H0oooo001W0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`1W0?ooo`00J03oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0J03oool006T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06T0oooo001Z0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1Y0?ooo`00J`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0JP3oool0
06/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
06/0oooo001/0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`1/0?ooo`00K@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0K@3oool006h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo06d0oooo001_0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`1^0?ooo`00K`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0K`3oool00700oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0700oooo001a0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1a0?ooo`00LP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0L@3o
ool007<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0780oooo001c0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1c0?ooo`00M03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0M03oool007D0oooo00D000000?ooo`3oool0oooo0000000^0?ooo`03
0000003oool0oooo07D0oooo001f0?ooo`030000003oool0000002l0oooo00<000000?ooo`3oool0
M@3oool007L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1f0?ooo`00M`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo07L0oooo001h0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0N03oool006d0oooo0`0000090?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0N@3oool006h0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo07T0oooo001[0?ooo`D000002`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo07X0oooo001[0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1k0?ooo`00K03oool00`000000oooo0000000=
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0O03oool006d0oooo0P00000>0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0O@3oool006h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07d0oooo001o0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0OP3oool00800oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1o0?ooo`00P@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0800oooo00210?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0P@3oool00880
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`220?ooo`00P`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0880oooo00240?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0P`3oool008D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`24
0?ooo`00Q@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo08D0oooo00260?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0QP3oool008L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`260?ooo`00R03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo08L0oooo00290?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0R03oool0
08X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`290?ooo`00RP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08X0oooo002;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0RP3oool008`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`2;0?ooo`00S@3oool01@000000oooo0?ooo`3oool0000008h0oooo002>0?ooo`030000003oool0
000008l0oooo002?0?ooo`030000003oool0oooo08h0oooo003o0?ooob40oooo003o0?ooob40oooo
00230?ooo`<00000VP3oool008@0oooo00<000000?ooo`3oool0V@3oool008@0oooo00<000000?oo
o`3oool0V@3oool008@0oooo00<000000?ooo`3oool0V@3oool008@0oooo00<000000?ooo`3oool0
V@3oool008<0oooo0P00002K0?ooo`00Q03oool00`000000oooo0?ooo`2I0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0339103}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.41667 .37082 L
s
.5 .49443 m
.83333 .12361 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.41667 .37082 m
.25 .24721 L
s
.41667 .37082 m
.58333 .24721 L
s
.58333 .24721 m
.5 .12361 L
s
.58333 .24721 m
.66667 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .38333 .39554 0 0 Mshowa
[(4)] .55 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`@00000;03oool3000002`0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00@00000
0?ooo`3oool00000;03oool00`000000oooo0?ooo`0/0?ooo`050000003oool0oooo0?ooo`000000
<03oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool0
0000;03oool5000002X0oooo00<000000?ooo`3oool0<P3oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`040000003oool0oooo000002`0oooo00D00000
0?ooo`3oool0oooo0000000Z0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`2>0?ooo`00G03oool200000300oooo0P00002@0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0<P3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0c0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03@0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0=@3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo03L0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0>03o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0h0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo03T0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0>P3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0k0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03`0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0?@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0n0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo03l0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
@03oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`100?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0440oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0@P3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`130?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04@0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0A@3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`160?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo04L0oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0B03oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`190?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04T0oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0BP3oool004D0oooo00D000000?ooo`3oool0oooo0000001K
0?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo0?ooo`1;0?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000W0?ooo`030000
003oool0oooo04`0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`0000009`3o
ool00`000000oooo0?ooo`1=0?ooo`00A`3oool2000005d0oooo0P00000W0?ooo`030000003oool0
oooo04h0oooo00190?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1?0?ooo`00BP3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0D03oool004/0oooo0P00001E0?ooo`800000:03oool00`000000oooo
0?ooo`1A0?ooo`00C@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0DP3oool003/0oooo1@00000>0?ooo`030000003oool0oooo04/0oooo0`000000
0`3oool000000?ooo`0Y0?ooo`030000003oool0oooo0580oooo000l0?ooo`040000003oool0oooo
000000l0oooo0P00001<0?ooo`<00000:P3oool00`000000oooo0?ooo`1C0?ooo`00?@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo04H0oooo1@00000Z0?ooo`030000003oool0oooo
05@0oooo000n0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A@3oool010000000
oooo00000000000Z0?ooo`030000003oool0oooo05D0oooo000k0?ooo`050000003oool0oooo0?oo
o`0000004`3oool2000004D0oooo0P0000000`3oool000000?ooo`0X0?ooo`030000003oool0oooo
05H0oooo000k0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00800000:03oool00`000000oooo0?ooo`1G0?ooo`00?03oool3000001L0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0F03oool005L0oooo0P00000m0?ooo`800000;03oool00`000000oooo
0?ooo`1I0?ooo`00F@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0FP3oool005X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo05X0oooo001K0?ooo`800000=@3oool2000002h0oooo00<000000?oo
o`3oool0F`3oool005d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo05`0oooo001N0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`1M0?ooo`00G`3oool2000002d0oooo0P00000_0?ooo`030000003o
ool0oooo05h0oooo001Q0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`1O0?ooo`00HP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0H03oool006<0oooo0P00000U0?ooo`800000<03oool00`000000
oooo0?ooo`1Q0?ooo`00I@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0HP3oool006H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo06<0oooo001W0?ooo`8000007@3oool200000380oooo00<00000
0?ooo`3oool0H`3oool006T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo06@0oooo001Z0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`1U0?ooo`00J`3oool2000001D0oooo0P00000c0?ooo`030000
003oool0oooo06H0oooo001]0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`1W0?ooo`00KP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0J03oool006l0oooo0P00000=0?ooo`800000=03oool00`00
0000oooo0?ooo`1Y0?ooo`00L@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0JP3oool00780oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo06/0oooo001c0?ooo`8000001@3oool2000003H0oooo00<0
00000?ooo`3oool0J`3oool007D0oooo00D000000?ooo`3oool0oooo0000000g0?ooo`030000003o
ool0oooo06`0oooo001f0?ooo`030000003oool0000003L0oooo00<000000?ooo`3oool0K@3oool0
07L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1^0?ooo`00M`3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo06l0oooo001h0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool0L03oool007T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`1a0?ooo`00K03oool3000000X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1b
0?ooo`00J`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`1c0?ooo`00K`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0M03oool006d0oooo0P00000<0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0M03oool006l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo07D0oooo001[0?ooo`050000003oool0oooo0?ooo`000000
3@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07H0oooo001/0?ooo`<000003`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07L0oooo001n0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0N03oool007l0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`1i0?ooo`00P03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo07X0
oooo00200?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0N`3oool00840oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1l0?ooo`00PP3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo07d0oooo00220?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0O@3oool008<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1n0?ooo`00
Q03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo07l0oooo00240?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0P03oool008D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0880oooo00260?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0P`3oool008L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`240?ooo`00R03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo08D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08L0oooo002;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool008/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08X0oooo002=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0R`3oool008d0
oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?0?ooo`00
S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`03
0000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3oool0V@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.16667 .12361 L
s
.5 .49443 m
.33333 .12361 L
s
.5 .49443 m
.66667 .37082 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .63333 .39554 0 0 Mshowa
[(3)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000c0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000f0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003L0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000i0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000k0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003`0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00?@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000n
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00@03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo00110?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool00440oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00@P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo00130?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool004@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00A@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00160?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool004L0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00B03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00190?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00BP3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo001;0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004`0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo00000016
0?ooo`00C@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0;@3oool01@000000oooo0?ooo`3oool0000004H0oooo001>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool00000
04L0oooo001?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo04H0oooo001@0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04H0oooo
001A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo001B0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04P0oooo001C0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo04P0oooo001C0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0N0?ooo`<000001P3oool00`000000oooo0?ooo`190?ooo`00
E03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
7@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0BP3oool005D0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1:0?ooo`00EP3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000000@0oooo00<0
00000?ooo`3oool0B`3oool005L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000CP3oool005P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo04`0oooo001I0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0J0?ooo`<000000P3oool0
0`000000oooo0?ooo`1=0?ooo`00FP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1>0?ooo`00F`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1>0?ooo`00F`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00G03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1@0?ooo`00G@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1@0?ooo`00GP3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1A0?oo
o`00G`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1B0?ooo`00H03oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1B0?ooo`00H@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1C0?ooo`00HP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1D0?ooo`00H`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1D0?ooo`00I03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00I03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1F0?ooo`00I@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1F0?ooo`00IP3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1G
0?ooo`00I`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1H0?ooo`00J03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1H0?ooo`00
J@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1I0?ooo`00JP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`00J`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1J0?ooo`00K03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00K03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo0000001N0?oo
o`00K@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3o
ool0oooo0000001N0?ooo`00KP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`000000G`3oool006l0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0l0?ooo`800000H03oool00700oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0600oooo001a0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`1Q0?ooo`00LP3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo03L0oooo0P00001T0?ooo`00L`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02h0oooo1@0000020?ooo`030000003oool0oooo06@0oooo001d0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`03000006L0oooo
001e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0000
001Y0?ooo`00M@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0J03oool007H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0/0?oo
o`<0000000<0oooo0000003oool0J03oool007L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0/0?ooo`050000003oool0oooo0?ooo`000000J@3oool007P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0[0?ooo`030000003oool0000000800000JP3oool007T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`800000K`3oool007X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo06l0oooo001k
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool200000780oooo001l0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1b0?oo
o`00O@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0L`3oool007h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`800000
MP3oool007h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo07H0oooo001o0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1g0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01T0oooo0P00001j0?ooo`00P@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0NP3oool00880oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo07/0oooo00230?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0503oool2000007h0oooo00240?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1n0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo0P0000210?ooo`00QP3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0P@3oool008H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0880oooo00270?ooo`050000003oool0oooo0?ooo`00
00003@3oool2000008D0oooo00280?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000
oooo0?ooo`250?ooo`00R@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo08H0
oooo002:0?ooo`040000003oool0oooo000000L0oooo0P0000290?ooo`00R`3oool00`000000oooo
000000060?ooo`030000003oool0oooo08T0oooo002<0?ooo`800000103oool2000008`0oooo002=
0?ooo`8000000P3oool00`000000oooo0?ooo`2<0?ooo`00SP3oool00`000000oooo0000002?0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0oooo
00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo00240?oo
o`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3oool0
V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .51503 m
.16667 .10301 L
s
.5 .51503 m
.58333 .41202 L
s
.58333 .41202 m
.33333 .10301 L
s
.58333 .41202 m
.66667 .30902 L
s
.66667 .30902 m
.5 .10301 L
s
.66667 .30902 m
.75 .20601 L
s
.75 .20601 m
.66667 .10301 L
s
.75 .20601 m
.83333 .10301 L
s
[(1)] .46667 .53563 0 0 Mshowa
[(2)] .55 .43262 0 0 Mshowa
[(3)] .63333 .32962 0 0 Mshowa
[(4)] .71667 .22661 0 0 Mshowa
gsave
.16667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[262]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo
000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00340oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0340oooo000c0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0b0?ooo`00=03o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000e0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0e0?ooo`00=`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03H0
oooo000h0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool003P0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0g0?ooo`00>@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0>@3oool003/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`00
?03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03X0oooo000l0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0l0?ooo`00?P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
03`0oooo000o0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?@3oool00400oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0n0?ooo`00@@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo03l0oooo00110?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0?`3oool00480oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`100?oo
o`00@`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0440oooo00140?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool004D0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`130?ooo`00A@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo04<0oooo00160?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0]0?ooo`050000003oool0oooo0?ooo`000000AP3oool004L0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`000000A`3oool004P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0AP3oool004T0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
AP3oool004T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0A`3oool004X0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo0`0000060?ooo`030000003oool0
oooo04P0oooo001;0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B@3oool004`0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01`0
oooo1@0000040?ooo`030000003oool0oooo04X0oooo001=0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`1;0?ooo`00CP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool06`3oool2000000<0oooo00<000000?ooo`3oool0C03oool004l0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01`0oooo00@00000
0?ooo`3oool00000C`3oool00500oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0CP3oool00540oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0C`3oool00540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0D03oool00580oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
D03oool005<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0D@3oool005@0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0DP3oool0
05D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0D`3oool005D0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005H0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0E03oool005L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E@3oool005P0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0EP3oool005T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E`3oool005T0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0F03oool005X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0F@3oool005/0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0F@3o
ool005`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0FP3oool005d0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool005d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?oo
o`000000GP3oool005h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0000005l0oooo001O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`1N0?ooo`00H03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0GP3oool00640oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05l0oooo001R0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool07`3oool3000000L0oooo00<000000?ooo`3oool0H03oool00680
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1R0?ooo`00
I03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01h0oooo0P0000050?ooo`030000
003oool0oooo0680oooo001U0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool07`3o
ool01@000000oooo0?ooo`3oool0000006D0oooo001V0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
I03oool006H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0J0?ooo`<000000P3o
ool00`000000oooo0?ooo`1U0?ooo`00I`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0IP3oool006P0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06H0oooo001Y0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1W0?ooo`00JP3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0J03oool006X0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06T0oooo001[
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1Z
0?ooo`00K03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0JP3oool006d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo06/0oooo001^0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1/0?ooo`00KP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0K@3oool006l0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06h0oooo001`0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1^0?ooo`00L@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0K`3oool00780oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0700oooo
001b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1a0?ooo`00L`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0LP3oool007@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0780oooo001e0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1c0?ooo`00MP3oool00`000000oooo0?ooo`0/0?ooo`050000
003oool0oooo0?ooo`000000MP3oool007H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0000001g0?ooo`00M`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07H0oooo001h
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0MP3oool007T0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`1g0?ooo`00NP3oool00`000000oooo0?ooo`0M0?ooo`D0
00001P3oool00`000000oooo0?ooo`1h0?ooo`00NP3oool00`000000oooo0?ooo`0N0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0N@3oool007/0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07X0oooo001l0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1k0?ooo`00O@3oool0
0`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`1k0?ooo`00OP3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`1l0?ooo`00OP3oool00`000000oooo0?ooo`0J0?ooo`<000000P3oool0
0`000000oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
07h0oooo00200?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0O`3oool00840oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`200?ooo`00PP3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0800oooo00230?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0P@3oool008<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`220?oo
o`00Q03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo08<0oooo00250?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0Q03oool008H0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`240?ooo`00Q`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo08D0oooo00270?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0QP3oool008P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`270?ooo`00R@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo08P0oooo002:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0R@3oool008/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`29
0?ooo`00R`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08X0oooo002<0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0R`3oool008d0oooo00D000000?ooo`3oool0
oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000
003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0
oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo
00<000000?ooo`3oool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0339103}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1026, 634},
WindowMargins->{{Automatic, 34}, {Automatic, 6}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SwapStates"->{
    Cell[4476, 126, 257, 5, 37, "DefinitionBox",
      CellTags->"SwapStates"]},
  "PossibleRootings"->{
    Cell[6888, 205, 259, 6, 37, "DefinitionBox",
      CellTags->"PossibleRootings"],
    Cell[8851, 279, 368, 7, 37, "DefinitionBox",
      CellTags->"PossibleRootings"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SwapStates", 436566, 11653},
  {"PossibleRootings", 436671, 11656}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 45, 0, 36, "SubsectionIcon"],
Cell[1787, 53, 550, 12, 38, "Text"],
Cell[2340, 67, 1190, 30, 67, "Text"],
Cell[3533, 99, 799, 19, 52, "Text"],
Cell[4335, 120, 46, 0, 28, "MathCaption"],
Cell[4384, 122, 89, 2, 26, "Input"],
Cell[4476, 126, 257, 5, 37, "DefinitionBox",
  CellTags->"SwapStates"],
Cell[4736, 133, 195, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4956, 141, 585, 12, 88, "Input"],
Cell[5544, 155, 62, 2, 20, "Output"]
}, Open  ]],
Cell[5621, 160, 134, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5780, 167, 132, 3, 26, "Input"],
Cell[5915, 172, 571, 13, 95, "Output"]
}, Open  ]],
Cell[6501, 188, 153, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6679, 195, 119, 3, 26, "Input"],
Cell[6801, 200, 72, 2, 20, "Output"]
}, Open  ]],
Cell[6888, 205, 259, 6, 37, "DefinitionBox",
  CellTags->"PossibleRootings"],
Cell[7150, 213, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7286, 220, 103, 2, 26, "Input"],
Cell[7392, 224, 94, 2, 20, "Output"]
}, Open  ]],
Cell[7501, 229, 179, 5, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[7705, 238, 177, 4, 26, "Input"],
Cell[7885, 244, 82, 2, 20, "Output"]
}, Open  ]],
Cell[7982, 249, 139, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8146, 256, 70, 2, 26, "Input"],
Cell[8219, 260, 332, 6, 47, "Output"]
}, Open  ]],
Cell[8566, 269, 214, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[8805, 277, 43, 0, 24, "SubsubsectionIcon"],
Cell[8851, 279, 368, 7, 37, "DefinitionBox",
  CellTags->"PossibleRootings"],
Cell[9222, 288, 200, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9447, 296, 159, 3, 26, "Input"],
Cell[9609, 301, 187, 3, 20, "Output"]
}, Open  ]],
Cell[9811, 307, 160, 4, 22, "Text"],
Cell[9974, 313, 511, 11, 37, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10522, 329, 64, 0, 24, "SubsubsectionIcon"],
Cell[10589, 331, 503, 11, 43, "MathCaption"],

Cell[CellGroupData[{
Cell[11117, 346, 165, 3, 42, "Input"],
Cell[11285, 351, 26159, 642, 184, 5984, 388, "GraphicsData", "PostScript", \
"Graphics"],
Cell[37447, 995, 516, 9, 41, "Output"]
}, Open  ]],
Cell[37978, 1007, 378, 9, 40, "Text"],
Cell[38359, 1018, 173, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[38557, 1026, 211, 4, 42, "Input"],
Cell[38771, 1032, 24785, 573, 184, 4707, 320, "GraphicsData", "PostScript", \
"Graphics"],
Cell[63559, 1607, 1002, 16, 77, "Output"]
}, Open  ]],
Cell[64576, 1626, 135, 5, 26, "Text"],

Cell[CellGroupData[{
Cell[64736, 1635, 103, 2, 26, "Input"],
Cell[64842, 1639, 139, 3, 20, "Output"]
}, Open  ]],
Cell[64996, 1645, 295, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[65316, 1654, 170, 3, 26, "Input"],
Cell[65489, 1659, 202, 4, 22, "Output"]
}, Open  ]],
Cell[65706, 1666, 265, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[65996, 1677, 142, 3, 26, "Input"],
Cell[66141, 1682, 405, 6, 20, "Output"]
}, Open  ]],
Cell[66561, 1691, 172, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[66758, 1699, 108, 2, 26, "Input"],
Cell[66869, 1703, 6229, 95, 480, "Output"]
}, Closed]],
Cell[73113, 1801, 63, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[73201, 1805, 237, 4, 48, "Input"],
Cell[73441, 1811, 46912, 1823, 184, 19787, 1483, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[120368, 3637, 61, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[120454, 3641, 197, 5, 42, "Input"],
Cell[120654, 3648, 16708, 375, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics"],
Cell[137365, 4025, 436, 9, 50, "Output"]
}, Open  ]],
Cell[137816, 4037, 259, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[138100, 4046, 269, 6, 42, "Input"],
Cell[138372, 4054, 18639, 398, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics"],
Cell[157014, 4454, 473, 10, 50, "Output"]
}, Open  ]],
Cell[157502, 4467, 138, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[157665, 4474, 356, 7, 42, "Input"],

Cell[CellGroupData[{
Cell[158046, 4485, 16708, 375, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics"],
Cell[174757, 4862, 16734, 376, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[191494, 5240, 16734, 376, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[208231, 5618, 16734, 376, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[224968, 5996, 16734, 376, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[241705, 6374, 16097, 365, 184, 3893, 208, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[257805, 6741, 18415, 393, 184, 3898, 208, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[276223, 7136, 18665, 399, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[294891, 7537, 16650, 374, 184, 3968, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[311544, 7913, 16734, 376, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[328281, 8291, 18289, 391, 184, 3902, 208, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[346573, 8684, 18630, 399, 184, 3963, 212, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

