(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     63153,       1802]*)
(*NotebookOutlinePosition[     64050,       1831]*)
(*  CellTagsIndexPosition[     64006,       1827]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(BeginPackage["\<Multilocus`DataManipulation`\>", \n\t\
{"\<Utilities`SetManipulation`\>", \n\t\t\t\
"\<Statistics`DescriptiveStatistics`\>", \
"\<Statistics`MultiDescriptiveStatistics`\>"}]\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  AspectRatioFixed->False],

Cell["\<\
I have removed the dependence on Multilocus`Multilocus` - that \
package should not be needed, but perhaps there is some unexpected \
dependence.\
\>", "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Public parts", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["\<\
HaploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible haploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
HaploidTypes[{{a,b,..},n}] lists all possible genotypes, assuming the same \
set of alleles at n loci.  HaploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}. HaploidTypes[n,SortByClass\[Rule]True] lists haplotypes \
ordered by the # of '1' alleles.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(HaploidTypes::usage = "\<HaploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists \
all possible haploid genotypes, based on the set of alleles {a1,b1,..} at \
locus 1, etc.  HaploidTypes[{{a,b,..},n}] lists all possible genotypes, \
assuming the same set of alleles at n loci.  HaploidTypes[n] assumes n loci, \
with two alleles labelled {0,1}. HaploidTypes[n,SortByClass\[Rule]True] lists \
haplotypes ordered by the # of '1' alleles.\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SortByClass is an option for HaploidTypes[] and Diploid Types[] \
which determines the order of the genotypes.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(SortByClass::usage = "\<SortByClass is an option for HaploidTypes[] and \
Diploid Types[] which determines the order of the genotypes.\>"; \)], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible diploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
DiploidTypes[{a,b,..},n] lists all possible genotypes, assuming the same set \
of alleles at n loci.  DiploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}.  DiploidTypes[n,SortByClass\[Rule]True] lists  diploid \
genotypes ordered by the # of '1' alleles.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(DiploidTypes::usage = "\<DiploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists \
all possible diploid genotypes, based on the set of alleles {a1,b1,..} at \
locus 1, etc.  DiploidTypes[{a,b,..},n] lists all possible genotypes, \
assuming the same set of alleles at n loci.  DiploidTypes[n] assumes n loci, \
with two alleles labelled {0,1}.  DiploidTypes[n,SortByClass\[Rule]True] \
lists  diploid genotypes ordered by the # of '1' alleles.\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidSubsets[S] gives all the diploid subsets based on loci \
listed in S\
\>", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\(PossibleGenotypes::usage = \
"\<PossibleGenotypes[{{a,A},{b,B},{c,c}}] lists all the diploid genotypes \
compatible with the observed genotype, {{{a,b,c},{A,B,c}},\[Ellipsis]}. The \
default is to list both {{a,b,c},{A,B,c}} and {{A,B,c},{a,b,c}}; \
ListEquivalentGenotypes->True only lists one of these two complementary \
genotypes\>"; \)\(\ \)\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["HaploidSubsets", "Subsubsection"],

Cell[BoxData[
    \(\(HaploidSubsets::usage = "\<HaploidSubsets[S] gives all the haploid \
subsets based on loci listed in S. Stores results.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DiploidSubsets", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidSubsets::usage = "\<DiploidSubsets[S] gives all the diploid \
subsets based on loci listed in S. Stores results.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ListEquivalentGenotypes is an option for PossibleGenotypes[g]; if \
true, lists both equivalent genotypes {h1,h2} and {h2,h1}\
\>", \
"Subsubsection"],

Cell["\<\
ListEquivalentGenotypes::usage=\"ListEquivalentGenotypes is an \
option for PossibleGenotypes[g]; if true, lists both equivalent genotypes \
(h1,h2} and {h2,h1}.\";\
\>", "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ObservableGenotype", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ObservableGenotype::usage\), "=", 
        "\"\<ObservableGenotype[{{a,b,\[Ellipsis]},{A,B,\[Ellipsis]}}] gives \
the diploid genotype that would be observed if \!\(\*
StyleBox[\\\"cis\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"and\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"trans\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"could\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"not\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"be\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"distinguished\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\".\\\",\\nFontSlant->\\\"Plain\\\"]\)\>\""}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Data[site] is a structure which denotes an array containing data on \
site;by default, it is a list of diploid genotypes written in the form \
{{0,0},{0,1},{1,1},..}\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Data::usage = "\<Data[site] is a structure which denotes an array \
containing data on site; by default, it is a list of diploid genotypes \
written in the form {{0,0},{0,1},{1,1},..}\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\[EmptySet] denotes missing data", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\[EmptySet]::usage = "\<\[EmptySet] denotes missing data\>"; \)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConvertData", "Subsubsection"],

Cell[BoxData[
    \(\(ConvertData::usage = "\<ConvertData[{{0,1,-1,2},\[Ellipsis]}}] \
converts data on biallelic loci into the more general form, {{{0,0},{0,1},\
\[EmptySet],{1,1}},\[Ellipsis]}.  \
ConvertData[{{0,1,-1,2},\[Ellipsis]}},{1,2,2,2,\[Ellipsis]}] allows for \
different ploidy across loci; gives  {{{0},{0,1},\[EmptySet],{1,1}},\
\[Ellipsis]}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfIndividuals", "Subsubsection"],

Cell[BoxData[
    \(NumberOfIndividuals::usage = "\<NumberOfIndividuals[site] gives the \
number of individualsin site.\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfLoci[site] gives the number of loci", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(LocusNames::usage = "\<LocusNames[site] gives the names of the loci at \
the site\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Ploidy::usage = "\<Ploidy[site] gives the ploidy of the various loci in \
the site\>"\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfGenes::usage = "\<NumberOfGenes[site] gives the number of genes \
sampled from the site, allowing for variation in ploidy\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfLoci::usage = "\<NumberOfLoci[site] gives the number of \
loci.\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SelectLoci", "Subsubsection"],

Cell[BoxData[
    \(\(SelectLoci::usage = "\<SelectLoci[newsite,oldsite,loci] names a new \
dataset which is derived as a subset of the old one. Loci can be specified by \
number ({5,1,3}, say) or by name ({'mtDNA','Adh'), say), provided that \
LocusNames[oldsite] is defined. SelectLoci[data,{5,1,3}] forms a new dataset \
which contains the chosen loci, specified by number.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SelectIndividuals[newsite,oldsite,inds] names a new dataset which \
is derived as a subset of the old one. Individuals are specified by number \
({5,1,3}, say).\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(SelectIndividuals::usage = "\<SelectIndividuals[newsite,oldsite,inds] \
names a new dataset which is derived as a subset of the old one. Individuals \
are specified by number ({5,1,3}, say).\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MissingData", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(MissingData::usage = "\<MissingData is an option for GenotypeFrequency \
and AlleleFrequencyTable that specifies that missing data,\[EmptySet], are \
interpreted as homozygous null alleles\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NullAllele", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NullAllele::usage = "\<NullAllele\[Rule]\[Nu] is anmoption for \
GenotypeFrequency and AlleleFrequencyTable which specifies that \[Nu] \
represents a null allele.  This must be listed in the allele list for the \
relevant loci, and the same symbol must be used for all loci\>"; \)], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeFrequency", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(GenotypeFrequency::usage = "\<GenotypeFrequency[d,alleleList,pList]  \
lists the diploid genotype frequency for each locus, given the allele \
frequencies p. The allele names are listed in the second argument. \
GenotypeFrequency[d,alleleList,p1,p2] allows there to be different pools for \
the two parents (as in an F1 hybrid or backcross) NullAllele\[Rule]\[Nu]  \
specifies that allele \[Nu] is a null allele; null heterozygotes appear as \
homozygotes, and null homozygotes appear as missing data.  \
MissingData\[Rule]True allows missing data to be interpreted as null \
homozygotes and used in estimation; otherwise they are ignored\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AlleleFrequency", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency::usage = \
\*"\"\<AlleleFrequency[locus,allele,alleleList,pList] gives the frequency of \
the given allele. Missing data are represented by \[EmptySet] and return a \
frequency of \[EmptySet]. \
AlleleFrequency[{\!\(a\_1\),\[Ellipsis]},alleleList,pList] lists the \
frequencies of all the alleles. (These are assumed to be at successive \
loci,so that {\!\(a\_1\),\[Ellipsis]} is a haploid genotype).\>\""; \)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyTable[site,alleles] gives a table of allele \
frequencies for the site\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyTable::usage = "\<AlleleFrequencyTable[site,alleles] \
gives a table of allele frequencies for the site.  NullAlleles\[Rule]\[Nu] \
allows for the presence of null alleles, labelled \[Nu].  The same symbol \
must be used for nulls at all loci.  MissingData->True specifies that \
\[EmptySet] is interpreted as a null homozygote.  Otherwise, missing data are \
ignored.\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividualsTable[site] gives a table of the number of \
individuals with data for each locus\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfIndividualsTable::usage = "\<NumberOfIndividualsTable[site] \
gives a table of the number of individuals with data for each locus\>"; \)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfGenesTable[site] gives a table of the number of genes with \
data for each locus\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfGenesTable::usage = "\<NumberOfGenesTable[site] gives a table \
of the number of genes with data for each locus\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ReducedData[site,alleles,Detail->True] lists the number of \
observations of each diploid type for that site, together with that type. \
ReducedData[site,alleles] just lists the counts, in the same order as \
DiploidTypes[].\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(ReducedData::usage = "\<ReducedData[site,alleles,Detail->True] lists \
the number of observations of each diploid type for that site, together with \
that type. ReducedData[site,alleles] just lists the counts, in the same order \
as DiploidTypes[].\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Detail::usage = "\<Detail is an option for ReducedData which lists \
counts and types, rather than just counts\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyMean[site,alleles] gives the mean allele frequency.  \
There must be the same number of alleles per locus.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyMean::usage = "\<AlleleFrequencyMean[site,alleles] gives \
the mean allele frequency.  There must be the same number of alleles per \
locus.\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NetCovariance[site] gives the net covariance between each locus and \
the others\
\>", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NetCovariance::usage = "\<NetCovariance[site] gives the net covariance \
between each locus and the others\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomFamily[p1,
    p2] gives a random offspring from a cross between genotypes p1, p2.\
\>", \
"Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(RandomFamily::usage = "\<RandomFamily[p] gives a haploid offspring from \
the diploid parent p.  RandomFamily[p1,p2] gives a random diploid offspring \
from a cross between diploid genotypes p1, p2.  RandomFamily[p1,p2,n] \
generates n such offspring.  Linkage\[Rule]{r12,r23,\[Ellipsis]} allows for \
linkage.  SegregationRatio\[Rule]{0.6,0.7,\[Ellipsis]} allows for a biased \
segregation at each locus; the proportion of alleles derived from the first \
genome in the diploid is given.\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(SegregationRatio\ is\ an\ option\ for\ RandomFamily\ that\ \
specifies\ the\ probability\ that\ the\ allele\ from\ the\ first\ genome\ in\ \
the\ diploid\ is\ transmitted . \ \ SegregationRatio \[Rule] {0.6, 
            0.7, \[Ellipsis]}\ specifies\ different\ ratios\ for\ each\ \
locus; \ SegregationRatio \[Rule] 1\/2, \ the\ default, \ 
      specifies\ the\ same\ ratio\ at\ all\ \(\(loci\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(SegregationRatio::usage = \*"\"\<SegregationRatio is an option for \
RandomFamily that specifies the probability that the allele from the first \
genome in the diploid is transmitted.  SegregationRatio\[Rule]{0.6,0.7,\
\[Ellipsis]} specifies different ratios for each locus.  SegregationRatio\
\[Rule]{{0.6,0.7,\[Ellipsis]},{0.8,\[Ellipsis]}} allows different ratios in \
the two parents. SegregationRatio\[Rule]\!\(1\/2\), the default, specifies \
the same ratio at all loci.\>\""; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`Linkage \[Rule] {r\_\(1, 2\), 
          r\_\(2, 3\), \[Ellipsis]}\ is\ an\ option\ for\ Gametes[]\ and\ \
GameteTable[]\ which\ specifies\ the\ recombination\ rates\ in\ each\ \
interval; \ 
    assumes\ no\ interference\ and\ a\ linear\ map . \ \ 
          The\ default\ Linkage \[Rule] 
      False\ gives\ unlinked\ \(\(loci\)\(.\)\)\)], "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Linkage::usage = \*"\"\<Linkage\[Rule]{\!\(r\_\(1, \\\\\\\ \
2\)\),\!\(r\_\(2, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(3\)\)\)\),\[Ellipsis]} \
is an option for Gametes[], GameteTable[] and RandomFamily[] which specifies \
the recombination rates in each interval; assumes no interference and a \
linear map.  The default Linkage\[Rule]False gives unlinked loci. \>\""; \)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NetRecombination[{r\_1, r\_2, 
          r\_3, \[Ellipsis]}]\ gives\ the\ net\ recombination\ rate\ across\ \
a\ linear\ genetic\ map\)], "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NetRecombination::usage = \
\*"\"\<NetRecombination[{\!\(r\_1\),\!\(r\_2\),\!\(r\_3\),\[Ellipsis]}] gives \
the net recombination rate across a linear genetic map\>\""; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ParentalGenotypes", "Subsubsection"],

Cell[BoxData[
    \(ParentalGenotypes::usage = "\<ParentalGenotypes[{{0,0,1,1,\[Ellipsis]},\
\[Ellipsis]}] returns a list of the joint parental genotypes inferred from a \
list of segregations.  Assumes two alleles per locus, with genotypes \
represented by 0,1, 2.  Missing data can be represented by \[EmptySet].\>"; \
\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeFrequencyTable", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(GenotypeFrequencyTable::usage\), "=", 
        "\"\<\!\(TraditionalForm\`GenotypeFrequencyTable\)[site,alleles] \
lists the diploid genotype frequencies, locus by locus\>\""}], ";"}]], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeProbability", "Subsubsection"],

Cell[BoxData[
    \(GenotypeProbability::usage = \*"\"\<GenotypeProbability[o,p] is the \
chance that haploid offspring o would be produced by diploid parent p. \
GenotypeProbability[o,\!\(p\_1\),\!\(p\_2\)] is the chance that diploid \
offspring o would be produced by diploid parents \!\(p\_1\),\!\(p\_2\).  \
Options Linkage and SegregationRatio can be used, as in RandomFamily[]. \
ObservableGenotype\[Rule]True sums over all full diploid offspring genotypes \
compatible with the observed genotype o. \>\""; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\"Private parts\"", "Section"],

Cell[BoxData[
    \(\(Begin["\<Multilocus`DataManipulation`Private`\>"];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \(Off[General::spell1, General::spell]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["\<\
HaploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible haploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
HaploidTypes[{{a,b,..},n}] lists all possible genotypes, assuming the same \
set of alleles at n loci.  HaploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}. HaploidTypes[n,SortByClass\[Rule]True] lists haplotypes \
ordered by the # of '1' alleles.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[HaploidTypes] = {SortByClass \[Rule] False}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(HaploidTypes[{}, ___] := {}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(HaploidTypes[g_List, opts___] := \(HaploidTypes[g, opts] = 
        If[\(SortByClass /. {opts}\) /. Options[HaploidTypes], \n\t\t\t
          Sort[HaploidTypes[g], 
            Module[{p1 = Plus @@ #1, p2 = Plus @@ #2}, 
                If[p1 < p2, True, 
                  If[p1 > p2, False, OrderedQ[{#1, #2}]]]] &], \n\t\t\t
          Flatten[Apply[Outer, Prepend[g, List]], 
            Length[g] - 1]]\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(HaploidTypes[{g_List, n_Integer}, 
        opts___] := \(HaploidTypes[{g, n}, opts] = 
        HaploidTypes[Table[g, {n}], opts]\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(HaploidTypes[n_Integer, opts___] := \(HaploidTypes[n, opts] = 
        HaploidTypes[{{0, 1}, n}, opts]\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible diploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
DiploidTypes[{a,b,..},n] lists all possible genotypes, assuming the same set \
of alleles at n loci.  DiploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}.  DiploidTypes[n,SortByClass\[Rule]True] lists  diploid \
genotypes ordered by the # of '1' alleles.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[DiploidTypes] = {SortByClass \[Rule] False}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(DiploidTypes[{}, ___] = {}; \), "\n", 
    \(DiploidTypes[{s_List}, opts___] := \(DiploidTypes[{s}, opts] = 
        If[\(SortByClass /. {opts}\) /. Options[DiploidTypes], \n\t\t\t
          Sort[DiploidTypes[{s}], 
            Module[{p1 = Plus @@ \(Plus @@ #1\), 
                  p2 = Plus @@ \(Plus @@ #2\)}, 
                If[p1 < p2, True, 
                  If[p1 > p2, False, OrderedQ[{#1, #2}]]]] &], \n\t\t\t
          Module[{fs, j, k}, \[IndentingNewLine]fs = 
              Flatten[Table[{Sort[{s\[LeftDoubleBracket]
                          j\[RightDoubleBracket], 
                        s\[LeftDoubleBracket]k\[RightDoubleBracket]}]}, {j, 
                    Length[s]}, {k, j}], 1]]]\); \), "\n", 
    \(DiploidTypes[{s_List, t__List}, 
        opts___] := \(DiploidTypes[{s, t}, opts] = \n\t\t
        If[\(SortByClass /. {opts}\) /. Options[DiploidTypes], \n\t\t\ 
          Sort[DiploidTypes[{s, t}], 
            Module[{p1 = Plus @@ \(Plus @@ #1\), 
                  p2 = Plus @@ \(Plus @@ #2\)}, 
                If[p1 < p2, True, 
                  If[p1 > p2, False, OrderedQ[{#1, #2}]]]] &], \n\t\t\t
          Flatten[Outer[Join, DiploidTypes[{s}], DiploidTypes[{t}], 1], 
            1]]\); \)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(DiploidTypes[{s_List, n_Integer}, 
        opts___] := \(DiploidTypes[s, n, opts] = \n\t\t
        DiploidTypes[Table[s, {n}], opts]\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(DiploidTypes[n_Integer, opts___] := \(DiploidTypes[n, opts] = \n\t\t
        DiploidTypes[{{0, 1}, n}, opts]\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidSubsets[S] gives all the diploid subsets based on loci \
listed in S\
\>", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(DiploidSubsets[S_List] := \(DiploidSubsets[S] = 
        HaploidSubsets[Join[S, \(\((\(#\^*\))\) &\) /@ S]]\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
HaploidSubsets[S] gives all the haploid subsets based on loci \
listed in S. Stores results\
\>", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(HaploidSubsets[S_List] := \(HaploidSubsets[S] = 
        Subsets[S, 2, Length[S]]\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PossibleGenotypes[{{a,A},{b,B},{c,c}}] lists all the diploid \
genotypes compatible with the observed genotype, {{{a,b,c},{A,B,c}},\
\[Ellipsis]}. The default is to list both {{a,b,c},{A,B,c}} and \
{{A,B,c},{a,b,c}}; ListEquivalentGenotypes->True only lists one of these two \
complementary genotypes\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[
        PossibleGenotypes] = {ListEquivalentGenotypes \[Rule] 
          True}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(PossibleGenotypes[g : {{_, _} ... }, 
        opts___Rule] := \[IndentingNewLine]Module[{ps}, \[IndentingNewLine]ps \
= \(Outer[List, ##] &\) @@ 
            Replace[g, {x_, x_} \[Rule] {x}, 1]; \[IndentingNewLine]ps = 
          Flatten[ps, 
            Depth[ps] - 
              3]; \[IndentingNewLine]ps = \({#, 
                Flatten[MapThread[TakeAway[#1, {#2}] &, {g, #}]]} &\) /@ 
            ps; \[IndentingNewLine]If[\(ListEquivalentGenotypes /. {opts}\) /. 
            Options[PossibleGenotypes], 
          ps, \((Sort /@ ps)\) // Union]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ObservableGenotype[{{a,b,\[Ellipsis]},{A,B,\[Ellipsis]}}] gives the \
diploid genotype that would be observed if cis and trans could not be \
distinguished.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ObservableGenotype[{h1_List, h2_List}] := 
        Sort /@ Transpose[{h1, h2}];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividuals[site] gives the number of individuals in the \
site\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfIndividuals[s_] := Length[Data[s]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberOfLoci[site] gives the number of loci", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfLoci[s_] := 
      If[NumberOfIndividuals[s] == 0, Indeterminate, 
        Length[\(Data[
              s]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividualsTable[site] gives a table of the number of \
individuals with data for each locus\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfIndividualsTable[
        s_] := \(Length[DeleteCases[#, \[EmptySet]]] &\) /@ 
        Transpose[Data[s]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NumberOfGenesTable[site] gives a table of the number of genes with \
data for each locus\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfGenesTable[
        s_] := \(Length[Flatten[DeleteCases[#, \[EmptySet]]]] &\) /@ 
        Transpose[Data[s]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfGenes[site] gives the number of genes sampled from the \
site, allowing for variation in ploidy\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NumberOfGenes[s_] := 
      NumberOfIndividuals[s] \((Plus @@ Ploidy[s])\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Ploidy[site] gives the ploidy of the various loci in the site\
\>", \
"Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Ploidy::baddata = "\<Data for a locus at site `1` are invalid or \
missing: `2`\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Ploidy[s_]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({pl, x}\), ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"pl", "=", 
                RowBox[{"Transpose", "[", 
                  
                  RowBox[{\(\((\(If[# === \[EmptySet], \[EmptySet], 
                              Length[#]] &\) /@ #)\) &\), "/@", 
                    TagBox[\(Data[s]\),
                      (MatrixForm[ #]&)]}], "]"}]}], ";", 
              "\[IndentingNewLine]", \(\(\((x = 
                      DeleteCases[#, \[EmptySet]] /. {a_Integer .. } \[Rule] 
                          a; If[MatchQ[x, _List], 
                      Message[Ploidy::baddata, s, x]; \[EmptySet], x])\) &\) /@ 
                pl\)}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SelectLoci[newsite,oldsite,loci] names a new dataset which is \
derived as a subset of the old one. Loci can be specified by number ({5,1,3}, \
say) or by name ({\"mtDNA\",\"Adh\"), say), provided that LocusNames[oldsite] \
is defined. SelectLoci[data,{5,1,3}] forms a new dataset which contains the \
chosen loci, specified by number.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(SelectLoci::badspec = "\<Specification `1` for loci does not match \
locus names `2` for site `3`\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(SelectLoci[ns_, os_, 
        x_] := \[IndentingNewLine]Module[{xx, \[IndentingNewLine]lns = \
\((Head[LocusNames[os]] === List)\)}, \[IndentingNewLine]\ 
        If[MatchQ[x, {___Integer}], \[IndentingNewLine]xx = 
            x, \[IndentingNewLine]xx = 
            Flatten[\(Position[LocusNames[os], \ #] &\) /@ 
                x]; \[IndentingNewLine]If[\((Length[xx] \[NotEqual] 
                  Length[x])\) || \((\(! MatchQ[
                    xx, {___Integer}]\))\), \[IndentingNewLine]Message[
              SelectLoci::badspec, x, LocusNames[os], 
              os]]]; \[IndentingNewLine]\((Data[ns] = 
            SelectLoci[Data[os], xx]; \[IndentingNewLine]If[lns, 
            LocusNames[ns] = \(LocusNames[os]\)\[LeftDoubleBracket]
                xx\[RightDoubleBracket]])\); ]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(SelectLoci[d_, x : {___Integer}] := 
      Transpose[\(Transpose[d]\)\[LeftDoubleBracket]
          x\[RightDoubleBracket]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(SelectIndividuals[ns_, os_, 
        x : {___Integer}] \
:= \[IndentingNewLine]Module[{\[IndentingNewLine]lns = \((Head[
                  LocusNames[os]] === List)\)}, \[IndentingNewLine]\ \((Data[
              ns] = \(Data[os]\)\[LeftDoubleBracket]
              x\[RightDoubleBracket]; \[IndentingNewLine]If[lns, 
            LocusNames[ns] = LocusNames[os]])\); ]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeFrequency", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Options[GenotypeFrequency] = {MissingData \[Rule] False, 
          NullAllele \[Rule] None};\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(GenotypeFrequency[l_Integer, \[EmptySet], al : {_List ... }, p1_List, 
          p2_List, 
          opts___Rule] := \[IndentingNewLine]Module[{na = \(NullAllele /. \
{opts}\) /. Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[GenotypeFrequency]}, \[IndentingNewLine]If[
            na === None, \[IndentingNewLine]\[EmptySet], \
\[IndentingNewLine]If[
              MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
                  na] \[And] 
                md, \[IndentingNewLine]AlleleFrequency[l, na, al, p1] 
                AlleleFrequency[l, na, al, 
                  p2], \[IndentingNewLine]\[EmptySet]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(GenotypeFrequency[l_Integer, {a_, a_}, al : {_List ... }, p1_List, 
          p2_List, 
          opts___Rule] := \[IndentingNewLine]Module[{na = \(NullAllele /. \
{opts}\) /. Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[GenotypeFrequency], pn1, pn2}, \[IndentingNewLine]If[
            MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
              na], \[IndentingNewLine]pn1 = AlleleFrequency[l, na, al, p1]; 
            pn2 = AlleleFrequency[l, na, al, 
                p2]; \[IndentingNewLine]\((AlleleFrequency[l, a, al, p1] 
                    AlleleFrequency[l, a, al, p2] + 
                  AlleleFrequency[l, a, al, p1] pn2 + 
                  AlleleFrequency[l, a, al, p2] pn1)\)/
              If[MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
                    na] \[And] \(! md\), 1 - pn1*pn2, 
                1], \[IndentingNewLine]AlleleFrequency[l, a, al, p1] 
              AlleleFrequency[l, a, al, p2]]];\)\), "\[IndentingNewLine]", 
    \(\(GenotypeFrequency[l_Integer, {a1_, a2_}, al : {_List ... }, p1_List, 
          p2_List, opts___Rule] := 
        Module[{na = \(NullAllele /. {opts}\) /. 
                Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[GenotypeFrequency], pn1, pn2}, \[IndentingNewLine]If[
            MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
              na], \[IndentingNewLine]pn1 = AlleleFrequency[l, na, al, p1]; 
            pn2 = AlleleFrequency[l, na, al, 
                p2]]; \[IndentingNewLine]\((AlleleFrequency[l, a1, al, p1] 
                  AlleleFrequency[l, a2, al, p2] + 
                AlleleFrequency[l, a1, al, p2] 
                  AlleleFrequency[l, a2, al, p1])\)/
            If[MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
                  na] \[And] \(! md\), 1 - pn1*pn2, 1]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[dg : {\(({_, _} | \[EmptySet])\) ... }, 
          al : {_List ... }, p1_List, p2_List, 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          GenotypeFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
              al, p1, p2, opts] &, dg];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[
          dg : {\(({_, _} | \[EmptySet])\) ... }, {as_List, n_Integer}, 
          p1_List, p2_List, opts___Rule] := \n\t\tGenotypeFrequency[dg, 
          Table[as, {n}], p1, p2, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[dg : {\(({_, _} | \[EmptySet])\) ... }, n_Integer, 
          p1_List, p2_List, opts___Rule] := \n\t
        GenotypeFrequency[dg, {{0, 1}, n}, p1, p2, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[dg : {\(({_, _} | \[EmptySet])\) ... }, as_, 
          pl_List, opts___Rule] := \n\t
        GenotypeFrequency[dg, as, pl, pl, opts];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["AlleleFrequency", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency::badAllele = "\<`1` is not an allele of locus `2`\>"; \
\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency[l_Integer, a_, al : {_List ... }, pl_List] := 
      Module[{pos = 
            Position[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
              a]}, \[IndentingNewLine]If[
          a === \[EmptySet], \[IndentingNewLine]\[EmptySet], \
\[IndentingNewLine]If[
            pos === {}, \[IndentingNewLine]Message[
              AlleleFrequency::badAllele, a, l]; 
            Indeterminate, \[IndentingNewLine]Extract[
              pl\[LeftDoubleBracket]l\[RightDoubleBracket], 
              pos\[LeftDoubleBracket]1\[RightDoubleBracket]]]]]; \)], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency[a_List, al : {_List ... }, pl_List] := 
      MapIndexed[
        AlleleFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, al, 
            pl] &, a]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency[l_Integer, a_, {as_List, n_Integer}, pl_List] := \n\t\t
      AlleleFrequency[l, a, Table[as, {n}], pl]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency[l_Integer, a_, n_Integer, pl_List] := \n\t
      AlleleFrequencyTable[l, a, {{0, 1}, n}, pl]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency[a_List, {as_List, n_Integer}, pl_List] := \n\t\t
      AlleleFrequency[a, Table[as, {n}], pl]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequency[a_List, n_Integer, pl_List] := \n\t
      AlleleFrequencyTable[a, {{0, 1}, n}, pl]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyTable[site,alleles] gives a table of allele \
frequencies for the site\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[AlleleFrequencyTable] = {NullAllele \[Rule] None, 
        MissingData \[Rule] False}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyTable::badNull = "\<Missing allele `1` is present more \
than once in allele list `2` for locus `3`\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyTable[s_, {as_List, n_Integer}, opts___Rule] := \n\t\t
      AlleleFrequencyTable[s, Table[as, {n}], opts]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyTable[s_, n_Integer, opts___Rule] := \n\t
      AlleleFrequencyTable[s, {{0, 1}, n}, opts]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[AlleleFrequencyTable] = {NullAllele \[Rule] None, 
        MissingData \[Rule] False}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyTable::badNull = "\<Missing allele `1` is present more \
than once in allele list `2` for locus `3`\>"; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyTable[s_, {as_List, n_Integer}, opts___Rule] := \n\t\t
      AlleleFrequencyTable[s, Table[as, {n}], opts]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyTable[s_, n_Integer, opts___Rule] := \n\t
      AlleleFrequencyTable[s, {{0, 1}, n}, opts]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(AlleleFrequencyTable[s_, al : {_List ... }, 
          opts___Rule] := \(AlleleFrequencyTable[s, as, opts] = 
          Module[{j, k, td = Transpose[Data[s]], pp, gt, ngt, nm, dt, homs, 
              ff, ntot = 2\ NumberOfIndividuals[s], pna, px, pl, 
              na = \(NullAllele /. {opts}\) /. Options[AlleleFrequencyTable], 
              md = \(MissingData /. {opts}\) /. 
                  Options[AlleleFrequencyTable]}, \[IndentingNewLine]ngt = 
              NumberOfGenesTable[s]; \[IndentingNewLine]pp = 
              Table[If[
                  ngt\[LeftDoubleBracket]j\[RightDoubleBracket] \[Equal] 0, 
                  Indeterminate, 
                  Count[Flatten[
                        DeleteCases[
                          td\[LeftDoubleBracket]
                            j\[RightDoubleBracket], \[EmptySet]]], 
                      al\[LeftDoubleBracket]j, k\[RightDoubleBracket]]/
                    ngt\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                  NumberOfLoci[s]}, {k, 
                  Length[al\[LeftDoubleBracket]
                      j\[RightDoubleBracket]]}]; \[IndentingNewLine]If[
              na === None, \[IndentingNewLine]pp, \[IndentingNewLine]dt = \
\(DiploidTypes[{#}] &\) /@ al; \[IndentingNewLine]gt = 
                GenotypeFrequencyTable[s, al]; \[IndentingNewLine]Table[
                np = Position[al\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    na]; \ \[IndentingNewLine]If[
                  Length[np] > 1, \[IndentingNewLine]Message[
                    AlleleFrequencyTable::badNull, na, al, j]; \ 
                  Indeterminate, 
                  If[Length[np] \[Equal] 0, 
                    pp\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    pna = np\[LeftDoubleBracket]1, 1\[RightDoubleBracket]; \ 
                    px = Delete[pp\[LeftDoubleBracket]j\[RightDoubleBracket], 
                        pna]; \ 
                    homs = Delete[\(ngt\[LeftDoubleBracket]
                                j\[RightDoubleBracket]*
                              Extract[
                                gt\[LeftDoubleBracket]
                                  j\[RightDoubleBracket], #] &\) /@ 
                          Position[
                            dt\[LeftDoubleBracket]
                              j\[RightDoubleBracket], {{a_, a_}}], 
                        pna]; \[IndentingNewLine]\ 
                    If[md, \[IndentingNewLine]nm = 
                        ntot - 
                          ngt\[LeftDoubleBracket]
                            j\[RightDoubleBracket]; \
\[IndentingNewLine]ff[{p_List, 
                            pn_}] := \[IndentingNewLine]1\/ntot\ {px*
                                ngt\[LeftDoubleBracket]
                                  j\[RightDoubleBracket] - 
                              homs*pn\/\(p + 2\ pn\), 
                            nm + homs . \(pn\/\(p + 
                                      2\ pn\)\)}, \
\[IndentingNewLine]ff[{p_List, 
                            pn_}] := \[IndentingNewLine]\((1 - pn\^2)\) {px - 
                              homs\/ngt\[LeftDoubleBracket]j\
\[RightDoubleBracket]*pn\/\(p + 2\ pn\), 
                            pn\^2\/\(1 - pn\^2\) + \(homs\/ngt\
\[LeftDoubleBracket]j\[RightDoubleBracket]\) . \(pn\/\(p + 2\ pn\)\)}]; \ 
                    pl = NestWhile[
                        ff, {px\ \((1 - 0.001)\), 
                          0.001}, \((Abs[#1\[LeftDoubleBracket]2\
\[RightDoubleBracket] - #2\[LeftDoubleBracket]2\[RightDoubleBracket]] > 
                                10\^\(-9\) \[And] \ 
                              0.999 > #2\[LeftDoubleBracket]2\
\[RightDoubleBracket] > 10\^\(-8\))\) &, 2]; \ 
                    Insert[pl\[LeftDoubleBracket]1\[RightDoubleBracket], 
                      pl\[LeftDoubleBracket]2\[RightDoubleBracket], 
                      pna]]], {j, NumberOfLoci[s]}]]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequencyTable[s_, {as_List, n_Integer}, opts___Rule] := 
        AlleleFrequencyTable[s, Table[as, {n}], opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequencyTable[s_, n_Integer, opts___Rule] := 
        AlleleFrequencyTable[s, {{0, 1}, n}, opts];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ReducedData[site,alleles,Detail->True] lists the number of \
observations of each diploid type for that site, together with that type. \
ReducedData[site,alleles] just lists the counts, in the same order as \
DiploidTypes[].\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[ReducedData] := {Detail -> False}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(ReducedData[s_, as_, opts___] := 
      Module[{dd = Data[s], dt = DiploidTypes[as]}, 
        If[\(Detail /. {opts}\) /. 
            Options[ReducedData], \n\t\t\t\({Count[dd, #], #} &\) /@ 
            dt, \n\t\t\t\(Count[dd, #] &\) /@ dt]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConvertData", "Subsubsection"],

Cell[BoxData[{
    \(ConvertData[{a__List}] := ConvertData /@ {a}; \), "\n", 
    \(ConvertData[{a___}] := \n\t{a} /. {0 \[Rule] {0, 0}, 1 \[Rule] {0, 1}, 
          2 \[Rule] {1, 1}, \(-1\) \[Rule] \[EmptySet]}; \)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(ConvertData[{a__List}, 
        pl_List] := \(ConvertData[#, pl] &\) /@ {a}; \), "\n", 
    \(ConvertData[{a___}, pl_List] := 
      Module[{j}, \n\t
        Table[If[
            pl\[LeftDoubleBracket]j\[RightDoubleBracket] == 
              2, \n\t\t\t\t{a}\[LeftDoubleBracket]
                j\[RightDoubleBracket] /. {0 \[Rule] {0, 0}, 
                1 \[Rule] {0, 1}, 
                2 \[Rule] {1, 
                    1}, \(-1\) \[Rule] \[EmptySet]}, \n\t\t\t\t{a}\
\[LeftDoubleBracket]j\[RightDoubleBracket] /. {0 \[Rule] {0}, 
                1 \[Rule] {1}}], {j, Length[{a}]}]]; \)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyMean[site,alleles] gives the mean allele frequency.  \
There must be the same number of alleles per locus.\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(AlleleFrequencyMean[s_, as_] := 
      If[NumberOfIndividuals[s] == 0, 
        Indeterminate, \(\((# . NumberOfGenesTable[s])\) &\) /@ 
            Transpose[AlleleFrequencyTable[s, as]]/
          Plus @@ NumberOfGenesTable[s]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NetCovariance[site] gives the net covariance between each locus and \
the others\
\>", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(NetCovariance[s_] := 
      Module[{i, j, k, ss, dsdt, ds, sds, ff}, \n\t
        ds = \((Data[
                s] /. {{i_?NumberQ, j_?NumberQ} :> i + j, {i_?NumberQ} :> 
                  i, \[EmptySet] \[Rule] 0})\)\t; \n\tsds = Plus @@ ds; \n\t
        dsdt = Table[
            If[\(NumberOfGenesTable[s]\)\[LeftDoubleBracket]
                  j\[RightDoubleBracket] == 0, Indeterminate, 
              sds\[LeftDoubleBracket]j\[RightDoubleBracket]\/\(\
NumberOfGenesTable[s]\)\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
              NumberOfLoci[s]}]; \n\tff = \(\((# - dsdt)\) &\) /@ ds; \n\t
        Table[\((ss = 0; 
            Sum[If[\((\(Data[s]\)\[LeftDoubleBracket]i, 
                          j\[RightDoubleBracket] === \[EmptySet])\) || \
\((\(Data[s]\)\[LeftDoubleBracket]i, 
                          k\[RightDoubleBracket] === \[EmptySet])\), 0, 
                  ss += 1; 
                  ff\[LeftDoubleBracket]i, j\[RightDoubleBracket] 
                    ff\[LeftDoubleBracket]i, k\[RightDoubleBracket]], {i, 
                  NumberOfIndividuals[s]}]/ss)\), {k, NumberOfLoci[s]}, {j, 
            NumberOfLoci[s]}]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomFamily[p1,
    p2] gives a random offspring from a cross between genotypes p1, p2.\
\>", \
"Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[RandomFamily] = {Linkage \[Rule] False, 
        SegregationRatio \[Rule] False}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(RandomFamily[p__List, n_Integer, opts___Rule]\  := 
      Table[RandomFamily[p, opts], {n}]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(RandomFamily[p1_List, p2_List]\  := {RandomFamily[p1], 
        RandomFamily[p2]}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(RandomFamily[p1_List, p2_List, 
        opts__Rule]\  := {RandomFamily[p1, 
          opts /. {\((Linkage \[Rule] {x_List, 
                      y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                    x)\), \((SegregationRatio \[Rule] {x_List, 
                      y_List})\) \[RuleDelayed] \((SegregationRatio \[Rule] 
                    x)\)}], \[IndentingNewLine]RandomFamily[p2, 
          opts /. {\((Linkage \[Rule] {x_List, 
                      y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                    y)\), \((SegregationRatio \[Rule] {x_List, 
                      y_List})\) \[RuleDelayed] \((SegregationRatio \[Rule] 
                    y)\)}]}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(RandomFamily[{h1_List, h2_List}, 
          opts___Rule]\  := \[IndentingNewLine]Module[{\[IndentingNewLine]rl \
= \(Linkage /. {opts}\) /. Options[RandomFamily], 
            sr = \(SegregationRatio /. {opts}\) /. 
                Options[RandomFamily], \[IndentingNewLine]x, y, 
            tss = Transpose[{h1, h2}], j}, \[IndentingNewLine]If[
            rl === False, \[IndentingNewLine]If[sr === False, 
              sr = Table[
                  1\/2, {Length[
                      h1]}]]; \[IndentingNewLine]MapThread[\((#1\
\[LeftDoubleBracket]If[Random[] < #2, 1, 
                      2]\[RightDoubleBracket])\) &, {Transpose[{h1, h2}], 
                sr}], \[IndentingNewLine]x = Random[Integer, {1, 2}]; 
            y = {tss\[LeftDoubleBracket]1, 
                  x\[RightDoubleBracket]}; \[IndentingNewLine]Do[
              If[Random[] < rl\[LeftDoubleBracket]j\[RightDoubleBracket], 
                x = If[x \[Equal] 1, 2, 1]]; 
              AppendTo[y, 
                tss\[LeftDoubleBracket]j + 1, x\[RightDoubleBracket]], {j, 
                Length[rl]}]; y]];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(GenotypeProbability[o, 
          p]\ is\ the\ chance\ that\ haploid\ offspring\ o\ would\ be\ \
produced\ by\ diploid\ parent\ p . \ 
          GenotypeProbability[o, p\_1, 
            p\_2]\ is\ the\ chance\ that\ diploid\ offspring\ o\ would\ be\ \
produced\ by\ diploid\ parents\ p\_1, \(\(p\_2\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Options[GenotypeProbability] = {Linkage \[Rule] False, 
        SegregationRatio \[Rule] False, 
        ObservableGenotype \[Rule] False}; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(GenotypeProbability[o_List, {h1_List, h2_List}, 
          opts___Rule] := \[IndentingNewLine]Module[{\[IndentingNewLine]rl = \
\(Linkage /. {opts}\) /. Options[GenotypeProbability], 
            sr = \(SegregationRatio /. {opts}\) /. 
                Options[GenotypeProbability], z, rr, 
            xx}, \[IndentingNewLine]If[
            rl === False, \[IndentingNewLine]If[sr === False, 
              sr = Table[1\/2, {Length[h1]}]]; \[IndentingNewLine]Times @@ 
              MapThread[\((Plus @@ \((Position[#2, #1] /. {{1} \[Rule] #3, \
{2} \[Rule] 1 - #3})\))\) &, {o, {h1, h2} // Transpose, 
                  sr}], \[IndentingNewLine]z = 
              Transpose[{Transpose[{h1, h2}], o, 
                  Append[rl, \[Pi]]}]; \[IndentingNewLine]If[
              And @@ \((\(MemberQ[#\[LeftDoubleBracket]1\[RightDoubleBracket],\
 #\[LeftDoubleBracket]2\[RightDoubleBracket]] &\) /@ 
                    z)\), \[IndentingNewLine]z = \(\(z //. {a___, {{y1_, 
                              z1_}, o1_, r1x_}, {{x_, x_}, x_, 
                            rx2_}, {{y2_, z2_}, o2_, r2_}, 
                          b___} \[RuleDelayed] {a, {{y1, z1}, o1, 
                            NetRecombination[{r1x, rx2}]}, {{y2, z2}, o2, 
                            r2}, b}\) /. {a___, {{x_, x_}, x_, 
                          rx_}} \[RuleDelayed] {a}\) /. {{{x_, x_}, x_, rx_}, 
                      b___} \[RuleDelayed] {b}; \[IndentingNewLine]rr = 
                Transpose[
                  z /. {{{x_, y_}, x_, r_} \[RuleDelayed] {1, r}, {{x_, y_}, 
                          y_, r_} \[RuleDelayed] {2, 
                          r}}]; \[IndentingNewLine]xx = 
                Abs[rr\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                    RotateLeft[
                      rr\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \
\[IndentingNewLine]Times @@ 
                Drop[Transpose[{xx, 
                        rr\[LeftDoubleBracket]2\[RightDoubleBracket]}] /. \
{{1, r_} \[RuleDelayed] r, {0, r_} \[RuleDelayed] 
                        1 - r}, \(-1\)], \[IndentingNewLine]0]]];\)\)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(GenotypeProbability[{h1_List, h2_List}, p1_List, 
        p2_List] := \[IndentingNewLine]GenotypeProbability[h1, p1] 
        GenotypeProbability[h2, p2]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(GenotypeProbability[{h1_List, h2_List}, p1_List, p2_List, 
        opts__Rule] := \[IndentingNewLine]If[\(ObservableGenotype /. {opts}\) \
/. Options[
            GenotypeProbability], \[IndentingNewLine]Module[{j, \
\[IndentingNewLine]ps = PossibleGenotypes[o], \[IndentingNewLine]nopts = 
              DeleteCases[opts, 
                ObservableGenotype \[Rule] 
                  True]}, \[IndentingNewLine]Sum[\(GenotypeProbability[
                  ps\[LeftDoubleBracket]
                    j\[RightDoubleBracket], #\[LeftDoubleBracket]1\
\[RightDoubleBracket], #\[LeftDoubleBracket]2\[RightDoubleBracket], 
                  nopts] &\) /@ parents, {j, 
              Length[ps]}]], \[IndentingNewLine]GenotypeProbability[h1, p1, 
            opts /. {\((Linkage \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                      x)\), \((SegregationRatio \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((SegregationRatio \[Rule] 
                      x)\)}] GenotypeProbability[h2, p2, 
            opts /. {\((Linkage \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                      y)\), \((SegregationRatio \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((SegregationRatio \[Rule] 
                      y)\)}]]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(GenotypeProbability[g : {{_, _} ... }, p1_List, p2_List, opts1___Rule, 
        ObservableGenotype \[Rule] True, 
        opts2___Rule] := \[IndentingNewLine]Plus @@ \
\((\(GenotypeProbability[#, p1, p2, opts1, opts2] &\) /@ 
            PossibleGenotypes[g])\); \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NetRecombination[{r\_1, r\_2, 
          r\_3, \[Ellipsis]}]\ gives\ the\ net\ recombination\ rate\ across\ \
a\ linear\ genetic\ map\)], "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(NetRecombination[{}] := 0; \), "\n", 
    \(NetRecombination[{r___, s_}] := 
      s + NetRecombination[{r}] \((1 - 2  s)\); \)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GenotypeFrequencyTable[site,alleles] lists the diploid genotype \
frequencies, locus by locus\
\>", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          FormBox["GenotypeFrequencyTable",
            "TraditionalForm"], "[", \(s_, a_\), "]"}], 
        ":=", \(Module[{f}, \[IndentingNewLine]f[d_, 
              aa_] := \((\(Count[
                    d, #] &\) /@ \((DiploidTypes[{aa}] /. {c_List} \[Rule] 
                      c)\))\); \[IndentingNewLine]MapThread[
              f, {Transpose[Data[s]], a}]/NumberOfIndividualsTable[s]]\)}], 
      ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParentalGenotypes", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(ParentalGenotypes[{}] := \[EmptySet]; \), "\n", 
    \(ParentalGenotypes[f : {\((0 | 1 | 2 | \[EmptySet])\) .. }] := 
      DeleteCases[
          Union[f], \[EmptySet]] /. {{0} \[Rule] {0, 0}, {1} \[Rule] {0, 
              2}, {2} \[Rule] {2, 2}, {0, 1, 2} \[Rule] {1, 1}, {0, 
              2} \[Rule] {1, 1}}; \), "\n", 
    \(ParentalGenotypes[f : {___List}] := 
      ParentalGenotypes /@ Transpose[f]; \)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsubsection"],

Cell[BoxData[
    \(On[General::spell1, General::spell]; \)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
End[];
\
\>", "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["EndPackage[];", "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{1011, 616},
WindowMargins->{{57, Automatic}, {Automatic, 41}},
Magnification->1,
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 327, 8, 59, "Input",
  InitializationCell->True],
Cell[2047, 59, 219, 6, 30, "Text"],

Cell[CellGroupData[{
Cell[2291, 69, 81, 2, 50, "Section"],

Cell[CellGroupData[{
Cell[2397, 75, 483, 9, 74, "Subsubsection"],
Cell[2883, 86, 541, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3461, 100, 193, 5, 28, "Subsubsection"],
Cell[3657, 107, 252, 6, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3946, 118, 490, 9, 60, "Subsubsection"],
Cell[4439, 129, 548, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5024, 143, 186, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[5213, 151, 463, 9, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5713, 165, 39, 0, 28, "Subsubsection"],
Cell[5755, 167, 238, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6030, 177, 39, 0, 28, "Subsubsection"],
Cell[6072, 179, 238, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6347, 189, 160, 4, 28, "Subsubsection"],
Cell[6510, 195, 217, 5, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6764, 205, 43, 0, 28, "Subsubsection"],
Cell[6810, 207, 1120, 21, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7967, 233, 248, 6, 28, "Subsubsection"],
Cell[8218, 241, 299, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8554, 252, 107, 2, 28, "Subsubsection"],
Cell[8664, 256, 174, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8875, 266, 36, 0, 28, "Subsubsection"],
Cell[8914, 268, 402, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9353, 280, 44, 0, 28, "Subsubsection"],
Cell[9400, 282, 215, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9652, 292, 118, 2, 28, "Subsubsection"],
Cell[9773, 296, 197, 5, 70, "Input",
  InitializationCell->True],
Cell[9973, 303, 196, 5, 70, "Input",
  InitializationCell->True],
Cell[10172, 310, 245, 5, 70, "Input",
  InitializationCell->True],
Cell[10420, 317, 187, 5, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10644, 327, 35, 0, 28, "Subsubsection"],
Cell[10682, 329, 423, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11142, 340, 243, 6, 28, "Subsubsection"],
Cell[11388, 348, 306, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11731, 359, 114, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[11848, 364, 304, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12189, 375, 113, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[12305, 380, 391, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12733, 393, 120, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[12856, 398, 709, 11, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13602, 414, 118, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[13723, 419, 536, 11, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14296, 435, 168, 5, 28, "Subsubsection"],
Cell[14467, 442, 499, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15003, 456, 183, 5, 28, "Subsubsection"],
Cell[15189, 463, 255, 6, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15481, 474, 171, 5, 28, "Subsubsection"],
Cell[15655, 481, 235, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15927, 491, 307, 7, 44, "Subsubsection"],
Cell[16237, 500, 364, 7, 75, "Input",
  InitializationCell->True],
Cell[16604, 509, 226, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16867, 519, 204, 5, 28, "Subsubsection"],
Cell[17074, 526, 271, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17382, 537, 191, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[17576, 545, 222, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17835, 555, 173, 6, 44, "Subsubsection"],
Cell[18011, 563, 604, 10, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18652, 578, 531, 9, 62, "Subsubsection"],
Cell[19186, 589, 594, 10, 108, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19817, 604, 439, 9, 44, "Subsubsection"],
Cell[20259, 615, 479, 9, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[20775, 629, 262, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[21040, 637, 280, 6, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21357, 648, 42, 0, 28, "Subsubsection"],
Cell[21402, 650, 412, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21851, 663, 47, 0, 28, "Subsubsection"],
Cell[21901, 665, 316, 8, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22254, 678, 44, 0, 28, "Subsubsection"],
Cell[22301, 680, 604, 10, 107, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22954, 696, 36, 0, 50, "Section"],
Cell[22993, 698, 192, 5, 27, "Input",
  InitializationCell->True],
Cell[23188, 705, 149, 4, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[23362, 713, 483, 9, 74, "Subsubsection"],
Cell[23848, 724, 164, 4, 27, "Input",
  InitializationCell->True],
Cell[24015, 730, 140, 4, 27, "Input",
  InitializationCell->True],
Cell[24158, 736, 521, 11, 75, "Input",
  InitializationCell->True],
Cell[24682, 749, 243, 6, 27, "Input",
  InitializationCell->True],
Cell[24928, 757, 217, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25182, 767, 490, 9, 60, "Subsubsection"],
Cell[25675, 778, 164, 4, 27, "Input",
  InitializationCell->True],
Cell[25842, 784, 1339, 26, 187, "Input",
  InitializationCell->True],
Cell[27184, 812, 247, 6, 43, "Input",
  InitializationCell->True],
Cell[27434, 820, 223, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27694, 830, 186, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[27883, 838, 222, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28142, 848, 202, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[28347, 856, 196, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28580, 866, 384, 8, 44, "Subsubsection"],
Cell[28967, 876, 200, 6, 27, "Input",
  InitializationCell->True],
Cell[29170, 884, 666, 14, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29873, 903, 239, 6, 28, "Subsubsection"],
Cell[30115, 911, 194, 5, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[30346, 921, 154, 5, 42, "Subsubsection"],
Cell[30503, 928, 155, 4, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[30695, 937, 118, 2, 42, "Subsubsection"],
Cell[30816, 941, 273, 7, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[31126, 953, 183, 5, 42, "Subsubsection"],
Cell[31312, 960, 226, 6, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[31575, 971, 171, 5, 42, "Subsubsection"],
Cell[31749, 978, 229, 6, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32015, 989, 186, 5, 28, "Subsubsection"],
Cell[32204, 996, 187, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32428, 1006, 174, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[32605, 1014, 195, 5, 27, "Input",
  InitializationCell->True],
Cell[32803, 1021, 894, 20, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33734, 1046, 418, 8, 44, "Subsubsection"],
Cell[34155, 1056, 213, 5, 27, "Input",
  InitializationCell->True],
Cell[34371, 1063, 909, 17, 171, "Input",
  InitializationCell->True],
Cell[35283, 1082, 236, 6, 27, "Input",
  InitializationCell->True],
Cell[35522, 1090, 481, 10, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36040, 1105, 120, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[36163, 1110, 208, 5, 27, "Input",
  InitializationCell->True],
Cell[36374, 1117, 751, 14, 139, "Input",
  InitializationCell->True],
Cell[37128, 1133, 1997, 33, 251, "Input",
  InitializationCell->True],
Cell[39128, 1168, 347, 6, 43, "Input",
  InitializationCell->True],
Cell[39478, 1176, 270, 5, 43, "Input",
  InitializationCell->True],
Cell[39751, 1183, 241, 4, 43, "Input",
  InitializationCell->True],
Cell[39995, 1189, 217, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[40249, 1198, 118, 3, 42, "Subsubsection",
  InitializationCell->True],
Cell[40370, 1203, 183, 5, 27, "Input",
  InitializationCell->True],
Cell[40556, 1210, 676, 15, 107, "Input",
  InitializationCell->True],
Cell[41235, 1227, 287, 7, 27, "Input",
  InitializationCell->True],
Cell[41525, 1236, 232, 5, 43, "Input",
  InitializationCell->True],
Cell[41760, 1243, 221, 5, 43, "Input",
  InitializationCell->True],
Cell[41984, 1250, 222, 5, 43, "Input",
  InitializationCell->True],
Cell[42209, 1257, 211, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[42457, 1267, 168, 5, 28, "Subsubsection"],
Cell[42628, 1274, 206, 5, 27, "Input",
  InitializationCell->True],
Cell[42837, 1281, 230, 5, 27, "Input",
  InitializationCell->True],
Cell[43070, 1288, 234, 5, 43, "Input",
  InitializationCell->True],
Cell[43307, 1295, 218, 5, 43, "Input",
  InitializationCell->True],
Cell[43528, 1302, 206, 5, 27, "Input",
  InitializationCell->True],
Cell[43737, 1309, 230, 5, 27, "Input",
  InitializationCell->True],
Cell[43970, 1316, 234, 5, 43, "Input",
  InitializationCell->True],
Cell[44207, 1323, 218, 5, 43, "Input",
  InitializationCell->True],
Cell[44428, 1330, 4003, 70, 486, "Input",
  InitializationCell->True],
Cell[48434, 1402, 183, 3, 27, "Input",
  InitializationCell->True],
Cell[48620, 1407, 169, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[48826, 1415, 307, 7, 44, "Subsubsection"],
Cell[49136, 1424, 154, 4, 27, "Input",
  InitializationCell->True],
Cell[49293, 1430, 356, 8, 75, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[49686, 1443, 36, 0, 42, "Subsubsection"],
Cell[49725, 1445, 305, 6, 59, "Input",
  InitializationCell->True],
Cell[50033, 1453, 705, 16, 88, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[50775, 1474, 204, 5, 28, "Subsubsection"],
Cell[50982, 1481, 342, 8, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51361, 1494, 191, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[51555, 1502, 1264, 24, 166, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52856, 1531, 173, 6, 44, "Subsubsection"],
Cell[53032, 1539, 201, 5, 27, "Input",
  InitializationCell->True],
Cell[53236, 1546, 204, 5, 27, "Input",
  InitializationCell->True],
Cell[53443, 1553, 194, 5, 27, "Input",
  InitializationCell->True],
Cell[53640, 1560, 795, 15, 123, "Input",
  InitializationCell->True],
Cell[54438, 1577, 1206, 23, 184, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[55681, 1605, 436, 9, 60, "Subsubsection"],
Cell[56120, 1616, 251, 6, 27, "Input",
  InitializationCell->True],
Cell[56374, 1624, 2216, 39, 312, "Input",
  InitializationCell->True],
Cell[58593, 1665, 266, 6, 43, "Input",
  InitializationCell->True],
Cell[58862, 1673, 1471, 26, 203, "Input",
  InitializationCell->True],
Cell[60336, 1701, 374, 8, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[60747, 1714, 262, 6, 42, "Subsubsection",
  InitializationCell->True],
Cell[61012, 1722, 238, 6, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[61287, 1733, 176, 5, 42, "Subsubsection"],
Cell[61466, 1740, 562, 14, 59, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[62065, 1759, 92, 2, 42, "Subsubsection"],
Cell[62160, 1763, 522, 11, 75, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[62719, 1779, 31, 0, 42, "Subsubsection"],
Cell[62753, 1781, 148, 4, 27, "Input",
  InitializationCell->True],
Cell[62904, 1787, 110, 6, 42, "Input",
  InitializationCell->True],
Cell[63017, 1795, 108, 3, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

