(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     76468,       2111]*)
(*NotebookOutlinePosition[    149243,       4722]*)
(*  CellTagsIndexPosition[    148874,       4708]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Estimating the matrix of moments from sets of families", \
"SubsectionIcon"],

Cell[TextData[{
  "\tSuppose that instead of observing a diploid individual directly, we \
observe pairs of diploid individuals indirectly, from samples of their \
progeny.  The moments among progeny, within and between families, can be \
related to the moments among the population of parents.  We can estimate \
linkage disequilibria (from correlations between loci across families), \
heterozygote deficit (from the variance within loci within families) and \
assortative mating (from the average heterozygosity).  It is impossible, \
however, to distinguish males & females, or maternal & paternal alleles.  \
More details of this ",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(extension\ to\ families\),
          
          ButtonData:>{"Estimating the matrix of moments", 
            "Extension to families"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  " are given in the overview above."
}], "Text"],

Cell[BoxData[
    \(\(<< Multilocus`EstimatingD`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell["Example data", "SubsubsectionIcon"],

Cell["\<\
This gives a set of 18 families, scored for 6 loci; missing data \
are represented as \[EmptySet]:\
\>", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"familydata", "=", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\({{2, 0, 1, 1, 1, 1}, {1, 1, 2, 1, 1, 1}, {2, 1, 1, 1, 1, 
                      1}, {1, 1, 1, 1, 1, 1}, {2, 0, 1, 1, 1, 1}, {1, 2, 2, 
                      1, 1, 1}, {1, 1, 1, 1, 1, 1}, {1, 2, 2, 1, 1, 1}, {1, 
                      1, 1, 1, 1, 1}}\)},
                {\({{1, 1, 1, 1, 1, 1}, {2, 1, 1, 1, 1, 1}, {2, 1, 2, 1, 1, 
                      2}, {1, 1, 1, 1, \[EmptySet], 1}, {2, 1, 1, 1, 1, 
                      1}, {2, 2, 1, 1, 1, 1}, {1, 0, 1, 1, 1, 1}, {2, 2, 2, 
                      1, 1, 1}}\)},
                {\({{1, 0, 0, 1, 1, 1}, {1, 1, 0, 1, 0, 0}, {1, 0, 0, 0, 0, 
                      0}, {1, 0, 1, 0, 0, 0}, {1, 1, \[EmptySet], 0, 0, 
                      1}, {1, 0, 0, \[EmptySet], 0, 1}, {1, 0, 1, 1, 1, 
                      1}, {1, 1, 0, 1, 0, 1}, {1, 1, 0, \[EmptySet], 1, 
                      0}}\)},
                {\({{1, 1, 2, 1, 1, 2}, {1, 1, 0, 0, 1, 0}, {2, 0, 2, 1, 2, 
                      2}, {2, 0, 2, 1, 0, 2}, {1, 0, 0, 1, 1, 1}, {1, 1, 0, 
                      0, 0, 0}, {2, 1, 2, 2, 1, 2}, {1, 0, 1, 0, 0, 0}, {0, 
                      0, 1, 1, 1, 1}}\)},
                {\({{1, 0, 1, 0, 1, 0}, {1, 0, 0, 0, 1, 1}, {1, 1, 1, 0, 1, 
                      0}, {1, 1, 0, 0, 1, 0}, {1, 1, 1, 0, 1, 1}, {1, 0, 0, 
                      0, 0, 0}, {1, 0, 0, 0, 0, 1}, {1, 0, \[EmptySet], 1, 0, 
                      1}, {1, 0, 1, 0, 1, 1}, {0, 0, 1, 1, 1, 1}}\)},
                {\({{2, 1, 1, 1, 1, 1}, {2, 1, 1, 1, 1, 1}, {2, 2, 1, 1, 2, 
                      1}, {2, 1, 2, 1, 1, 1}, {2, 2, 1, 1, 2, 2}, {2, 1, 2, 
                      2, 1, 2}, {2, 1, 2, 1, 2, 1}, {2, 1, 2, 1, 2, 1}, {2, 
                      2, 1, 1, 1, 1}, {2, 1, 2, 1, 1, 1}}\)},
                {\({{1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
                      0}, {0, 1, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 0}, {0, 0, 0, 
                      0, 0, 0}, {2, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 
                      0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}\)},
                {\({{2, 2, 2, 1, 2, 1}, {2, 2, 1, 1, 1, 1}, {2, 2, 1, 1, 1, 
                      2}, {1, 1, 1, 1, 1, 1}, {2, 1, 2, 1, 2, 2}, {2, 2, 1, 
                      2, \[EmptySet], 2}, {\[EmptySet], 1, \[EmptySet], 1, 1, 
                      1}, {2, 1, 2, 2, 1, 2}, {2, 1, 2, 1, 2, 2}, {2, 1, 
                      1, \[EmptySet], 2, 1}, {2, \[EmptySet], 1, \[EmptySet], 
                      2, 1}}\)},
                {\({{2, 1, 2, 1, 2, 1}, {2, 1, 1, 1, 2, 1}, {2, 0, 2, 1, 2, 
                      2}, {2, 2, 1, 1, 2, 1}, {2, 1, 2, 1, 1, 2}, {2, 1, 1, 
                      1, 1, 1}, {2, 2, 1, 1, 1, 2}, {2, 0, 2, 1, 2, 2}, {2, 
                      2, 1, 1, 1, 2}}\)},
                {\({{1, 1, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 
                      0}, {0, 0, 0, 0, 0, 0}, {\[EmptySet], 1, 
                      2, \[EmptySet], 2, \[EmptySet]}, {0, 0, 0, 0, 0, 
                      0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 
                      0, 0, 0}, {1, 0, 0, 0, 0, 0}}\)},
                {\({{2, 1, 1, 1, 2, 2}, {2, 0, 2, 1, 2, 2}, {2, 2, 1, 1, 1, 
                      1}, {2, 2, 1, 1, 2, 1}, {2, 1, 1, 1, 2, 1}, {2, 1, 2, 
                      1, 2, 2}, {2, 2, 1, 1, 2, 1}, {2, 1, 2, 1, 2, 2}, {2, 
                      1, 1, 1, 1, 1}, {2, 1, 1, 1, 1, 2}, {2, 1, 2, 1, 2, 
                      2}}\)},
                {\({{1, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 
                      0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {1, 0, 0, 
                      0, 0, 0}, {0, 0, 0, 0, 0, 0}, {1, \[EmptySet], 0, 0, 0, 
                      0}, {1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {1, 0, 0, 
                      0, 0, 0}}\)},
                {\({{1, 1, 1, 1, 1, 1}, {1, 0, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 
                      1}, {1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, \[EmptySet], 
                      1}, {1, 1, 1, 1, 1, 1}, {1, 0, 1, 1, 2, 1}, {1, 0, 1, 
                      1, 1, 1}, {1, 0, 1, 1, 1, 1}, {1, 1, 1, 1, 2, 1}, {1, 
                      0, 1, 1, 2, 1}}\)},
                {\({{1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 2, 1}, {1, 1, 1, 1, 2, 
                      1}, {1, 1, 1, 1, 2, 1}, {1, 1, 1, 1, 1, 1}, {1, 0, 1, 
                      1, 1, 1}, {1, 1, 1, 1, 2, 
                      1}, {\[EmptySet], \[EmptySet], 1, 1, \[EmptySet], 
                      1}, {1, 1, 1, 1, 2, 1}, {1, 0, 1, 1, 1, 1}, {1, 0, 1, 
                      1, 2, 1}}\)},
                {\({{1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 2, 
                      1}, {1, 2, 1, 1, 2, 1}, {1, 2, 1, 2, 2, 1}, {1, 0, 1, 
                      1, 1, 1}, {2, 0, 1, 2, 1, 1}, {1, 1, 1, 1, 1, 1}, {1, 
                      1, 1, 1, 2, 1}, {1, 1, 1, 1, 2, 1}}\)},
                {\({{1, 2, 2, 0, 1, 1}, {1, 1, 1, 0, 1, 1}, {1, 1, 1, 0, 1, 
                      1}, {1, 2, 2, 0, 1, 2}, {1, 2, 2, \[EmptySet], 1, 
                      2}, {1, 0, 0, 0, 1, 2}, {1, 0, 0, 0, 1, 1}}\)},
                {\({{2, 2, 2, 2, 2, 2}, {2, 2, 2, 2, 2, 1}, {2, 2, 2, 2, 1, 
                      1}, {2, 2, 2, 2, 2, 1}}\)},
                {\({{1, 2, 1, 1, 2, 1}, {1, 0, 1, 1, 2, 1}, {2, 1, 1, 1, 1, 
                      1}, {1, 1, 1, 1, 2, 1}, {1, 1, 1, 1, 2, 
                      1}, {1, \[EmptySet], 1, 1, 1, 1}, {2, 2, 2, 2, 2, 
                      2}, {1, 2, 1, 1, 1, 1}}\)}
                }], "\[NoBreak]", ")"}],
          
          MatrixForm[ {{{2, 0, 1, 1, 1, 1}, {1, 1, 2, 1, 1, 1}, {2, 1, 1, 1, 
            1, 1}, {1, 1, 1, 1, 1, 1}, {2, 0, 1, 1, 1, 1}, {1, 2, 2, 1, 1, 
            1}, {1, 1, 1, 1, 1, 1}, {1, 2, 2, 1, 1, 1}, {1, 1, 1, 1, 1, 
            1}}, {{1, 1, 1, 1, 1, 1}, {2, 1, 1, 1, 1, 1}, {2, 1, 2, 1, 1, 
            2}, {1, 1, 1, 1, \[EmptySet], 1}, {2, 1, 1, 1, 1, 1}, {2, 2, 1, 1,
             1, 1}, {1, 0, 1, 1, 1, 1}, {2, 2, 2, 1, 1, 1}}, {{1, 0, 0, 1, 1, 
            1}, {1, 1, 0, 1, 0, 0}, {1, 0, 0, 0, 0, 0}, {1, 0, 1, 0, 0, 0}, {
            1, 1, \[EmptySet], 0, 0, 1}, {1, 0, 0, \[EmptySet], 0, 1}, {1, 0, 
            1, 1, 1, 1}, {1, 1, 0, 1, 0, 1}, {1, 1, 0, \[EmptySet], 1, 0}}, {{
            1, 1, 2, 1, 1, 2}, {1, 1, 0, 0, 1, 0}, {2, 0, 2, 1, 2, 2}, {2, 0, 
            2, 1, 0, 2}, {1, 0, 0, 1, 1, 1}, {1, 1, 0, 0, 0, 0}, {2, 1, 2, 2, 
            1, 2}, {1, 0, 1, 0, 0, 0}, {0, 0, 1, 1, 1, 1}}, {{1, 0, 1, 0, 1, 
            0}, {1, 0, 0, 0, 1, 1}, {1, 1, 1, 0, 1, 0}, {1, 1, 0, 0, 1, 0}, {
            1, 1, 1, 0, 1, 1}, {1, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 1}, {1, 
            0, \[EmptySet], 1, 0, 1}, {1, 0, 1, 0, 1, 1}, {0, 0, 1, 1, 1, 
            1}}, {{2, 1, 1, 1, 1, 1}, {2, 1, 1, 1, 1, 1}, {2, 2, 1, 1, 2, 
            1}, {2, 1, 2, 1, 1, 1}, {2, 2, 1, 1, 2, 2}, {2, 1, 2, 2, 1, 2}, {
            2, 1, 2, 1, 2, 1}, {2, 1, 2, 1, 2, 1}, {2, 2, 1, 1, 1, 1}, {2, 1, 
            2, 1, 1, 1}}, {{1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 
            0, 0, 0}, {0, 1, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
            0}, {2, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {
            0, 0, 0, 0, 0, 0}}, {{2, 2, 2, 1, 2, 1}, {2, 2, 1, 1, 1, 1}, {2, 
            2, 1, 1, 1, 2}, {1, 1, 1, 1, 1, 1}, {2, 1, 2, 1, 2, 2}, {2, 2, 1, 
            2, \[EmptySet], 2}, {\[EmptySet], 1, \[EmptySet], 1, 1, 1}, {2, 1,
             2, 2, 1, 2}, {2, 1, 2, 1, 2, 2}, {2, 1, 1, \[EmptySet], 2, 1}, {
            2, \[EmptySet], 1, \[EmptySet], 2, 1}}, {{2, 1, 2, 1, 2, 1}, {2, 
            1, 1, 1, 2, 1}, {2, 0, 2, 1, 2, 2}, {2, 2, 1, 1, 2, 1}, {2, 1, 2, 
            1, 1, 2}, {2, 1, 1, 1, 1, 1}, {2, 2, 1, 1, 1, 2}, {2, 0, 2, 1, 2, 
            2}, {2, 2, 1, 1, 1, 2}}, {{1, 1, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 
            0}, {1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {\[EmptySet], 1, 
            2, \[EmptySet], 2, \[EmptySet]}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
            0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 
            0}}, {{2, 1, 1, 1, 2, 2}, {2, 0, 2, 1, 2, 2}, {2, 2, 1, 1, 1, 
            1}, {2, 2, 1, 1, 2, 1}, {2, 1, 1, 1, 2, 1}, {2, 1, 2, 1, 2, 2}, {
            2, 2, 1, 1, 2, 1}, {2, 1, 2, 1, 2, 2}, {2, 1, 1, 1, 1, 1}, {2, 1, 
            1, 1, 1, 2}, {2, 1, 2, 1, 2, 2}}, {{1, 0, 0, 0, 0, 0}, {1, 0, 0, 
            0, 0, 0}, {1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
            0}, {1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {1, \[EmptySet], 0, 0,
             0, 0}, {1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 
            0}}, {{1, 1, 1, 1, 1, 1}, {1, 0, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 
            1}, {1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, \[EmptySet], 1}, {1, 1, 1, 1,
             1, 1}, {1, 0, 1, 1, 2, 1}, {1, 0, 1, 1, 1, 1}, {1, 0, 1, 1, 1, 
            1}, {1, 1, 1, 1, 2, 1}, {1, 0, 1, 1, 2, 1}}, {{1, 1, 1, 1, 1, 
            1}, {1, 1, 1, 1, 2, 1}, {1, 1, 1, 1, 2, 1}, {1, 1, 1, 1, 2, 1}, {
            1, 1, 1, 1, 1, 1}, {1, 0, 1, 1, 1, 1}, {1, 1, 1, 1, 2, 
            1}, {\[EmptySet], \[EmptySet], 1, 1, \[EmptySet], 1}, {1, 1, 1, 1,
             2, 1}, {1, 0, 1, 1, 1, 1}, {1, 0, 1, 1, 2, 1}}, {{1, 1, 1, 1, 1, 
            1}, {1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 2, 1}, {1, 2, 1, 1, 2, 1}, {
            1, 2, 1, 2, 2, 1}, {1, 0, 1, 1, 1, 1}, {2, 0, 1, 2, 1, 1}, {1, 1, 
            1, 1, 1, 1}, {1, 1, 1, 1, 2, 1}, {1, 1, 1, 1, 2, 1}}, {{1, 2, 2, 
            0, 1, 1}, {1, 1, 1, 0, 1, 1}, {1, 1, 1, 0, 1, 1}, {1, 2, 2, 0, 1, 
            2}, {1, 2, 2, \[EmptySet], 1, 2}, {1, 0, 0, 0, 1, 2}, {1, 0, 0, 0,
             1, 1}}, {{2, 2, 2, 2, 2, 2}, {2, 2, 2, 2, 2, 1}, {2, 2, 2, 2, 1, 
            1}, {2, 2, 2, 2, 2, 1}}, {{1, 2, 1, 1, 2, 1}, {1, 0, 1, 1, 2, 
            1}, {2, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 2, 1}, {1, 1, 1, 1, 2, 1}, {
            1, \[EmptySet], 1, 1, 1, 1}, {2, 2, 2, 2, 2, 2}, {1, 2, 1, 1, 1, 
            1}}}]]}], ";"}]], "Input",
  CellLabel->"In[2]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimating allele frequencies", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FamilyAlleleFrequencyEstimate[{family\_1, \[Ellipsis]}]\), \
\(gives\ the\ average\ allele\ frequency, \ 
            weighting\ each\ family\ \(\(equally\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell["\<\
These are the allele frequencies estimated from the example above.  \
There are 18 families, and so the effective sample size is of 36 \
parents:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp = FamilyAlleleFrequencyEstimate[familydata] // N\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({0.6336489898989899`, 0.42446789321789324`, 0.4909982764149431`, 
      0.3943452380952381`, 0.5269149831649832`, 
      0.4708553791887125`}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Estimating moments in the parent population from moments among the \
offspring\
\>", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FamilyEffects[
              family, {p\_1, \[Ellipsis]}]\), \(gives\ a\ list\ {S, H, SS, 
                SH, HH}\ which\ estimates\ \((\[Zeta] + \(\[Zeta]\^*\) + \(\
\[Zeta]\^'\) + \[Zeta]\^\(\('\)\(*\)\))\), \
\((\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\) + \(\[Zeta]\^'\)\[VeryThinSpace]\
\[Zeta]\^\(\('\)\(*\)\))\), \ \((\[Zeta] + \(\[Zeta]\^*\))\) \
\((\(\[Zeta]\^'\) + \[Zeta]\^\(\('\)\(*\)\))\), \ \((\[Zeta] + \
\(\[Zeta]\^*\))\) \(\[Zeta]\^'\) \[Zeta]\^\(\('\)\(*\)\) + \[Zeta]\
\[VeryThinSpace]\(\(\[Zeta]\^*\) \((\(\[Zeta]\^'\) + \[Zeta]\^\(\('\)\(*\)\))\
\)\), \ \[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\) \(\[Zeta]\^'\) \[Zeta]\^\(\('\)\
\(*\)\)\ from\ the\ segregations\ in\ the\ family . \ \ The\ \[Zeta], \ \(\
\[Zeta]\^*\)\ are\ contributions\ form\ the\ mother\ and\ the\ \
\(\[Zeta]\^'\), \ \[Zeta]\^\(\('\)\(*\)\)\ are\ contributions\ from\ the\ \
father . \ \ These\ are\ measured\ relative\ to\ the\ baseline\ allele\ \
\(\(frequencies\)\(.\)\)\)},
          {\(FamilyM[{family\_1, \[Ellipsis]}, {S, H, SS, SH, 
                HH}, {p\_1, \[Ellipsis]}]\), \(estimates\ M\_\(S, H, SS, SH, \
HH\), \ relative\ to\ the\ baseline\ allele\ \(\(frequencies\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"FamilyEffects", "FamilyM"}],

Cell[TextData[{
  "This gives, for family 2, and for each of the 6 loci, estimates of the \
five moments {S, H, SS, SH, HH}.  The first estimates the sum of \[Zeta] \
across parents, the second the average ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\)\)]],
  "in the parents (a measure of heterozygosity) and so on."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyEffects[familydata\[LeftDoubleBracket]2\[RightDoubleBracket], 
        pp] // MatrixForm\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7154040404040405`", "0.552128427128427`", 
              "0.5360068943402276`", 
              "0.42261904761904756`", \(-0.10765993265993279`\), 
              "0.3665784832451501`"},
            {\(-0.16705141808598245`\), \(-0.2911353464231576`\), 
              "0.07609149527610345`", "0.522325857426304`", 
              "0.5014488326375429`", "0.2589849730472893`"},
            {\(-0.012674264743393504`\), \(-0.18941354998917237`\), \
\(-0.49067415230493605`\), \(-0.9553482851473926`\), \
\(-0.9971023347249152`\), \(-0.7320300539054212`\)},
            {\(-0.22305870846073445`\), \(-0.19639133932190522`\), \
\(-0.31116272742743634`\), \(-0.10093709560337033`\), 
              "0.026836992552886532`", \(-0.2159085413158033`\)},
            {\(-0.04043362860634846`\), \(-0.011886898501165435`\), \
\(-0.04740987953890993`\), "0.05704314662087898`", 
              "0.062138316619617294`", \(-0.005882410442478045`\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[4]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "This gives an estimate of ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_i + \(\[Zeta]\_i\%*\) + \
\(\[Zeta]\_i\%'\) + \[Zeta]\_i\%\(\('\)\(*\)\))\) \((\[Zeta]\_j + \
\(\[Zeta]\_j\%*\) + \(\[Zeta]\_j\%'\) + \[Zeta]\_j\%\(\('\)\(*\)\))\)\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyM[familydata, {2, 0, 0, 0, 0}, pp]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(0.9472616445231039`\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(EstimateFamilyMoments[{family\_1, \[Ellipsis]}, 
              c[i, j, k, 
                l], {p\_1, \[Ellipsis]}]\), \(gives\ an\ estimate\ of\ the\ \
moment\ c[i, j, k, l]\ from\ the\ family\ \(\(data\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "This is an estimate of the covariance between maternal & paternal alleles; \
it is an average of ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_i\) \(q\_i\) F\)]],
  " over loci."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EstimateFamilyMoments[familydata, c[0, 0, 1, 1], pp]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(0.051171452687870565`\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["This is an estimate of the pairwise linkage disequilibrium:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EstimateFamilyMoments[familydata, c[0, 0, 0, 2], pp]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(0.21665721801261595`\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["\<\
This is an estimate of the covariance between parents - a measure \
of assortative mating:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EstimateFamilyMoments[familydata, c[0, 1, 0, 1], pp]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(\(-0.015506629784855262`\)\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inferring joint parental genotypes directly", "SubsubsectionIcon"],

Cell[TextData[{
  "In the above example, the states of the parents were inferred fromthe mean \
and variance of genotype scores in the offspring.  A more direct method is to \
infer the parent's genotypes from the ",
  StyleBox["class",
    FontSlant->"Italic"],
  " of croiss.  For example, a family {0,1,0,1,1} is likely to have come from \
parents {0,1}.(Clearly, such inferences are only accurate for large families, \
with more than 8 offspring, say).  "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(EstimateFamilyMoments[{family\_1, \[Ellipsis]}, 
              c[i, j, k, l], {p\_1, \[Ellipsis]}, 
              InferParentalGenotypes \[Rule] 
                True]\), \(gives\ an\ estimate\ of\ the\ moment\ c[i, j, k, 
                l]\ from\ the\ family\ data, \ 
            using\ direct\ inference\ of\ parent\ \(\(genotypes\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"InferParentalGenotypes"],

Cell[TextData[{
  "This compares estimates of the covariance between maternal & paternal \
alleles (the average of ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_i\) \(q\_i\) F\)]],
  " over loci) made in the two ways:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({EstimateFamilyMoments[familydata, c[0, 0, 1, 1], pp], 
      EstimateFamilyMoments[familydata, c[0, 0, 1, 1], pp, 
        InferParentalGenotypes \[Rule] True]}\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({0.051171452687870565`, 0.04916365027636646`}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
This compares  estimates of the pairwise linkage \
disequilibrium:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({EstimateFamilyMoments[familydata, c[0, 0, 0, 2], pp], 
      EstimateFamilyMoments[familydata, c[0, 0, 0, 2], pp, 
        InferParentalGenotypes \[Rule] True]}\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({0.21665721801261595`, 0.17905117461181663`}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
This compares estimates of the covariance between parents - a \
measure of assortative mating:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({EstimateFamilyMoments[familydata, c[0, 1, 0, 1], pp], 
      EstimateFamilyMoments[familydata, c[0, 1, 0, 1], pp, 
        InferParentalGenotypes \[Rule] True]}\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({\(-0.015506629784855262`\), \(-0.006391905279189098`\)}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
Estimates differ somewhat. They should agree for large family sizes \
and large numbers of families.  If deviations from Mendelian segregation are \
suspected, InferParentalGenotypes\[Rule]True should be used.  This option may \
be more accurate (in that it is not affected by random fluctuations in \
segregation) but is sensitive to errors in inference that arise in small \
families.  \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The method", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MToC[m, c, n, 
              Family \[Rule] True]\), \(gives\ the\ moments\ c[i, j, k, 
                l]\ \ in\ terms\ of\ \(\(m[S, H, SS, SH, HH]\)\(.\)\)\)},
          {\(MToC[m, c, j, n, Family \[Rule] True]\), \(gives\ only\ j' 
              th\ order\ \(\(moments\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MToC"],

Cell["\<\
MToC[] can now be applied to give the moments amongst the parental \
population.  EstimateMoments[] is not defined for family data, for two \
reasons.  First, the large number of moments cannot be represented in a \
simple array.  Second, there is a difficulty in calculating higher-order \
moments because the equations are overdetermined (see below).\
\>", "Text"],

Cell[TextData[{
  "This gives the ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "'s up to fifth order:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rls = 
      Flatten[Table[
          MToC[m, c, j, 6, Family \[Rule] True], {j, 0, 5}]]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({c[0, 0, 0, 0] \[Rule] m[0, 0, 0, 0, 0], 
      c[0, 0, 0, 1] \[Rule] 1\/4\ m[1, 0, 0, 0, 0], 
      c[0, 0, 0, 2] \[Rule] 
        1\/4\ \((\(-2\)\ m[0, 0, 1, 0, 0] - 2\ m[0, 1, 0, 0, 0] + 
              m[2, 0, 0, 0, 0])\), 
      c[0, 0, 1, 1] \[Rule] 1\/2\ m[0, 1, 0, 0, 0], 
      c[0, 1, 0, 1] \[Rule] 1\/4\ m[0, 0, 1, 0, 0], 
      c[0, 0, 0, 3] \[Rule] 
        1\/4\ \((3\ m[0, 0, 0, 1, 0] - 3\ m[1, 0, 1, 0, 0] - 
              3\ m[1, 1, 0, 0, 0] + m[3, 0, 0, 0, 0])\), 
      c[0, 0, 1, 2] \[Rule] 
        1\/4\ \((\(-m[0, 0, 0, 1, 0]\) + m[1, 1, 0, 0, 0])\), 
      c[0, 1, 0, 2] \[Rule] 
        1\/8\ \((\(-2\)\ m[0, 0, 0, 1, 0] + m[1, 0, 1, 0, 0])\), 
      c[0, 1, 1, 1] \[Rule] 1\/4\ m[0, 0, 0, 1, 0], 
      c[0, 0, 0, 4] \[Rule] 
        1\/4\ \((\(-4\)\ m[0, 0, 0, 0, 1] + 2\ m[0, 0, 2, 0, 0] + 
              4\ m[0, 1, 1, 0, 0] + 2\ m[0, 2, 0, 0, 0] + 
              4\ m[1, 0, 0, 1, 0] - 4\ m[2, 0, 1, 0, 0] - 
              4\ m[2, 1, 0, 0, 0] + m[4, 0, 0, 0, 0])\), 
      c[0, 0, 1, 3] \[Rule] 
        1\/4\ \((4\ m[0, 0, 0, 0, 1] - m[0, 1, 1, 0, 0] - 
              2\ m[0, 2, 0, 0, 0] - m[1, 0, 0, 1, 0] + m[2, 1, 0, 0, 0])\), 
      c[0, 0, 2, 2] \[Rule] \(-m[0, 0, 0, 0, 1]\) + 1\/2\ m[0, 2, 0, 0, 0], 
      c[0, 1, 0, 3] \[Rule] 
        1\/8\ \((\(-2\)\ m[0, 0, 2, 0, 0] - 3\ m[0, 1, 1, 0, 0] + 
              m[2, 0, 1, 0, 0])\), 
      c[0, 1, 1, 2] \[Rule] 1\/8\ m[0, 1, 1, 0, 0], 
      c[0, 2, 0, 2] \[Rule] 
        1\/4\ \((4\ m[0, 0, 0, 0, 1] + m[0, 0, 2, 0, 0] + 
              2\ m[0, 1, 1, 0, 0] - 2\ m[1, 0, 0, 1, 0])\), 
      c[0, 2, 1, 1] \[Rule] 
        1\/4\ \((\(-4\)\ m[0, 0, 0, 0, 1] - m[0, 1, 1, 0, 0] + 
              m[1, 0, 0, 1, 0])\), c[1, 1, 1, 1] \[Rule] m[0, 0, 0, 0, 1], 
      c[0, 0, 0, 5] \[Rule] 
        1\/4\ \((\(-5\)\ m[0, 0, 1, 1, 0] - 5\ m[0, 1, 0, 1, 0] - 
              5\ m[1, 0, 0, 0, 1] + 5\ m[1, 0, 2, 0, 0] + 
              10\ m[1, 1, 1, 0, 0] + 5\ m[1, 2, 0, 0, 0] + 
              5\ m[2, 0, 0, 1, 0] - 5\ m[3, 0, 1, 0, 0] - 
              5\ m[3, 1, 0, 0, 0] + m[5, 0, 0, 0, 0])\), 
      c[0, 0, 1, 4] \[Rule] 
        1\/4\ \((m[0, 0, 1, 1, 0] + 3\ m[0, 1, 0, 1, 0] + 
              3\ m[1, 0, 0, 0, 1] - 2\ m[1, 1, 1, 0, 0] - 
              3\ m[1, 2, 0, 0, 0] - m[2, 0, 0, 1, 0] + m[3, 1, 0, 0, 0])\), 
      c[0, 0, 2, 3] \[Rule] 
        1\/4\ \((\(-m[0, 1, 0, 1, 0]\) - m[1, 0, 0, 0, 1] + 
              m[1, 2, 0, 0, 0])\), 
      c[0, 1, 0, 4] \[Rule] 
        1\/8\ \((4\ m[0, 0, 1, 1, 0] + 2\ m[0, 1, 0, 1, 0] - 
              2\ m[1, 0, 0, 0, 1] - 3\ m[1, 0, 2, 0, 0] - 
              4\ m[1, 1, 1, 0, 0] + m[3, 0, 1, 0, 0])\), 
      c[0, 1, 1, 3] \[Rule] 
        1\/8\ \((\(-m[0, 0, 1, 1, 0]\) - 2\ m[0, 1, 0, 1, 0] + 
              2\ m[1, 0, 0, 0, 1] + m[1, 1, 1, 0, 0])\), 
      c[0, 1, 2, 2] \[Rule] 1\/4\ \((m[0, 1, 0, 1, 0] - m[1, 0, 0, 0, 1])\), 
      c[0, 2, 0, 3] \[Rule] 
        1\/8\ \((\(-m[0, 0, 1, 1, 0]\) + 6\ m[1, 0, 0, 0, 1] + 
              m[1, 0, 2, 0, 0] + 2\ m[1, 1, 1, 0, 0] - 
              2\ m[2, 0, 0, 1, 0])\), 
      c[0, 2, 1, 2] \[Rule] 
        1\/8\ \((m[0, 0, 1, 1, 0] - 2\ m[1, 0, 0, 0, 1])\), 
      c[0, 3, 1, 1] \[Rule] 
        1\/4\ \((\(-m[0, 0, 1, 1, 0]\) - 3\ m[1, 0, 0, 0, 1] - 
              m[1, 1, 1, 0, 0] + m[2, 0, 0, 1, 0])\), 
      c[1, 1, 1, 2] \[Rule] 1\/4\ m[1, 0, 0, 0, 1]}\)], "Output",
  CellLabel->"Out[9]="]
}, Closed]],

Cell[TextData[{
  "This is an array of the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c'\) \(s\)\(\ \)\(which\)\(\ \)\(involve\)\(\ \)\
\)\)]],
  "associations among genes within diploid individuals:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cc = Array[\((c @@ Join[{0, 0}, Sort[{#1, #2}]])\) &, {4, 4}, 0]; 
    cc // MatrixForm\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(c[0, 0, 0, 0]\), \(c[0, 0, 0, 1]\), \(c[0, 0, 0, 2]\), \(c[0, 
                0, 0, 3]\)},
            {\(c[0, 0, 0, 1]\), \(c[0, 0, 1, 1]\), \(c[0, 0, 1, 2]\), \(c[0, 
                0, 1, 3]\)},
            {\(c[0, 0, 0, 2]\), \(c[0, 0, 1, 2]\), \(c[0, 0, 2, 2]\), \(c[0, 
                0, 2, 3]\)},
            {\(c[0, 0, 0, 3]\), \(c[0, 0, 1, 3]\), \(c[0, 0, 2, 3]\), \(c[0, 
                0, 3, 3]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[10]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "This applies the solution from MToC[], and then substitutes in the \
estimated ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "'s:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(cc /. rls\) /. m[x__] \[RuleDelayed] FamilyM[familydata, {x}, pp] // 
        Chop\) // MatrixForm\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0.21665721801261595`", \(-0.016443555328054985`\)},
            {"0", "0.051171452687870565`", "0.020457344486374263`", 
              "0.02976426301060351`"},
            {"0.21665721801261595`", "0.020457344486374263`", 
              "0.009037134071447989`", "0.004578249388346275`"},
            {\(-0.016443555328054985`\), "0.02976426301060351`", 
              "0.004578249388346275`", \(c[0, 0, 3, 3]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[11]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The estimated pairwise linkage disequilibrium is 0.22; the estimated \
heterozygote deficit is 0.0773.  The sixth-order moment ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, 0, 3, 3\)\)]],
  "is left unresolved."
}], "Text"],

Cell["\<\
This is the estimated association between parent's allelic \
values:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(c[0, 1, 0, 1] /. rls\) /. 
          m[x__] \[RuleDelayed] FamilyM[familydata, {x}, pp] // Chop\) // 
      MatrixForm\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[\(-0.015506629784855262`\),
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[12]//MatrixForm="]
}, Open  ]],

Cell["\<\
This is the covariance between heterozygosity in one parent and \
additive score in the other:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(c[0, 1, 1, 1] /. rls\) /. 
          m[x__] \[RuleDelayed] FamilyM[familydata, {x}, pp] // Chop\) // 
      MatrixForm\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    TagBox[\(-0.02117920742968229`\),
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[13]//MatrixForm="]
}, Open  ]],

Cell["\<\
This is the covariance between heterozygosities in the two parents:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(c[1, 1, 1, 1] /. rls\) /. 
          m[x__] \[RuleDelayed] FamilyM[familydata, {x}, pp] // Chop\) // 
      MatrixForm\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    TagBox["0.01173678582751956`",
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[14]//MatrixForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Technicalities", "SubsubsectionIcon"],

Cell["\<\
The functions used in the extension to families parallel those \
above:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MVariables[n, 
              Family \[Rule] True]\), \(lists\ all\ the\ coefficients\ m[S, 
                H]\ needed\ to\ describe\ an\ n\ locus\ diploid\ \(\(genotype\
\)\(.\)\)\)},
          {\(MVariables[j, \ n, 
              Family \[Rule] 
                True]\), \(lists\ those\ of\ order\ j \[LessEqual] 
              2 \( \(n\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MVariables"],

Cell["\<\
In order to describe all the moments among 3 biallelic loci in two \
diploid parents, moments of the following form are required:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            RowBox[{\(M\_\(S, H, SS, SH, HH\)\), "\[Congruent]", 
              RowBox[{"E", "[", "\[IndentingNewLine]", 
                RowBox[{\(\[Product]\_\(i \[Element] S\)\), 
                  RowBox[{"(", 
                    RowBox[{\(\[Zeta]\_i\), "+", \(\[Zeta]\_i\%*\), "+", 
                      
                      FormBox[\(\(\[Zeta]\_i\%'\) + \ \
\[Zeta]\_i\%\(\('\)\(*\)\)\),
                        "TraditionalForm"]}], ")"}]}]}]}],
            "TraditionalForm"], 
          RowBox[{\(\[Product]\_\(i \[Element] H\)\), 
            
            RowBox[{\((\(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) + \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\))\), 
              FormBox[
                RowBox[{\(\[Product]\_\(i \[Element] SS\)\), 
                  RowBox[{"(", 
                    
                    RowBox[{\(\(\[Zeta]\_i\) \(\[Zeta]\_i\%'\)\), 
                      "+", \(\(\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\)\), "+", 
                      RowBox[{\(\[Zeta]\_i\), 
                        
                        FormBox[\(\[Zeta]\_i\%\(\('\)\(*\)\) + \
\(\[Zeta]\_i\%*\)\ \[Zeta]\_i\%\(\('\)\(*\)\)\),
                          "TraditionalForm"]}]}], ")"}]}],
                "TraditionalForm"], 
              RowBox[{\(\[Product]\_\(i \[Element] SH\)\), 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Zeta]\_i\), \(\[Zeta]\_i\%*\), 
                        
                        FormBox[\(\(\[Zeta]\_i\%'\) + \(\[Zeta]\_i\) \
\(\[Zeta]\_i\%*\)\ \[Zeta]\_i\%\(\('\)\(*\)\)\),
                          "TraditionalForm"]}], 
                      "+", \(\(\[Zeta]\_i\) \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\)\), 
                      "+", \(\(\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\) \[Zeta]\_i\%\
\(\('\)\(*\)\)\)}], 
                    ")"}], \(\[Product]\_\(i \[Element] HH\)\(\[Zeta]\_i\) \(\
\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\) \[Zeta]\_i\%\(\('\)\(*\)\)\)}]}]}]}]}], 
        "]"}], TraditionalForm]], "NumberedEquation",
  FormatType->StandardForm],

Cell["\<\
 Here, S, H,\[Ellipsis] are sets of distinct and non-overlapping \
indices.  In the symmetric model, only the number of elements in S, H,\
\[Ellipsis] is important,  MVariables gives the set of {|S|,|H|,\[Ellipsis]} \
required for a full description.   \
\>", "Text"],

Cell[TextData[{
  "For example, with three loci the most complex moment would be ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(0, 0, 0, 0, 3\)\)]],
  "=E[",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_1\[VeryThinSpace]\(\[Zeta]\_1\%*\) \
\(\[Zeta]\_1\%'\)\[VeryThinSpace]\[Zeta]\_1\%\(\('\)\(*\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_2\[VeryThinSpace]\(\[Zeta]\_2\%*\) \
\(\[Zeta]\_2\%'\)\[VeryThinSpace]\[Zeta]\_2\%\(\('\)\(*\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_3\[VeryThinSpace]\(\[Zeta]\_3\%*\) \
\(\[Zeta]\_3\%'\)\[VeryThinSpace]\[Zeta]\_3\%\(\('\)\(*\)\)\)]],
  "]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MVariables[3, Family \[Rule] True]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 1}, {0, 0, 0, 0, 2}, {0, 0, 0, 0, 
        3}, {0, 0, 0, 1, 0}, {0, 0, 0, 1, 1}, {0, 0, 0, 1, 2}, {0, 0, 0, 2, 
        0}, {0, 0, 0, 2, 1}, {0, 0, 0, 3, 0}, {0, 0, 1, 0, 0}, {0, 0, 1, 0, 
        1}, {0, 0, 1, 0, 2}, {0, 0, 1, 1, 0}, {0, 0, 1, 1, 1}, {0, 0, 1, 2, 
        0}, {0, 0, 2, 0, 0}, {0, 0, 2, 0, 1}, {0, 0, 2, 1, 0}, {0, 0, 3, 0, 
        0}, {0, 1, 0, 0, 0}, {0, 1, 0, 0, 1}, {0, 1, 0, 0, 2}, {0, 1, 0, 1, 
        0}, {0, 1, 0, 1, 1}, {0, 1, 0, 2, 0}, {0, 1, 1, 0, 0}, {0, 1, 1, 0, 
        1}, {0, 1, 1, 1, 0}, {0, 1, 2, 0, 0}, {0, 2, 0, 0, 0}, {0, 2, 0, 0, 
        1}, {0, 2, 0, 1, 0}, {0, 2, 1, 0, 0}, {0, 3, 0, 0, 0}, {1, 0, 0, 0, 
        0}, {1, 0, 0, 0, 1}, {1, 0, 0, 0, 2}, {1, 0, 0, 1, 0}, {1, 0, 0, 1, 
        1}, {1, 0, 0, 2, 0}, {1, 0, 1, 0, 0}, {1, 0, 1, 0, 1}, {1, 0, 1, 1, 
        0}, {1, 0, 2, 0, 0}, {1, 1, 0, 0, 0}, {1, 1, 0, 0, 1}, {1, 1, 0, 1, 
        0}, {1, 1, 1, 0, 0}, {1, 2, 0, 0, 0}, {2, 0, 0, 0, 0}, {2, 0, 0, 0, 
        1}, {2, 0, 0, 1, 0}, {2, 0, 1, 0, 0}, {2, 1, 0, 0, 0}, {3, 0, 0, 0, 
        0}}\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["This picks out those elements of order 2:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MVariables[2, 3, Family \[Rule] True]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \({{0, 0, 1, 0, 0}, {0, 1, 0, 0, 0}, {2, 0, 0, 0, 0}}\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell[TextData[{
  "Thus, moments like E[",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_1\[VeryThinSpace] + \(\[Zeta]\_1\%*\))\)\
\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[Zeta]\_1\%'\)\[VeryThinSpace] + \
\[Zeta]\_1\%\(\('\)\(*\)\))\)\)]],
  "],  E[",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_1\[VeryThinSpace]\(\[Zeta]\_1\%*\) + \(\
\[Zeta]\_1\%'\)\[VeryThinSpace]\[Zeta]\_1\%\(\('\)\(*\)\))\)\)]],
  "] and E[",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_1\[VeryThinSpace] + \(\[Zeta]\_1\%*\) + \
\(\[Zeta]\_1\%'\)\[VeryThinSpace] + \[Zeta]\_1\%\(\('\)\(*\)\))\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_2 + \[VeryThinSpace]\(\[Zeta]\_2\%*\) + \
\(\[Zeta]\_1\%'\)\[VeryThinSpace] + \[Zeta]\_1\%\(\('\)\(*\)\)\)\)]],
  "] involve only 2 genes."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MFromC[
              c, {S, H, SS, SH, HH}]\), \(gives\ the\ expression\ for\ M[S, 
                H, SS, SH, HH]\ in\ terms\ of\ the\ c[i, j, k, l]\)},
          {\(MToCEquations[m, c, n, 
              Family \[Rule] 
                True]\), \(gives\ the\ set\ of\ equations\ for\ m[S, 
                H, \[Ellipsis]]\ in\ terms\ of\ the\ c[i, j, k, 
                l]\ for\ n\ \(\(loci\)\(.\)\)\)},
          {\(MToCEquations[m, c, j, n, 
              Family \[Rule] 
                True]\), \(gives\ the\ set\ of\ equations\ of\ order\ \(\(j\)\
\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MFromC", "MToCEquations"}],

Cell[TextData[{
  "For example, ",
  Cell[BoxData[
      \(TraditionalForm\`M[2, 0, 0, 0, 1] = 
        E[\(\((\[Zeta] + \(\[Zeta]\^*\) + \(\[Zeta]\^'\)\[VeryThinSpace] + \
\[Zeta]\^\(\('\)\(*\)\))\)\_S\) \((\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\) \(\
\[Zeta]\^'\)\[VeryThinSpace]\[Zeta]\^\(\('\)\(*\)\))\)\_H]\)]],
  " for S containing 2 distinct indices, and H one.  Expanding, ",
  Cell[BoxData[
      \(TraditionalForm\`M[2, 0, 0, 0, 1] = 
        4  E[\(\(\(\[Zeta]\)\(\[VeryThinSpace]\)\)\_i\) \(\[Zeta]\_i\%*\) \(\
\[Zeta]\_i\%'\)\[VeryThinSpace]\(\[Zeta]\_i\%\(\('\)\(*\)\)\) \
\(\[Zeta]\_j\%\(\('\)\(*\)\)\) \[Zeta]\_k\%\(\('\)\(*\)\)] + 
          4  E[\(\(\(\[Zeta]\)\(\[VeryThinSpace]\)\)\_i\) \(\[Zeta]\_i\%*\) \
\(\[Zeta]\_i\%'\)\[VeryThinSpace]\(\[Zeta]\_j\%'\) \(\[Zeta]\_i\%\(\('\)\(*\)\
\)\) \[Zeta]\_j\%\(\('\)\(*\)\)] + 
          8  E[\(\(\(\[Zeta]\)\(\[VeryThinSpace]\)\)\_i\) \(\[Zeta]\_i\%*\) \
\(\[Zeta]\_j\%*\)\[VeryThinSpace]\(\[Zeta]\_i\%'\) \(\[Zeta]\_i\%\(\('\)\(*\)\
\)\) \[Zeta]\_j\%\(\('\)\(*\)\)]\)]],
  ", and we assume that loci are exchangeable:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MFromC[c, {2, 0, 0, 0, 1}]\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(4\ c[1, 1, 1, 3] + 4\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]],

Cell["\<\
These are the 56 equations needed to describe the 3 locus system:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToCEquations[m, c, 3, Family \[Rule] True] // TableForm\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(m[0, 0, 0, 0, 0] == c[0, 0, 0, 0]\)},
          {\(m[0, 0, 0, 0, 1] == c[1, 1, 1, 1]\)},
          {\(m[0, 0, 0, 0, 2] == c[2, 2, 2, 2]\)},
          {\(m[0, 0, 0, 0, 3] == c[3, 3, 3, 3]\)},
          {\(m[0, 0, 0, 1, 0] == 4\ c[0, 1, 1, 1]\)},
          {\(m[0, 0, 0, 1, 1] == 4\ c[1, 2, 2, 2]\)},
          {\(m[0, 0, 0, 1, 2] == 4\ c[2, 3, 3, 3]\)},
          {\(m[0, 0, 0, 2, 0] == 
              4\ c[0, 2, 2, 2] + 4\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)},
          {\(m[0, 0, 0, 2, 1] == 
              4\ c[1, 3, 3, 3] + 4\ c[2, 2, 3, 3] + 8\ c[2, 3, 2, 3]\)},
          {\(m[0, 0, 0, 3, 0] == 
              4\ c[0, 3, 3, 3] + 12\ c[1, 2, 3, 3] + 24\ c[1, 3, 2, 3] + 
                24\ c[2, 2, 2, 3]\)},
          {\(m[0, 0, 1, 0, 0] == 4\ c[0, 1, 0, 1]\)},
          {\(m[0, 0, 1, 0, 1] == 4\ c[1, 2, 1, 2]\)},
          {\(m[0, 0, 1, 0, 2] == 4\ c[2, 3, 2, 3]\)},
          {\(m[0, 0, 1, 1, 0] == 8\ c[0, 2, 1, 2] + 8\ c[1, 1, 1, 2]\)},
          {\(m[0, 0, 1, 1, 1] == 8\ c[1, 3, 2, 3] + 8\ c[2, 2, 2, 3]\)},
          {\(m[0, 0, 1, 2, 0] == 
              8\ c[0, 3, 2, 3] + 24\ c[1, 2, 2, 3] + 8\ c[1, 3, 1, 3] + 
                16\ c[1, 3, 2, 2] + 8\ c[2, 2, 2, 2]\)},
          {\(m[0, 0, 2, 0, 0] == 
              4\ c[0, 2, 0, 2] + 8\ c[0, 2, 1, 1] + 4\ c[1, 1, 1, 1]\)},
          {\(m[0, 0, 2, 0, 1] == 
              4\ c[1, 3, 1, 3] + 8\ c[1, 3, 2, 2] + 4\ c[2, 2, 2, 2]\)},
          {\(m[0, 0, 2, 1, 0] == 
              8\ c[0, 3, 1, 3] + 8\ c[0, 3, 2, 2] + 24\ c[1, 2, 1, 3] + 
                24\ c[1, 2, 2, 2]\)},
          {\(m[0, 0, 3, 0, 0] == 
              4\ c[0, 3, 0, 3] + 24\ c[0, 3, 1, 2] + 36\ c[1, 2, 1, 2]\)},
          {\(m[0, 1, 0, 0, 0] == 2\ c[0, 0, 1, 1]\)},
          {\(m[0, 1, 0, 0, 1] == 2\ c[1, 1, 2, 2]\)},
          {\(m[0, 1, 0, 0, 2] == 2\ c[2, 2, 3, 3]\)},
          {\(m[0, 1, 0, 1, 0] == 4\ c[0, 1, 2, 2] + 4\ c[1, 1, 1, 2]\)},
          {\(m[0, 1, 0, 1, 1] == 4\ c[1, 2, 3, 3] + 4\ c[2, 2, 2, 3]\)},
          {\(m[0, 1, 0, 2, 0] == 
              4\ c[0, 2, 3, 3] + 4\ c[1, 1, 3, 3] + 16\ c[1, 2, 2, 3] + 
                4\ c[1, 3, 2, 2] + 4\ c[2, 2, 2, 2]\)},
          {\(m[0, 1, 1, 0, 0] == 8\ c[0, 1, 1, 2]\)},
          {\(m[0, 1, 1, 0, 1] == 8\ c[1, 2, 2, 3]\)},
          {\(m[0, 1, 1, 1, 0] == 
              8\ c[0, 2, 2, 3] + 8\ c[1, 1, 2, 3] + 8\ c[1, 2, 1, 3] + 
                8\ c[1, 2, 2, 2]\)},
          {\(m[0, 1, 2, 0, 0] == 
              8\ c[0, 2, 1, 3] + 8\ c[0, 2, 2, 2] + 8\ c[1, 1, 1, 3] + 
                8\ c[1, 1, 2, 2]\)},
          {\(m[0, 2, 0, 0, 0] == 2\ c[0, 0, 2, 2] + 2\ c[1, 1, 1, 1]\)},
          {\(m[0, 2, 0, 0, 1] == 2\ c[1, 1, 3, 3] + 2\ c[2, 2, 2, 2]\)},
          {\(m[0, 2, 0, 1, 0] == 
              4\ c[0, 1, 3, 3] + 4\ c[1, 1, 2, 3] + 8\ c[1, 2, 2, 2]\)},
          {\(m[0, 2, 1, 0, 0] == 8\ c[0, 1, 2, 3] + 8\ c[1, 2, 1, 2]\)},
          {\(m[0, 3, 0, 0, 0] == 2\ c[0, 0, 3, 3] + 6\ c[1, 1, 2, 2]\)},
          {\(m[1, 0, 0, 0, 0] == 4\ c[0, 0, 0, 1]\)},
          {\(m[1, 0, 0, 0, 1] == 4\ c[1, 1, 1, 2]\)},
          {\(m[1, 0, 0, 0, 2] == 4\ c[2, 2, 2, 3]\)},
          {\(m[1, 0, 0, 1, 0] == 
              8\ c[0, 1, 1, 2] + 4\ c[0, 2, 1, 1] + 4\ c[1, 1, 1, 1]\)},
          {\(m[1, 0, 0, 1, 1] == 
              8\ c[1, 2, 2, 3] + 4\ c[1, 3, 2, 2] + 4\ c[2, 2, 2, 2]\)},
          {\(m[1, 0, 0, 2, 0] == 
              8\ c[0, 2, 2, 3] + 4\ c[0, 3, 2, 2] + 8\ c[1, 1, 2, 3] + 
                16\ c[1, 2, 1, 3] + 28\ c[1, 2, 2, 2]\)},
          {\(m[1, 0, 1, 0, 0] == 8\ c[0, 1, 0, 2] + 8\ c[0, 1, 1, 1]\)},
          {\(m[1, 0, 1, 0, 1] == 8\ c[1, 2, 1, 3] + 8\ c[1, 2, 2, 2]\)},
          {\(m[1, 0, 1, 1, 0] == 
              8\ c[0, 2, 1, 3] + 8\ c[0, 2, 2, 2] + 8\ c[0, 3, 1, 2] + 
                8\ c[1, 1, 1, 3] + 8\ c[1, 1, 2, 2] + 24\ c[1, 2, 1, 2]\)},
          {\(m[1, 0, 2, 0, 0] == 
              8\ c[0, 2, 0, 3] + 24\ c[0, 2, 1, 2] + 8\ c[0, 3, 1, 1] + 
                24\ c[1, 1, 1, 2]\)},
          {\(m[1, 1, 0, 0, 0] == 4\ c[0, 0, 1, 2] + 4\ c[0, 1, 1, 1]\)},
          {\(m[1, 1, 0, 0, 1] == 4\ c[1, 1, 2, 3] + 4\ c[1, 2, 2, 2]\)},
          {\(m[1, 1, 0, 1, 0] == 
              8\ c[0, 1, 2, 3] + 4\ c[0, 2, 2, 2] + 4\ c[1, 1, 1, 3] + 
                8\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)},
          {\(m[1, 1, 1, 0, 0] == 
              8\ c[0, 1, 1, 3] + 8\ c[0, 1, 2, 2] + 8\ c[0, 2, 1, 2] + 
                8\ c[1, 1, 1, 2]\)},
          {\(m[1, 2, 0, 0, 0] == 
              4\ c[0, 0, 2, 3] + 4\ c[0, 1, 2, 2] + 8\ c[1, 1, 1, 2]\)},
          {\(m[2, 0, 0, 0, 0] == 
              4\ c[0, 0, 0, 2] + 4\ c[0, 0, 1, 1] + 8\ c[0, 1, 0, 1]\)},
          {\(m[2, 0, 0, 0, 1] == 
              4\ c[1, 1, 1, 3] + 4\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)},
          {\(m[2, 0, 0, 1, 0] == 
              8\ c[0, 1, 1, 3] + 8\ c[0, 1, 2, 2] + 16\ c[0, 2, 1, 2] + 
                4\ c[0, 3, 1, 1] + 28\ c[1, 1, 1, 2]\)},
          {\(m[2, 0, 1, 0, 0] == 
              8\ c[0, 1, 0, 3] + 24\ c[0, 1, 1, 2] + 8\ c[0, 2, 0, 2] + 
                16\ c[0, 2, 1, 1] + 8\ c[1, 1, 1, 1]\)},
          {\(m[2, 1, 0, 0, 0] == 
              4\ c[0, 0, 1, 3] + 4\ c[0, 0, 2, 2] + 16\ c[0, 1, 1, 2] + 
                4\ c[0, 2, 1, 1] + 4\ c[1, 1, 1, 1]\)},
          {\(m[3, 0, 0, 0, 0] == 
              4\ c[0, 0, 0, 3] + 12\ c[0, 0, 1, 2] + 24\ c[0, 1, 0, 2] + 
                24\ c[0, 1, 1, 1]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          m[ 0, 0, 0, 0, 0], 
          c[ 0, 0, 0, 0]], 
        Equal[ 
          m[ 0, 0, 0, 0, 1], 
          c[ 1, 1, 1, 1]], 
        Equal[ 
          m[ 0, 0, 0, 0, 2], 
          c[ 2, 2, 2, 2]], 
        Equal[ 
          m[ 0, 0, 0, 0, 3], 
          c[ 3, 3, 3, 3]], 
        Equal[ 
          m[ 0, 0, 0, 1, 0], 
          Times[ 4, 
            c[ 0, 1, 1, 1]]], 
        Equal[ 
          m[ 0, 0, 0, 1, 1], 
          Times[ 4, 
            c[ 1, 2, 2, 2]]], 
        Equal[ 
          m[ 0, 0, 0, 1, 2], 
          Times[ 4, 
            c[ 2, 3, 3, 3]]], 
        Equal[ 
          m[ 0, 0, 0, 2, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 2, 2, 2]], 
            Times[ 4, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 0, 0, 0, 2, 1], 
          Plus[ 
            Times[ 4, 
              c[ 1, 3, 3, 3]], 
            Times[ 4, 
              c[ 2, 2, 3, 3]], 
            Times[ 8, 
              c[ 2, 3, 2, 3]]]], 
        Equal[ 
          m[ 0, 0, 0, 3, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 3, 3, 3]], 
            Times[ 12, 
              c[ 1, 2, 3, 3]], 
            Times[ 24, 
              c[ 1, 3, 2, 3]], 
            Times[ 24, 
              c[ 2, 2, 2, 3]]]], 
        Equal[ 
          m[ 0, 0, 1, 0, 0], 
          Times[ 4, 
            c[ 0, 1, 0, 1]]], 
        Equal[ 
          m[ 0, 0, 1, 0, 1], 
          Times[ 4, 
            c[ 1, 2, 1, 2]]], 
        Equal[ 
          m[ 0, 0, 1, 0, 2], 
          Times[ 4, 
            c[ 2, 3, 2, 3]]], 
        Equal[ 
          m[ 0, 0, 1, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 1, 2]], 
            Times[ 8, 
              c[ 1, 1, 1, 2]]]], 
        Equal[ 
          m[ 0, 0, 1, 1, 1], 
          Plus[ 
            Times[ 8, 
              c[ 1, 3, 2, 3]], 
            Times[ 8, 
              c[ 2, 2, 2, 3]]]], 
        Equal[ 
          m[ 0, 0, 1, 2, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 3, 2, 3]], 
            Times[ 24, 
              c[ 1, 2, 2, 3]], 
            Times[ 8, 
              c[ 1, 3, 1, 3]], 
            Times[ 16, 
              c[ 1, 3, 2, 2]], 
            Times[ 8, 
              c[ 2, 2, 2, 2]]]], 
        Equal[ 
          m[ 0, 0, 2, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 2, 0, 2]], 
            Times[ 8, 
              c[ 0, 2, 1, 1]], 
            Times[ 4, 
              c[ 1, 1, 1, 1]]]], 
        Equal[ 
          m[ 0, 0, 2, 0, 1], 
          Plus[ 
            Times[ 4, 
              c[ 1, 3, 1, 3]], 
            Times[ 8, 
              c[ 1, 3, 2, 2]], 
            Times[ 4, 
              c[ 2, 2, 2, 2]]]], 
        Equal[ 
          m[ 0, 0, 2, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 3, 1, 3]], 
            Times[ 8, 
              c[ 0, 3, 2, 2]], 
            Times[ 24, 
              c[ 1, 2, 1, 3]], 
            Times[ 24, 
              c[ 1, 2, 2, 2]]]], 
        Equal[ 
          m[ 0, 0, 3, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 3, 0, 3]], 
            Times[ 24, 
              c[ 0, 3, 1, 2]], 
            Times[ 36, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 0, 1, 0, 0, 0], 
          Times[ 2, 
            c[ 0, 0, 1, 1]]], 
        Equal[ 
          m[ 0, 1, 0, 0, 1], 
          Times[ 2, 
            c[ 1, 1, 2, 2]]], 
        Equal[ 
          m[ 0, 1, 0, 0, 2], 
          Times[ 2, 
            c[ 2, 2, 3, 3]]], 
        Equal[ 
          m[ 0, 1, 0, 1, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 1, 2, 2]], 
            Times[ 4, 
              c[ 1, 1, 1, 2]]]], 
        Equal[ 
          m[ 0, 1, 0, 1, 1], 
          Plus[ 
            Times[ 4, 
              c[ 1, 2, 3, 3]], 
            Times[ 4, 
              c[ 2, 2, 2, 3]]]], 
        Equal[ 
          m[ 0, 1, 0, 2, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 2, 3, 3]], 
            Times[ 4, 
              c[ 1, 1, 3, 3]], 
            Times[ 16, 
              c[ 1, 2, 2, 3]], 
            Times[ 4, 
              c[ 1, 3, 2, 2]], 
            Times[ 4, 
              c[ 2, 2, 2, 2]]]], 
        Equal[ 
          m[ 0, 1, 1, 0, 0], 
          Times[ 8, 
            c[ 0, 1, 1, 2]]], 
        Equal[ 
          m[ 0, 1, 1, 0, 1], 
          Times[ 8, 
            c[ 1, 2, 2, 3]]], 
        Equal[ 
          m[ 0, 1, 1, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 2, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 3]], 
            Times[ 8, 
              c[ 1, 2, 1, 3]], 
            Times[ 8, 
              c[ 1, 2, 2, 2]]]], 
        Equal[ 
          m[ 0, 1, 2, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 1, 3]], 
            Times[ 8, 
              c[ 0, 2, 2, 2]], 
            Times[ 8, 
              c[ 1, 1, 1, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 2]]]], 
        Equal[ 
          m[ 0, 2, 0, 0, 0], 
          Plus[ 
            Times[ 2, 
              c[ 0, 0, 2, 2]], 
            Times[ 2, 
              c[ 1, 1, 1, 1]]]], 
        Equal[ 
          m[ 0, 2, 0, 0, 1], 
          Plus[ 
            Times[ 2, 
              c[ 1, 1, 3, 3]], 
            Times[ 2, 
              c[ 2, 2, 2, 2]]]], 
        Equal[ 
          m[ 0, 2, 0, 1, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 1, 3, 3]], 
            Times[ 4, 
              c[ 1, 1, 2, 3]], 
            Times[ 8, 
              c[ 1, 2, 2, 2]]]], 
        Equal[ 
          m[ 0, 2, 1, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 2, 3]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 0, 3, 0, 0, 0], 
          Plus[ 
            Times[ 2, 
              c[ 0, 0, 3, 3]], 
            Times[ 6, 
              c[ 1, 1, 2, 2]]]], 
        Equal[ 
          m[ 1, 0, 0, 0, 0], 
          Times[ 4, 
            c[ 0, 0, 0, 1]]], 
        Equal[ 
          m[ 1, 0, 0, 0, 1], 
          Times[ 4, 
            c[ 1, 1, 1, 2]]], 
        Equal[ 
          m[ 1, 0, 0, 0, 2], 
          Times[ 4, 
            c[ 2, 2, 2, 3]]], 
        Equal[ 
          m[ 1, 0, 0, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 1, 2]], 
            Times[ 4, 
              c[ 0, 2, 1, 1]], 
            Times[ 4, 
              c[ 1, 1, 1, 1]]]], 
        Equal[ 
          m[ 1, 0, 0, 1, 1], 
          Plus[ 
            Times[ 8, 
              c[ 1, 2, 2, 3]], 
            Times[ 4, 
              c[ 1, 3, 2, 2]], 
            Times[ 4, 
              c[ 2, 2, 2, 2]]]], 
        Equal[ 
          m[ 1, 0, 0, 2, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 2, 3]], 
            Times[ 4, 
              c[ 0, 3, 2, 2]], 
            Times[ 8, 
              c[ 1, 1, 2, 3]], 
            Times[ 16, 
              c[ 1, 2, 1, 3]], 
            Times[ 28, 
              c[ 1, 2, 2, 2]]]], 
        Equal[ 
          m[ 1, 0, 1, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 0, 2]], 
            Times[ 8, 
              c[ 0, 1, 1, 1]]]], 
        Equal[ 
          m[ 1, 0, 1, 0, 1], 
          Plus[ 
            Times[ 8, 
              c[ 1, 2, 1, 3]], 
            Times[ 8, 
              c[ 1, 2, 2, 2]]]], 
        Equal[ 
          m[ 1, 0, 1, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 1, 3]], 
            Times[ 8, 
              c[ 0, 2, 2, 2]], 
            Times[ 8, 
              c[ 0, 3, 1, 2]], 
            Times[ 8, 
              c[ 1, 1, 1, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 2]], 
            Times[ 24, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 1, 0, 2, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 0, 3]], 
            Times[ 24, 
              c[ 0, 2, 1, 2]], 
            Times[ 8, 
              c[ 0, 3, 1, 1]], 
            Times[ 24, 
              c[ 1, 1, 1, 2]]]], 
        Equal[ 
          m[ 1, 1, 0, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 0, 1, 2]], 
            Times[ 4, 
              c[ 0, 1, 1, 1]]]], 
        Equal[ 
          m[ 1, 1, 0, 0, 1], 
          Plus[ 
            Times[ 4, 
              c[ 1, 1, 2, 3]], 
            Times[ 4, 
              c[ 1, 2, 2, 2]]]], 
        Equal[ 
          m[ 1, 1, 0, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 2, 3]], 
            Times[ 4, 
              c[ 0, 2, 2, 2]], 
            Times[ 4, 
              c[ 1, 1, 1, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 1, 1, 1, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 1, 3]], 
            Times[ 8, 
              c[ 0, 1, 2, 2]], 
            Times[ 8, 
              c[ 0, 2, 1, 2]], 
            Times[ 8, 
              c[ 1, 1, 1, 2]]]], 
        Equal[ 
          m[ 1, 2, 0, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 0, 2, 3]], 
            Times[ 4, 
              c[ 0, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 1, 1, 2]]]], 
        Equal[ 
          m[ 2, 0, 0, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 0, 0, 2]], 
            Times[ 4, 
              c[ 0, 0, 1, 1]], 
            Times[ 8, 
              c[ 0, 1, 0, 1]]]], 
        Equal[ 
          m[ 2, 0, 0, 0, 1], 
          Plus[ 
            Times[ 4, 
              c[ 1, 1, 1, 3]], 
            Times[ 4, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 2, 0, 0, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 1, 3]], 
            Times[ 8, 
              c[ 0, 1, 2, 2]], 
            Times[ 16, 
              c[ 0, 2, 1, 2]], 
            Times[ 4, 
              c[ 0, 3, 1, 1]], 
            Times[ 28, 
              c[ 1, 1, 1, 2]]]], 
        Equal[ 
          m[ 2, 0, 1, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 0, 3]], 
            Times[ 24, 
              c[ 0, 1, 1, 2]], 
            Times[ 8, 
              c[ 0, 2, 0, 2]], 
            Times[ 16, 
              c[ 0, 2, 1, 1]], 
            Times[ 8, 
              c[ 1, 1, 1, 1]]]], 
        Equal[ 
          m[ 2, 1, 0, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 0, 1, 3]], 
            Times[ 4, 
              c[ 0, 0, 2, 2]], 
            Times[ 16, 
              c[ 0, 1, 1, 2]], 
            Times[ 4, 
              c[ 0, 2, 1, 1]], 
            Times[ 4, 
              c[ 1, 1, 1, 1]]]], 
        Equal[ 
          m[ 3, 0, 0, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 0, 0, 3]], 
            Times[ 12, 
              c[ 0, 0, 1, 2]], 
            Times[ 24, 
              c[ 0, 1, 0, 2]], 
            Times[ 24, 
              c[ 0, 1, 1, 1]]]]}]]], "Output",
  CellLabel->"Out[80]//TableForm="]
}, Closed]],

Cell["These are those equations that involve just 3 loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToCEquations[m, c, 3, 3, Family \[Rule] True] // TableForm\)], "Input",\

  CellLabel->"In[82]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(m[0, 0, 0, 1, 0] == 4\ c[0, 1, 1, 1]\)},
          {\(m[1, 0, 1, 0, 0] == 8\ c[0, 1, 0, 2] + 8\ c[0, 1, 1, 1]\)},
          {\(m[1, 1, 0, 0, 0] == 4\ c[0, 0, 1, 2] + 4\ c[0, 1, 1, 1]\)},
          {\(m[3, 0, 0, 0, 0] == 
              4\ c[0, 0, 0, 3] + 12\ c[0, 0, 1, 2] + 24\ c[0, 1, 0, 2] + 
                24\ c[0, 1, 1, 1]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          m[ 0, 0, 0, 1, 0], 
          Times[ 4, 
            c[ 0, 1, 1, 1]]], 
        Equal[ 
          m[ 1, 0, 1, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 0, 2]], 
            Times[ 8, 
              c[ 0, 1, 1, 1]]]], 
        Equal[ 
          m[ 1, 1, 0, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 0, 1, 2]], 
            Times[ 4, 
              c[ 0, 1, 1, 1]]]], 
        Equal[ 
          m[ 3, 0, 0, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 0, 0, 3]], 
            Times[ 12, 
              c[ 0, 0, 1, 2]], 
            Times[ 24, 
              c[ 0, 1, 0, 2]], 
            Times[ 24, 
              c[ 0, 1, 1, 1]]]]}]]], "Output",
  CellLabel->"Out[82]//TableForm="]
}, Open  ]],

Cell["\<\
The solution for moments involving three genes is just \
MToC[m,c,3,3]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToC[m, c, 3, 3, Family \[Rule] True]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \({c[0, 0, 0, 3] \[Rule] 
        1\/4\ \((3\ m[0, 0, 0, 1, 0] - 3\ m[1, 0, 1, 0, 0] - 
              3\ m[1, 1, 0, 0, 0] + m[3, 0, 0, 0, 0])\), 
      c[0, 0, 1, 2] \[Rule] 
        1\/4\ \((\(-m[0, 0, 0, 1, 0]\) + m[1, 1, 0, 0, 0])\), 
      c[0, 1, 0, 2] \[Rule] 
        1\/8\ \((\(-2\)\ m[0, 0, 0, 1, 0] + m[1, 0, 1, 0, 0])\), 
      c[0, 1, 1, 1] \[Rule] 1\/4\ m[0, 0, 0, 1, 0]}\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell["\<\
However, the sixth-order equations imply a certain relation among \
the m's, and so cannot be solved in general.  MToC[] prints a warning, \
together with this relation:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToC[m, c, 6, 3, Family \[Rule] True]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    InterpretationBox[\("WARNING: more equations than variables for {j,n}="\
\[InvisibleSpace]{6, 3}\),
      SequenceForm[ 
      "WARNING: more equations than variables for {j,n}=", {6, 3}],
      Editable->False]], "Print",
  CellLabel->"From In[87]:="],

Cell[BoxData[
    TagBox[\(4\ m[0, 0, 1, 0, 1] - m[0, 2, 1, 0, 0] + m[1, 1, 0, 1, 0] - 
          m[2, 0, 0, 0, 1] == m[0, 0, 0, 2, 0]\),
      (TableForm[ #]&)]], "Print",
  CellLabel->"From In[87]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[87]="]
}, Open  ]],

Cell["\<\
We can examine the problem in more detail.  There are 10 6'th order \
equations and only 9 variables:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqns = MToCEquations[m, c, 6, 3, Family \[Rule] True]; 
    eqns // TableForm\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(m[0, 0, 0, 2, 0] == 
              4\ c[0, 2, 2, 2] + 4\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)},
          {\(m[0, 0, 1, 0, 1] == 4\ c[1, 2, 1, 2]\)},
          {\(m[0, 0, 3, 0, 0] == 
              4\ c[0, 3, 0, 3] + 24\ c[0, 3, 1, 2] + 36\ c[1, 2, 1, 2]\)},
          {\(m[0, 1, 0, 0, 1] == 2\ c[1, 1, 2, 2]\)},
          {\(m[0, 1, 2, 0, 0] == 
              8\ c[0, 2, 1, 3] + 8\ c[0, 2, 2, 2] + 8\ c[1, 1, 1, 3] + 
                8\ c[1, 1, 2, 2]\)},
          {\(m[0, 2, 1, 0, 0] == 8\ c[0, 1, 2, 3] + 8\ c[1, 2, 1, 2]\)},
          {\(m[0, 3, 0, 0, 0] == 2\ c[0, 0, 3, 3] + 6\ c[1, 1, 2, 2]\)},
          {\(m[1, 0, 1, 1, 0] == 
              8\ c[0, 2, 1, 3] + 8\ c[0, 2, 2, 2] + 8\ c[0, 3, 1, 2] + 
                8\ c[1, 1, 1, 3] + 8\ c[1, 1, 2, 2] + 24\ c[1, 2, 1, 2]\)},
          {\(m[1, 1, 0, 1, 0] == 
              8\ c[0, 1, 2, 3] + 4\ c[0, 2, 2, 2] + 4\ c[1, 1, 1, 3] + 
                8\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)},
          {\(m[2, 0, 0, 0, 1] == 
              4\ c[1, 1, 1, 3] + 4\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          m[ 0, 0, 0, 2, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 2, 2, 2]], 
            Times[ 4, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 0, 0, 1, 0, 1], 
          Times[ 4, 
            c[ 1, 2, 1, 2]]], 
        Equal[ 
          m[ 0, 0, 3, 0, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 3, 0, 3]], 
            Times[ 24, 
              c[ 0, 3, 1, 2]], 
            Times[ 36, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 0, 1, 0, 0, 1], 
          Times[ 2, 
            c[ 1, 1, 2, 2]]], 
        Equal[ 
          m[ 0, 1, 2, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 1, 3]], 
            Times[ 8, 
              c[ 0, 2, 2, 2]], 
            Times[ 8, 
              c[ 1, 1, 1, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 2]]]], 
        Equal[ 
          m[ 0, 2, 1, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 2, 3]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 0, 3, 0, 0, 0], 
          Plus[ 
            Times[ 2, 
              c[ 0, 0, 3, 3]], 
            Times[ 6, 
              c[ 1, 1, 2, 2]]]], 
        Equal[ 
          m[ 1, 0, 1, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 2, 1, 3]], 
            Times[ 8, 
              c[ 0, 2, 2, 2]], 
            Times[ 8, 
              c[ 0, 3, 1, 2]], 
            Times[ 8, 
              c[ 1, 1, 1, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 2]], 
            Times[ 24, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 1, 1, 0, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 2, 3]], 
            Times[ 4, 
              c[ 0, 2, 2, 2]], 
            Times[ 4, 
              c[ 1, 1, 1, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 2, 0, 0, 0, 1], 
          Plus[ 
            Times[ 4, 
              c[ 1, 1, 1, 3]], 
            Times[ 4, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]]}]]], "Output",
  CellLabel->"Out[100]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vars = Union[Extract[eqns, Position[eqns, c[__]]]]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \({c[0, 0, 3, 3], c[0, 1, 2, 3], c[0, 2, 1, 3], c[0, 2, 2, 2], 
      c[0, 3, 0, 3], c[0, 3, 1, 2], c[1, 1, 1, 3], c[1, 1, 2, 2], 
      c[1, 2, 1, 2]}\)], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell["\<\
The equations thus imply a relation among the m's which must be \
satisfied if there is to be a solution.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eliminate[eqns, vars]\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(4\ m[0, 0, 1, 0, 1] - m[0, 2, 1, 0, 0] + m[1, 1, 0, 1, 0] - 
        m[2, 0, 0, 0, 1] == m[0, 0, 0, 2, 0]\)], "Output",
  CellLabel->"Out[102]="]
}, Open  ]],

Cell["\<\
Deleting any one of the m's involved in that relation \
(m[0,0,0,2,0], m[0,0,1,0,1], m[0,2,1,0,0], m[1,1,0,1,0], m[2,0,0,0,1]) gives \
a solution.  For example:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[DeleteCases[eqns, m[0, 0, 1, 0, 1] \[Equal] __], vars]\)], "Input",\

  CellLabel->"In[120]:="],

Cell[BoxData[
    \({{c[0, 0, 3, 3] \[Rule] 
          1\/2\ \((\(-3\)\ m[0, 1, 0, 0, 1] + m[0, 3, 0, 0, 0])\), 
        c[0, 1, 2, 3] \[Rule] 
          1\/16\ \((\(-m[0, 0, 0, 2, 0]\) + m[0, 2, 1, 0, 0] + 
                m[1, 1, 0, 1, 0] - m[2, 0, 0, 0, 1])\), 
        c[0, 2, 1, 3] \[Rule] 
          1\/8\ \((4\ m[0, 1, 0, 0, 1] + m[0, 1, 2, 0, 0] + 
                2\ m[0, 2, 1, 0, 0] - 2\ m[1, 1, 0, 1, 0])\), 
        c[0, 2, 2, 2] \[Rule] 
          1\/8\ \((m[0, 0, 0, 2, 0] - 4\ m[0, 1, 0, 0, 1] - 
                m[0, 2, 1, 0, 0] + m[1, 1, 0, 1, 0] - m[2, 0, 0, 0, 1])\), 
        c[0, 3, 0, 3] \[Rule] 
          1\/16\ \((9\ m[0, 0, 0, 2, 0] + 4\ m[0, 0, 3, 0, 0] + 
                12\ m[0, 1, 2, 0, 0] + 9\ m[0, 2, 1, 0, 0] - 
                12\ m[1, 0, 1, 1, 0] - 9\ m[1, 1, 0, 1, 0] + 
                9\ m[2, 0, 0, 0, 1])\), 
        c[0, 3, 1, 2] \[Rule] 
          1\/16\ \((\(-3\)\ m[0, 0, 0, 2, 0] - 2\ m[0, 1, 2, 0, 0] - 
                3\ m[0, 2, 1, 0, 0] + 2\ m[1, 0, 1, 1, 0] + 
                3\ m[1, 1, 0, 1, 0] - 3\ m[2, 0, 0, 0, 1])\), 
        c[1, 1, 1, 3] \[Rule] 
          1\/8\ \((\(-m[0, 0, 0, 2, 0]\) - 4\ m[0, 1, 0, 0, 1] - 
                m[0, 2, 1, 0, 0] + m[1, 1, 0, 1, 0] + m[2, 0, 0, 0, 1])\), 
        c[1, 1, 2, 2] \[Rule] 1\/2\ m[0, 1, 0, 0, 1], 
        c[1, 2, 1, 2] \[Rule] 
          1\/16\ \((m[0, 0, 0, 2, 0] + m[0, 2, 1, 0, 0] - m[1, 1, 0, 1, 0] + 
                m[2, 0, 0, 0, 1])\)}}\)], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell["\<\
The problem gets worse with more loci.  However, it seems only to \
influence higher-order moments that may not be of much interest.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Checking against simulations", "SubsubsectionIcon"],

Cell["\<\
Simulate a population with p=0.75 at 4 loci , LE, HW.There is \
surprisinglylittle difference between the two methods (inference from moments \
of offspring, and frominferred joint parental genotypes (jpg))
There is a hint of bias for pqF using inference of joint parental genotypes\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(hp = 
      MakePopulation[4, 0.75, 1, 
        NumericalModel \[Rule] SymmetricHaploidFrequencies]; 
    dp = MakeDiploid[hp];\), "\n", 
    \(\(st0 = simulate[dp, 10, 24, 100];\)\), "\n", 
    \(printResults[st0] // TableForm\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"pqF\"\>", "\<\"D\"\>", "\<\"AM\"\>"},
          {"\<\"mean\"\>", \(-0.0012980613425925866`\), 
            "0.0059939814814814725`", \(-0.0022714409722222216`\)},
          {"\<\"mean (jpg)\"\>", "0.003144704861111113`", 
            "0.0001002025462962975`", \(-0.0015948784722222224`\)},
          {"\<\"sd\"\>", "0.015429333093135253`", "0.032100614105454395`", 
            "0.010218440656238842`"},
          {"\<\"sd (jpg)\"\>", "0.014611598961712585`", 
            "0.029248183547771905`", "0.008996480405934155`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[198]//TableForm="]
}, Open  ]],

Cell["D is estimated correctly by both methods (here, D=0.05).", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dp = makePop[4, 0.75, 0.05, 0];\)\), "\[IndentingNewLine]", 
    \(\(st1 = simulate[dp, 10, 24, 100];\)\), "\n", 
    \(printResults[st1] // TableForm\)}], "Input",
  CellLabel->"In[241]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"pqF\"\>", "\<\"D\"\>", "\<\"AM\"\>"},
          {"\<\"mean\"\>", \(-0.003591807725694445`\), 
            "0.05237357132523148`", \(-0.001086599392361103`\)},
          {"\<\"mean (jpg)\"\>", "0.0012117078993055558`", 
            "0.04787118417245369`", \(-0.0009497504340277776`\)},
          {"\<\"sd\"\>", "0.014972074148545374`", "0.026164974950276525`", 
            "0.011285236158988897`"},
          {"\<\"sd (jpg)\"\>", "0.013322584078202202`", 
            "0.025002567941984518`", "0.010771558171869457`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[243]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "There is a complication in constructing a population out of HW under the \
symmetric model.  In this example, a fraction 0.7 of diploid individuals are \
generated by random union of gametes, whilst 0.3 are generated by combining \
two gametes of the same class.  However, that does not mean that these \
gametes will be homozygous.  For example, two class 1 gametes  may be ",
  Cell[BoxData[
      \(TraditionalForm\`0001\/0001, \ 0001\/0010, \[Ellipsis]\)]],
  ":: the average heterozygosity is only ",
  Cell[BoxData[
      \(TraditionalForm\`3\/8\)]],
  ".  Averaging over the classes 0,1,\[Ellipsis]4, the expected pqF is \
0.0281,which fits simulations with D=0"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(0.6\/2\) \((2  p \((1 - p)\) - 
            Sum[\(\((1 - p)\)\^\(4 - i\)\) \(p\^i\) Binomial[4, i] 
                HeterozygoteB[i, i, 4] . Range[0, 1, 1\/4], {i, 0, 4}])\) /. 
      p \[Rule] 0.75\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \(0.028124999999999997`\)], "Output",
  CellLabel->"Out[175]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dp = makePop[4, 0.75, 0, 0.6];\)\), "\[IndentingNewLine]", 
    \(\(st1 = simulate[dp, 10, 24, 100];\)\), "\n", 
    \(printResults[st1] // TableForm\)}], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"pqF\"\>", "\<\"D\"\>", "\<\"AM\"\>"},
          {"\<\"mean\"\>", "0.027939811197916678`", 
            "0.001474403211805545`", \(-0.0006278971354166614`\)},
          {"\<\"mean (jpg)\"\>", 
            "0.031664029947916665`", \(-0.001078490306712963`\), \
\(-0.0011224283854166673`\)},
          {"\<\"sd\"\>", "0.019637513455934785`", "0.03244635424745178`", 
            "0.013655206976028875`"},
          {"\<\"sd (jpg)\"\>", "0.01750862794744476`", "0.03075878859723907`",
             "0.012468272690642435`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[43]//TableForm="]
}, Open  ]],

Cell["\<\
With linkage disequilibrium 0.05 and \"F\"=0.3, the simulations \
again fit reasonably well. There is still an upwards bias in using the jpg \
method.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dp = makePop[4, 0.75, 0.05, 0.3];\)\), "\[IndentingNewLine]", 
    \(\(0.3\/2\) \((2  
              p \((1 - p)\) - \(MakeHaploid[
                  dp]\)\[LeftDoubleBracket]1\[RightDoubleBracket] . 
              Table[HeterozygoteB[i, i, 4] . Range[0, 1, 1\/4], {i, 0, 
                  4}])\) /. p \[Rule] 0.75\)}], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    \(0.0253125`\)], "Output",
  CellLabel->"Out[185]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(st1 = simulate[dp, 10, 24, 100];\)\), "\n", 
    \(printResults[st1] // TableForm\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"pqF\"\>", "\<\"D\"\>", "\<\"AM\"\>"},
          {"\<\"mean\"\>", "0.026855971498842602`", 
            "0.0544204535590278`", \(-0.00421752387152778`\)},
          {"\<\"mean (jpg)\"\>", "0.02978512369791667`", 
            "0.05056699580439813`", \(-0.00297529296875`\)},
          {"\<\"sd\"\>", "0.0186084921073658`", "0.026024403603362282`", 
            "0.013049888602169653`"},
          {"\<\"sd (jpg)\"\>", "0.016635009391017516`", 
            "0.025019312063301487`", "0.012385747223703164`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[250]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions used in simulations", "SubsubsectionIcon"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Utilities`RandomNumbers`;\)], "Input",\

  CellLabel->"In[3]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(makePop::usage = "\<makePop[n,p,D,F] makes a diploid population with \
disequilibrium D, and heterozygite deficit F\>";\)\)], "Input",
  CellLabel->"In[4]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(makePop[n_Integer, p_, d_, f_] := 
        Module[{hp, \[Alpha], j}, \[IndentingNewLine]hp = 
            If[d == 0, \[IndentingNewLine]MakePopulation[n, p, 1, 
                NumericalModel \[Rule] 
                  SymmetricHaploidFrequencies], \[IndentingNewLine]\[Alpha] = \
\(p \((1 - p)\)\)\/d - 1; \[IndentingNewLine]SymmetricHaploidFrequencies[
                Table[PDF[NegativeHypergeometricDistribution[n, p, \[Alpha]], 
                    j], {j, 0, n}], 
                1]]; \[IndentingNewLine]SymmetricDiploidFrequencies[\(\
MakeDiploid[hp]\)\[LeftDoubleBracket]1\[RightDoubleBracket] \((1 - f)\) + 
              f*DiagonalMatrix[hp\[LeftDoubleBracket]1\[RightDoubleBracket]], 
            1]];\)\)], "Input",
  CellLabel->"In[120]:=",
  InitializationCell->True],

Cell[TextData[{
  "If a negative hypergeometric disribution is chosen,with parameter \
\[Alpha], then D is just ",
  Cell[BoxData[
      \(TraditionalForm\`pq\/\(1 + \[Alpha]\)\)]]
}], "Text"],

Cell[BoxData[
    \(\(DrawFamilies::usage = "\<DrawFamilies[SymmetricDiploidFrequencies[\
\[Ellipsis]],k,n] draws n families,each of k members, from the specified \
population\>";\)\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawFamilies[dp_SymmetricDiploidFrequencies, k_Integer, n_Integer] := 
        Module[{pop, rf, 
            j}, \[IndentingNewLine]Table[\[IndentingNewLine]pop = 
              MakeIndividuals[dp, 2]; \[IndentingNewLine]rf = 
              RandomFamily[pop\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
                pop\[LeftDoubleBracket]1, 2\[RightDoubleBracket], 
                k]; \[IndentingNewLine]\(\((Plus @@ #)\) &\) /@ rf, {j, 
              n}]];\)\)], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(simulate::usage = \*"\"\<simulate[pop,k,n,nreps] generates a table of \
nreps replicates, and lists for each {\!\(c\_\(0, \\\\\\\ 0, \\\\\\\ 1, \
\\\\\\\ 1\)\),\!\(c\_\(0, \\\\\\\ 0, \\\\\\\ 1, \\\\\\\ \
1\)\%jpg\),\!\(c\_\(0, \\\\\\\ 0, \\\\\\\ 0, \\\\\\\ 2\)\),\!\(c\_\(0, \\\\\\\
\ 0, \\\\\\\ 0, \\\\\\\ 2\)\%jpg\),\!\(c\_\(0, \\\\\\\ 1, \\\\\\\ 0, \\\\\\\ \
1\)\),\!\(c\_\(0, \\\\\\\ 1, \\\\\\\ 01, \\\\\\\ 1\)\%jpg\)}.  The population \
is of the form SymmetricDiploidFrequencies[]\>\"";\)\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(simulate[pop_, k_, n_, nr_] := 
        Module[{rep, simdata, pp}, \[IndentingNewLine]Table[
            Print[rep]; \[IndentingNewLine]simdata = 
              DrawFamilies[pop, k, n]; \[IndentingNewLine]pp = 
              FamilyAlleleFrequencyEstimate[simdata] // 
                N; \[IndentingNewLine]{EstimateFamilyMoments[simdata, 
                c[0, 0, 1, 1], pp], \[IndentingNewLine]EstimateFamilyMoments[
                simdata, c[0, 0, 1, 1], pp, 
                InferParentalGenotypes \[Rule] 
                  True], \[IndentingNewLine]EstimateFamilyMoments[simdata, 
                c[0, 0, 0, 2], pp], \[IndentingNewLine]EstimateFamilyMoments[
                simdata, c[0, 0, 0, 2], pp, 
                InferParentalGenotypes \[Rule] 
                  True], \[IndentingNewLine]EstimateFamilyMoments[simdata, 
                c[0, 1, 0, 1], pp], \[IndentingNewLine]EstimateFamilyMoments[
                simdata, c[0, 1, 0, 1], pp, 
                InferParentalGenotypes \[Rule] True]}, {rep, 
              nr}]];\)\)], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(printResults::usage = "\<printResults[simtable] prints results \
neatly.\>";\)\)], "Input",
  CellLabel->"In[10]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(printResults[st_] := 
        Prepend[Transpose[
            Prepend[Transpose[
                Transpose[Partition[Mean[st], 2]]\[Vee]Transpose[
                    Partition[StandardDeviation[st], 
                      2]]], {"\<mean\>", "\<mean (jpg)\>", "\<sd\>", "\<sd \
(jpg)\>"}]], {"\<\>", "\<pqF\>", "\<D\>", "\<AM\>"}];\)\)], "Input",
  CellLabel->"In[11]:=",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{1004, 686},
WindowMargins->{{43, Automatic}, {Automatic, 13}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "FamilyAlleleFrequencyEstimate"->{
    Cell[13116, 236, 326, 6, 38, "DefinitionBox",
      CellTags->"FamilyAlleleFrequencyEstimate"]},
  "FamilyEffects"->{
    Cell[14123, 271, 1333, 21, 112, "DefinitionBox",
      CellTags->{"FamilyEffects", "FamilyM"}]},
  "FamilyM"->{
    Cell[14123, 271, 1333, 21, 112, "DefinitionBox",
      CellTags->{"FamilyEffects", "FamilyM"}]},
  "EstimateFamilyMoments"->{
    Cell[17660, 354, 367, 7, 38, "DefinitionBox",
      CellTags->"EstimateFamilyMoments"]},
  "InferParentalGenotypes"->{
    Cell[19734, 428, 499, 9, 52, "DefinitionBox",
      CellTags->"InferParentalGenotypes"]},
  "MToC"->{
    Cell[22297, 510, 418, 8, 56, "DefinitionBox",
      CellTags->"MToC"]},
  "MVariables"->{
    Cell[30613, 748, 491, 11, 56, "DefinitionBox",
      CellTags->"MVariables"]},
  "MFromC"->{
    Cell[36734, 899, 722, 15, 76, "DefinitionBox",
      CellTags->{"MFromC", "MToCEquations"}]},
  "MToCEquations"->{
    Cell[36734, 899, 722, 15, 76, "DefinitionBox",
      CellTags->{"MFromC", "MToCEquations"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"FamilyAlleleFrequencyEstimate", 147844, 4677},
  {"FamilyEffects", 147966, 4680},
  {"FamilyM", 148082, 4683},
  {"EstimateFamilyMoments", 148212, 4686},
  {"InferParentalGenotypes", 148335, 4689},
  {"MToC", 148441, 4692},
  {"MVariables", 148535, 4695},
  {"MFromC", 148632, 4698},
  {"MToCEquations", 148751, 4701}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 82, 1, 36, "SubsectionIcon"],
Cell[1824, 54, 932, 18, 64, "Text"],
Cell[2759, 74, 88, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[2872, 80, 41, 0, 24, "SubsubsectionIcon"],
Cell[2916, 82, 129, 3, 28, "MathCaption"],
Cell[3048, 87, 9970, 142, 345, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13055, 234, 58, 0, 20, "SubsubsectionIcon"],
Cell[13116, 236, 326, 6, 38, "DefinitionBox",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[13445, 244, 176, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13646, 252, 108, 2, 26, "Input"],
Cell[13757, 256, 199, 4, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[14005, 266, 115, 3, 20, "SubsubsectionIcon"],
Cell[14123, 271, 1333, 21, 112, "DefinitionBox",
  CellTags->{"FamilyEffects", "FamilyM"}],
Cell[15459, 294, 371, 7, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[15855, 305, 151, 3, 26, "Input"],
Cell[16009, 310, 1125, 21, 95, "Output"]
}, Open  ]],
Cell[17149, 334, 294, 7, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[17468, 345, 97, 2, 26, "Input"],
Cell[17568, 349, 77, 2, 20, "Output"]
}, Open  ]],
Cell[17660, 354, 367, 7, 38, "DefinitionBox",
  CellTags->"EstimateFamilyMoments"],
Cell[18030, 363, 219, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18274, 373, 109, 2, 26, "Input"],
Cell[18386, 377, 79, 2, 20, "Output"]
}, Open  ]],
Cell[18480, 382, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18589, 387, 109, 2, 26, "Input"],
Cell[18701, 391, 78, 2, 20, "Output"]
}, Open  ]],
Cell[18794, 396, 121, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18940, 403, 109, 2, 26, "Input"],
Cell[19052, 407, 84, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[19185, 415, 72, 0, 20, "SubsubsectionIcon"],
Cell[19260, 417, 471, 9, 38, "Text"],
Cell[19734, 428, 499, 9, 52, "DefinitionBox",
  CellTags->"InferParentalGenotypes"],
Cell[20236, 439, 240, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20501, 449, 219, 4, 42, "Input"],
Cell[20723, 455, 104, 2, 20, "Output"]
}, Open  ]],
Cell[20842, 460, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20964, 467, 219, 4, 42, "Input"],
Cell[21186, 473, 103, 2, 20, "Output"]
}, Open  ]],
Cell[21304, 478, 125, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[21454, 485, 219, 4, 42, "Input"],
Cell[21676, 491, 115, 2, 20, "Output"]
}, Open  ]],
Cell[21806, 496, 412, 7, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[22255, 508, 39, 0, 20, "SubsubsectionIcon"],
Cell[22297, 510, 418, 8, 56, "DefinitionBox",
  CellTags->"MToC"],
Cell[22718, 520, 376, 6, 36, "Text"],
Cell[23097, 528, 129, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[23251, 537, 145, 4, 26, "Input"],
Cell[23399, 543, 3393, 66, 642, "Output"]
}, Closed]],
Cell[26807, 612, 224, 6, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[27056, 622, 145, 3, 26, "Input"],
Cell[27204, 627, 606, 13, 79, "Output"]
}, Open  ]],
Cell[27825, 643, 175, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[28025, 653, 160, 3, 26, "Input"],
Cell[28188, 658, 615, 12, 79, "Output"]
}, Open  ]],
Cell[28818, 673, 248, 6, 22, "Text"],
Cell[29069, 681, 99, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[29193, 688, 180, 4, 26, "Input"],
Cell[29376, 694, 126, 3, 32, "Output"]
}, Open  ]],
Cell[29517, 700, 125, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[29667, 707, 180, 4, 26, "Input"],
Cell[29850, 713, 125, 3, 32, "Output"]
}, Open  ]],
Cell[29990, 719, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[30115, 726, 180, 4, 26, "Input"],
Cell[30298, 732, 122, 3, 32, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[30469, 741, 43, 0, 20, "SubsubsectionIcon"],
Cell[30515, 743, 95, 3, 22, "Text"],
Cell[30613, 748, 491, 11, 56, "DefinitionBox",
  CellTags->"MVariables"],
Cell[31107, 761, 153, 3, 22, "Text"],
Cell[31263, 766, 2143, 47, 55, "NumberedEquation"],
Cell[33409, 815, 277, 5, 36, "Text"],
Cell[33689, 822, 641, 15, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[34355, 841, 92, 2, 26, "Input"],
Cell[34450, 845, 1137, 16, 110, "Output"]
}, Open  ]],
Cell[35602, 864, 64, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[35691, 868, 95, 2, 26, "Input"],
Cell[35789, 872, 110, 2, 20, "Output"]
}, Open  ]],
Cell[35914, 877, 817, 20, 23, "Text"],
Cell[36734, 899, 722, 15, 76, "DefinitionBox",
  CellTags->{"MFromC", "MToCEquations"}],
Cell[37459, 916, 1100, 20, 46, "MathCaption"],

Cell[CellGroupData[{
Cell[38584, 940, 84, 2, 26, "Input"],
Cell[38671, 944, 113, 2, 20, "Output"]
}, Open  ]],
Cell[38799, 949, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[38922, 956, 114, 2, 26, "Input"],
Cell[39039, 960, 16687, 539, 70, "Output"]
}, Closed]],
Cell[55741, 1502, 74, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[55840, 1506, 119, 3, 26, "Input"],
Cell[55962, 1511, 1326, 43, 79, "Output"]
}, Open  ]],
Cell[57303, 1557, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[57430, 1564, 95, 2, 26, "Input"],
Cell[57528, 1568, 441, 9, 104, "Output"]
}, Open  ]],
Cell[57984, 1580, 200, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[58209, 1588, 95, 2, 26, "Input"],
Cell[58307, 1592, 270, 6, 20, "Print"],
Cell[58580, 1600, 202, 4, 20, "Print"],
Cell[58785, 1606, 61, 2, 20, "Output"]
}, Open  ]],
Cell[58861, 1611, 132, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[59018, 1618, 136, 3, 26, "Input"],
Cell[59157, 1623, 3568, 115, 175, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62762, 1743, 109, 2, 26, "Input"],
Cell[62874, 1747, 209, 4, 20, "Output"]
}, Open  ]],
Cell[63098, 1754, 136, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63259, 1761, 80, 2, 26, "Input"],
Cell[63342, 1765, 165, 3, 20, "Output"]
}, Open  ]],
Cell[63522, 1771, 191, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63738, 1779, 121, 3, 26, "Input"],
Cell[63862, 1784, 1488, 28, 254, "Output"]
}, Open  ]],
Cell[65365, 1815, 156, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[65558, 1823, 57, 0, 20, "SubsubsectionIcon"],
Cell[65618, 1825, 308, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[65951, 1835, 287, 7, 58, "Input"],
Cell[66241, 1844, 790, 17, 95, "Output"]
}, Open  ]],
Cell[67046, 1864, 72, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[67143, 1868, 213, 4, 58, "Input"],
Cell[67359, 1874, 785, 17, 95, "Output"]
}, Open  ]],
Cell[68159, 1894, 700, 13, 62, "Text"],

Cell[CellGroupData[{
Cell[68884, 1911, 259, 5, 41, "Input"],
Cell[69146, 1918, 81, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69264, 1925, 211, 4, 58, "Input"],
Cell[69478, 1931, 785, 18, 95, "Output"]
}, Open  ]],
Cell[70278, 1952, 174, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[70477, 1960, 378, 7, 59, "Input"],
Cell[70858, 1969, 70, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70965, 1976, 118, 2, 42, "Input"],
Cell[71086, 1980, 771, 17, 95, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[71906, 2003, 60, 0, 24, "SubsubsectionIcon"],
Cell[71969, 2005, 147, 4, 26, "Input",
  InitializationCell->True],
Cell[72119, 2011, 208, 4, 26, "Input",
  InitializationCell->True],
Cell[72330, 2017, 804, 14, 136, "Input",
  InitializationCell->True],
Cell[73137, 2033, 192, 5, 26, "Text"],
Cell[73332, 2040, 246, 5, 42, "Input",
  InitializationCell->True],
Cell[73581, 2047, 553, 10, 90, "Input",
  InitializationCell->True],
Cell[74137, 2059, 581, 9, 49, "Input",
  InitializationCell->True],
Cell[74721, 2070, 1127, 20, 170, "Input",
  InitializationCell->True],
Cell[75851, 2092, 166, 4, 26, "Input",
  InitializationCell->True],
Cell[76020, 2098, 420, 9, 58, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

