(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42835,       1188]*)
(*NotebookOutlinePosition[     43745,       1217]*)
(*  CellTagsIndexPosition[     43701,       1213]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["An example: epistatic selection against heterozygotes", "SubsectionIcon"],

Cell[TextData[{
  "\tIn this example, epistatic selection acts against heterozygotes, such \
that ",
  Cell[BoxData[
      \(TraditionalForm\`W = \((1 - s)\)\^4\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " being the number of heterozygous loci.  There are 20 demes and 3 genes; ",
  
  Cell[BoxData[
      \(TraditionalForm\`m = 0.5\)]],
  ", s=1%.  With these parameters, the fitmnesses of genotypes with {0, 1, 2, \
3} heterozygous loci are {1, 0.99, 0.85, 0.44} respectively."
}], "Text"],

Cell[BoxData[
    \(\(\(hetWfull[s_, k_]\)[_]\)[X_, Y_] := 
      \((1 - s)\)\^\(CountHeterozygotes[X, Y]\^k\); \n
    StoreExact[\[Psi], hetWfull[0.01, 4], 0.5, {200, 50}, {20, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True]; \)], "Input",
  CellLabel->"In[182]:="],

Cell["\<\
Cline width reaches equilibrium at w=5.31 for all 3 loci within 200 \
generations\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, 
            ClineWidth[\[Psi][t], SymmetricModel \[Rule] False, 
              SortByClass \[Rule] True]} // Flatten, {t, 0, 200, 50}] // 
      TableForm\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1", "1", "1"},
          {"50", "5.20775486910014517`", "5.20775486910014695`", 
            "5.20775486910014695`"},
          {"100", "5.29734636763913169`", "5.29734636763913169`", 
            "5.29734636763913524`"},
          {"150", "5.30619373083351941`", "5.30619373083352208`", 
            "5.3061937308335203`"},
          {"200", "5.30728884369828612`", "5.30728884369828612`", 
            "5.30728884369828168`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[183]//TableForm="]
}, Open  ]],

Cell["\<\
These results can be compared with the symmetric model.  Note that \
the fitness is now defined as a function W[i,j,h] not W[Y,Z].\
\>", "Text"],

Cell[BoxData[
    \(\(\(hetW[s_, k_]\)[_]\)[_, _, h_] := \((1 - s)\)\^\(h\^k\); \n
    StoreExact[\[Psi]E, hetW[0.01, 4], 0.5, {200, 50}, {20, 3}, 
      Compiled \[Rule] True]; \)], "Input",
  CellLabel->"In[184]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, ClineWidth[\[Psi]E[t]]}, {t, 0, 200, 50}] // TableForm\)], 
  "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1"},
          {"50", "5.20775486910014429`"},
          {"100", "5.29734636763913524`"},
          {"150", "5.30619373083352829`"},
          {"200", "5.30728884369828612`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[185]//TableForm="]
}, Open  ]],

Cell["\<\
Under this model, there is a severe loss of fitness only when \
several loci are heterozygous.  Thus, the symmetric solution is unstable: if \
the initial state is slightly perturbed, the clines scatter, and become much \
wider.  The logit-transformed genotype frequencies are perturbed from their \
values at the symmetric equilibrium, and renormalised:\
\>", "Text"],

Cell[BoxData[
    \(ff[x_, a_] := 1/\((1 + Exp[Log[1/x - 1] + a \((Random[] - 0.5)\)])\); \n
    \[Psi]R[0] = Map[ff[#, 0.1]&, \[Psi][200], 2]; 
    \[Psi]R0 = \[Psi]R0/\((\(\((Plus@@#)\)&\)/@\[Psi]R0)\); \n
    pR[t_] := 
      MeanP[\[Psi]R[t], SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]; \)], "Input",
  CellLabel->"In[206]:="],

Cell[BoxData[
    \(\(Do[
      \[Psi]R[t] = 
        Nest[IterateExact[#, hetWfull[0.01, 4], 0.5, 
              SymmetricModel \[Rule] False, Compiled \[Rule] True, 
              SortByClass \[Rule] True]&, \[Psi]R[t - 100], 100], {t, 100, 
        500, 100}]; \)\)], "Input",
  CellLabel->"In[209]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Graphics`Colors`; \n
    gr[t_, c_] := 
      \(ListPlot[#, PlotJoined -> True, PlotStyle \[Rule] c, 
            DisplayFunction \[Rule] Identity]&\)/@Transpose[pR[t]]; \n
    Show[gr[0, Black], gr[100, Blue], gr[200, Purple], gr[300, Green], 
      gr[400, Orange], gr[500, Red], 
      DisplayFunction \[Rule] $DisplayFunction]; \)], "Input",
  CellLabel->"In[212]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.588724 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13246 -18 -4.5 ]
[.01131 .13246 0 4.5 ]
[.01131 .2502 -18 -4.5 ]
[.01131 .2502 0 4.5 ]
[.01131 .36795 -18 -4.5 ]
[.01131 .36795 0 4.5 ]
[.01131 .48569 -18 -4.5 ]
[.01131 .48569 0 4.5 ]
[.01131 .60344 -6 -4.5 ]
[.01131 .60344 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13246 m
.03006 .13246 L
s
[(0.2)] .01131 .13246 1 0 Mshowa
.02381 .2502 m
.03006 .2502 L
s
[(0.4)] .01131 .2502 1 0 Mshowa
.02381 .36795 m
.03006 .36795 L
s
[(0.6)] .01131 .36795 1 0 Mshowa
.02381 .48569 m
.03006 .48569 L
s
[(0.8)] .01131 .48569 1 0 Mshowa
.02381 .60344 m
.03006 .60344 L
s
[(1)] .01131 .60344 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07359 m
.02756 .07359 L
s
.02381 .10302 m
.02756 .10302 L
s
.02381 .1619 m
.02756 .1619 L
s
.02381 .19133 m
.02756 .19133 L
s
.02381 .22077 m
.02756 .22077 L
s
.02381 .27964 m
.02756 .27964 L
s
.02381 .30908 m
.02756 .30908 L
s
.02381 .33851 m
.02756 .33851 L
s
.02381 .39739 m
.02756 .39739 L
s
.02381 .42682 m
.02756 .42682 L
s
.02381 .45626 m
.02756 .45626 L
s
.02381 .51513 m
.02756 .51513 L
s
.02381 .54457 m
.02756 .54457 L
s
.02381 .574 m
.02756 .574 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
.07143 .03016 m
.11905 .0312 L
.16667 .03354 L
.21429 .03857 L
.2619 .04498 L
.30952 .06055 L
.35714 .07584 L
.40476 .1127 L
.45238 .16545 L
.5 .24523 L
.54762 .35586 L
.59524 .46451 L
.64286 .51978 L
.69048 .52849 L
.7381 .56313 L
.78571 .56125 L
.83333 .57537 L
.88095 .58789 L
.92857 .58153 L
.97619 .58601 L
s
.07143 .03056 m
.11905 .03051 L
.16667 .03325 L
.21429 .03769 L
.2619 .04553 L
.30952 .0574 L
.35714 .07891 L
.40476 .11093 L
.45238 .16214 L
.5 .24925 L
.54762 .3539 L
.59524 .45991 L
.64286 .51937 L
.69048 .5314 L
.7381 .56359 L
.78571 .56143 L
.83333 .57602 L
.88095 .58725 L
.92857 .58123 L
.97619 .5852 L
s
.07143 .03049 m
.11905 .03034 L
.16667 .03412 L
.21429 .03862 L
.2619 .04575 L
.30952 .05779 L
.35714 .07501 L
.40476 .1092 L
.45238 .16387 L
.5 .25024 L
.54762 .3523 L
.59524 .45745 L
.64286 .52292 L
.69048 .52991 L
.7381 .56218 L
.78571 .56223 L
.83333 .57507 L
.88095 .58655 L
.92857 .58083 L
.97619 .58538 L
s
0 0 1 r
.07143 .03062 m
.11905 .03199 L
.16667 .0349 L
.21429 .03981 L
.2619 .04752 L
.30952 .05959 L
.35714 .07905 L
.40476 .1121 L
.45238 .17017 L
.5 .26306 L
.54762 .37387 L
.59524 .46324 L
.64286 .51697 L
.69048 .54654 L
.7381 .56358 L
.78571 .57406 L
.83333 .58074 L
.88095 .58498 L
.92857 .58752 L
.97619 .5887 L
s
.07143 .02994 m
.11905 .0312 L
.16667 .0339 L
.21429 .03843 L
.2619 .04556 L
.30952 .05673 L
.35714 .07484 L
.40476 .10597 L
.45238 .1617 L
.5 .25276 L
.54762 .36364 L
.59524 .45496 L
.64286 .51106 L
.69048 .54252 L
.7381 .56088 L
.78571 .57223 L
.83333 .57947 L
.88095 .58407 L
.92857 .58682 L
.97619 .5881 L
s
.07143 .02953 m
.11905 .03073 L
.16667 .03329 L
.21429 .03758 L
.2619 .04433 L
.30952 .05492 L
.35714 .07215 L
.40476 .102 L
.45238 .15614 L
.5 .2459 L
.54762 .35673 L
.59524 .44928 L
.64286 .50695 L
.69048 .5397 L
.7381 .55896 L
.78571 .57091 L
.83333 .57854 L
.88095 .5834 L
.92857 .58628 L
.97619 .58763 L
s
.628 .126 .941 r
.07143 .03775 m
.11905 .04025 L
.16667 .04563 L
.21429 .0547 L
.2619 .06889 L
.30952 .09065 L
.35714 .12395 L
.40476 .17502 L
.45238 .25123 L
.5 .35136 L
.54762 .45116 L
.59524 .52049 L
.64286 .55653 L
.69048 .57357 L
.7381 .5822 L
.78571 .58709 L
.83333 .59008 L
.88095 .59195 L
.92857 .59307 L
.97619 .59359 L
s
.07143 .02903 m
.11905 .03018 L
.16667 .03263 L
.21429 .03679 L
.2619 .04342 L
.30952 .05405 L
.35714 .07168 L
.40476 .10247 L
.45238 .15711 L
.5 .24441 L
.54762 .35072 L
.59524 .44204 L
.64286 .50183 L
.69048 .5369 L
.7381 .55757 L
.78571 .57023 L
.83333 .5782 L
.88095 .58321 L
.92857 .58617 L
.97619 .58755 L
s
.07143 .0251 m
.11905 .02569 L
.16667 .02696 L
.21429 .02909 L
.2619 .0325 L
.30952 .03806 L
.35714 .04779 L
.40476 .06659 L
.45238 .10519 L
.5 .17727 L
.54762 .27856 L
.59524 .37806 L
.64286 .45225 L
.69048 .50107 L
.7381 .53244 L
.78571 .55274 L
.83333 .56592 L
.88095 .5743 L
.92857 .57927 L
.97619 .58159 L
s
0 1 0 r
.07143 .11114 m
.11905 .11963 L
.16667 .13699 L
.21429 .16396 L
.2619 .20143 L
.30952 .25009 L
.35714 .30955 L
.40476 .37689 L
.45238 .44537 L
.5 .50559 L
.54762 .54995 L
.59524 .57698 L
.64286 .59087 L
.69048 .59722 L
.7381 .60003 L
.78571 .60132 L
.83333 .60194 L
.88095 .60225 L
.92857 .6024 L
.97619 .60246 L
s
.07143 .02185 m
.11905 .0228 L
.16667 .02499 L
.21429 .0291 L
.2619 .03648 L
.30952 .04958 L
.35714 .07225 L
.40476 .10944 L
.45238 .16516 L
.5 .2389 L
.54762 .32299 L
.59524 .4045 L
.64286 .47173 L
.69048 .51976 L
.7381 .55057 L
.78571 .5691 L
.83333 .57991 L
.88095 .58613 L
.92857 .58952 L
.97619 .59103 L
s
.07143 .01598 m
.11905 .01609 L
.16667 .01634 L
.21429 .01685 L
.2619 .01781 L
.30952 .01971 L
.35714 .02355 L
.40476 .03148 L
.45238 .04753 L
.5 .07734 L
.54762 .12532 L
.59524 .19002 L
.64286 .26289 L
.69048 .33307 L
.7381 .39316 L
.78571 .44064 L
.83333 .47603 L
.88095 .50083 L
.92857 .5165 L
.97619 .52407 L
s
1 .5 0 r
.07143 .30366 m
.11905 .31347 L
.16667 .33273 L
.21429 .36061 L
.2619 .39559 L
.30952 .4352 L
.35714 .47589 L
.40476 .51356 L
.45238 .54472 L
.5 .56772 L
.54762 .58298 L
.59524 .59223 L
.64286 .59745 L
.69048 .60026 L
.7381 .60174 L
.78571 .60251 L
.83333 .60292 L
.88095 .60313 L
.92857 .60324 L
.97619 .60329 L
s
.07143 .01959 m
.11905 .02125 L
.16667 .02513 L
.21429 .03244 L
.2619 .04515 L
.30952 .06587 L
.35714 .09724 L
.40476 .14076 L
.45238 .19584 L
.5 .25964 L
.54762 .32772 L
.59524 .39481 L
.64286 .45544 L
.69048 .50509 L
.7381 .54175 L
.78571 .56632 L
.83333 .58149 L
.88095 .59026 L
.92857 .59493 L
.97619 .59693 L
s
.07143 .01493 m
.11905 .015 L
.16667 .01515 L
.21429 .01545 L
.2619 .01599 L
.30952 .01698 L
.35714 .01877 L
.40476 .02201 L
.45238 .02783 L
.5 .03797 L
.54762 .05471 L
.59524 .0802 L
.64286 .11517 L
.69048 .15778 L
.7381 .20382 L
.78571 .24836 L
.83333 .28728 L
.88095 .31794 L
.92857 .33892 L
.97619 .34954 L
s
1 0 0 r
.07143 .53992 m
.11905 .5432 L
.16667 .5493 L
.21429 .55741 L
.2619 .56645 L
.30952 .57536 L
.35714 .58326 L
.40476 .58964 L
.45238 .59438 L
.5 .59767 L
.54762 .59982 L
.59524 .60117 L
.64286 .602 L
.69048 .60251 L
.7381 .60283 L
.78571 .60303 L
.83333 .60316 L
.88095 .60325 L
.92857 .6033 L
.97619 .60332 L
s
.07143 .03606 m
.11905 .04032 L
.16667 .04926 L
.21429 .06361 L
.2619 .08414 L
.30952 .11143 L
.35714 .14555 L
.40476 .18594 L
.45238 .23142 L
.5 .28034 L
.54762 .33071 L
.59524 .3804 L
.64286 .42726 L
.69048 .46933 L
.7381 .5051 L
.78571 .53373 L
.83333 .55519 L
.88095 .57006 L
.92857 .57925 L
.97619 .5836 L
s
.07143 .0149 m
.11905 .01493 L
.16667 .01499 L
.21429 .0151 L
.2619 .01526 L
.30952 .01552 L
.35714 .01591 L
.40476 .01654 L
.45238 .01757 L
.5 .01923 L
.54762 .0219 L
.59524 .02601 L
.64286 .03201 L
.69048 .04013 L
.7381 .05023 L
.78571 .06167 L
.83333 .07328 L
.88095 .08367 L
.92857 .09149 L
.97619 .09568 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[212]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool005Aoo`<003Yoo`<000Aoo`8003Qoo`<000=oo`<003Qoo`@000=oo`8000Aoo`00Egoo00<007oo
Ool0>7oo00<007ooOol00Woo00@007ooOol003Qoo`03001oogoo00Eoo`03001oogoo03Ioo`03001o
ogoo009oo`04001oogoo0003Ool005Moo`03001oogoo03Qoo`03001oogoo009oo`04001oogoo000h
Ool00`00Oomoo`05Ool00`00Oomoo`0gOol01@00Oomoogoo00000Woo00<007ooOol00Goo001DOol3
000kOol00`00Oomoo`02Ool01000Oomoo`00>7oo00<007ooOol00Woo0`00>goo00@007ooOol0009o
o`03001oogoo005oo`00E7oo00<007ooOol0>goo00<007ooOol00Woo00@007ooOol003Qoo`03001o
ogoo009oo`03001oogoo03Qoo`04001oogoo0002Ool01000Oomoo`000goo001DOol4000iOol20005
Ool2000hOol20004Ool4000hOol20004Ool20004Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<0
07ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`003goo4`00
Hg`0VP000Goo000EOol00`00Oomoo`0:Ool8ON05Ool00`00Oomoo`0:Ool00`00Oomoo`05OolJ0n0J
ON05Ool00`00Oomoo`05OolIO005Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`05Ool001Eoo`03001oogoo00Yoo`P3h0emh1moo`03001oogoo019o
o`P3h0Eoo`Umh1Eoo`03001oogoo00Eoo`el02aoo`03001oogoo03ioo`03001oogoo00Eoo`005Goo
00<007ooOol02Woo5E2N2GgP10?P;goo1@?P2Goo1ggP8goo2G`0K7oo000EOol00`00Oomoo`0:OolE
D9h9Ool7ON060n04D9hWOol40n0<Ool6ON0VOol7O01UOol001Eoo`03001oogoo019oo`d07`e@WP=o
o`Emh003Ool3h0?P00D3h0Y@WQioo`@3h0ioo`Imh2Moo`Il05moo`005Goo00<007ooOol02Woo27`0
5Woo100O252N1GgP0goo1@?P1Goo252N6Woo0`?P4Goo17gP:Goo1g`0F7oo000EOol00`00Oomoo`0B
Ool9O004D9h@Ool601l4D9h4ON04Ool50n08Ool5D9hHOol30n0BOol3ON0]Ool5O01COol001Eoo`80
01aoo`Ml00E@WPioo`L07`05D9imh7gPON1@WP05Ool40n09Ool4D9hGOol30n0BOol3ON0_Ool5O01>
Ool001Eoo`03001oogoo029oo`El00E@WQ1oo`@07`9mh0A@WPAoo`<3h0Yoo`=@WQMoo`<3h19oo`9m
h39oo`Al04Yoo`005Goo00<007ooOol09goo0g`00Woo152N4Goo00<07ggPON000P0O152N0goo0P?P
2goo0e2N5goo00<3h7ooOol04Goo0ggP<goo17`0AWoo000EOol00`00Oomoo`0ZOol3O003Ool4D9h@
Ool3ON0301l4D9h00goo0n03h00<Ool3D9hEOol20n0DOol2ON0eOol5O011Ool001Eoo`03001oogoo
02eoo`=l00Aoo`=@WQ1oo`9mh003Ool07`0O00807`=@WP83h0eoo`9@WQEoo`030n1oogoo01=oo`9m
h3Qoo`Al03eoo`005Goo00<007ooOol0<7oo0g`017oo0e2N3goo0WgP0Woo100O0U2N00<3h7ooOol0
37oo0e2N4goo0P?P5Goo0WgP>Woo17`0>Goo000EOol00`00Oomoo`0cOol2O005Ool3D9h>Ool2ON03
Ool401l20n000e2NOomoo`0<Ool2D9hCOol00`?POomoo`0DOol2ON0lOol5O00dOol001Eoo`03001o
ogoo03Eoo`9l00Ioo`=@WPeoo`03ON1oogoo00=oo`<07`83h09@WPeoo`03D9ioogoo015oo`83h1Io
o`03ON1oogoo03ioo`Al031oo`005Goo0P00>7oo0g`01Woo0U2N37oo0WgP1Goo0`0O0P?P00=@WWoo
Ool02goo00=@WWooOol04Woo00<3h7ooOol057oo0WgP@Woo17`0;7oo000EOol00`00Oomoo`0jOol2
O006Ool2D9h<Ool2ON06Ool201l00`?PD9i@WP0<Ool00e2NOomoo`0BOol00`?POomoo`0EOol2ON14
Ool5O00WOol001Eoo`03001oogoo03aoo`9l00Ioo`=@WP]oo`03ON1oogoo00Eoo`0401l3h00OD9h<
Ool00e2NOomoo`0BOol00`?POomoo`0FOol2ON17Ool4O00SOol001Eoo`03001oogoo03ioo`9l00Mo
o`9@WPYoo`9mh0Ioo`0301l3h0?P009@WP]oo`9@WQ=oo`030n1oogoo01Moo`03ON1oogoo04Qoo`El
01ioo`005Goo00<007ooOol0@7oo0W`01goo0U2N2Woo0WgP1Goo00D0000O0n007e2N00aoo`03D9io
ogoo015oo`030n1oogoo01Moo`9mh4eoo`Ml01Moo`005Goo00<007ooOol0@Woo0W`01goo0U2N2Woo
00=mh7ooOol017oo00@07`?P01m@WPaoo`03D9ioogoo015oo`030n1oogoo01Qoo`03ON1oogoo055o
o`Yl00eoo`005Goo00<007ooOol0A7oo0W`01goo00=@WWooOol027oo0WgP1Goo00<000?P01l00U2N
2goo00=@WWooOol04Goo00<3h7ooOol067oo0WgPFgoo1W`01goo000EOol00`00Oomoo`16Ool00g`0
Oomoo`05Ool2D9h:Ool00ggPOomoo`03Ool01@000n03h00OD9h02goo00=@WWooOol04Goo00<3h7oo
Ool06Goo00=mh7ooOol0IGoo000EOol20018Ool2O007Ool00e2NOomoo`08Ool00ggPOomoo`03Ool0
1@0001l3h00OD9h02goo00=@WWooOol04Goo00<3h7ooOol06Goo00=mh7ooOol0I7oo000EOol00`00
Oomoo`19Ool2O006Ool2D9h9Ool00ggPOomoo`04Ool00`000n1@WP0<Ool00e2NOomoo`0AOol00`?P
Oomoo`0IOol2ON1TOol001Eoo`03001oogoo00Yoo`@3h3eoo`9l00Ioo`03D9ioogoo00Moo`03ON1o
ogoo00Aoo`030003h52N00]oo`03D9ioogoo019oo`030n1oogoo01Yoo`03ON1oogoo065oo`005Goo
00<007ooOol03Woo1`?P>7oo00=l07ooOol017oo00=@WWooOol01goo00=mh7ooOol017oo00<3h00O
D9h02goo00=@WWooOol04Woo00<3h7ooOol06Woo0WgPHGoo000EOol00`00Oomoo`0EOol40n0eOol0
0g`0Oomoo`04Ool2D9h8Ool00ggPOomoo`03Ool010000n007e2N2goo00=@WWooOol04Woo00<3h7oo
Ool06goo00=mh7ooOol0GWoo000EOol00`00Oomoo`0IOol30n0cOol2O006Ool00e2NOomoo`06Ool0
0ggPOomoo`03Ool010000n007e2N2Woo00=@WWooOol04goo00<3h7ooOol06goo00=mh7ooOol0GGoo
0002Ool20004Ool20003Ool40004Ool00`00Oomoo`0LOol30n0bOol00g`0Oomoo`04Ool00e2NOomo
o`06Ool00ggPOomoo`03Ool010000n007e2N2Woo00=@WWooOol04goo00<3h7ooOol06goo00=mh7oo
Ool0G7oo00001Goo001oogoo00000goo0P0017oo00<007ooOol017oo00<007ooOol07goo0P?P<Goo
00=l07ooOol00goo00=@WWooOol01goo00=mh7ooOol00goo00@000?P01m@WPUoo`03D9ioogoo01=o
o`030n1oogoo01aoo`03ON1oogoo05]oo`0000Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`<0025o
o`<3h2moo`03O01oogoo00=oo`03D9ioogoo00Moo`03ON1oogoo00=oo`0401l3h00OD9h9Ool00e2N
Oomoo`0COol00`?POomoo`0LOol00ggPOomoo`1JOol00005Ool007ooOol0000;Ool00`00Oomoo`02
Ool00`00Oomoo`0TOol20n0^Ool2O004Ool00e2NOomoo`07Ool00ggPOomoo`03Ool0100O0n1@WP0O
2Goo00=@WWooOol04goo00<3h7ooOol077oo00=mh7ooOol0FGoo00001Goo001oogoo000027oo00@0
07ooOol000Aoo`03001oogoo02Ioo`030n1oogoo02eoo`03O01oogoo009oo`03D9ioogoo00Moo`03
ON1oogoo00=oo`0401l3h52N01l8Ool00e2NOomoo`0DOol00`?POomoo`0LOol00ggPOomoo`1HOol0
009oo`8000Yoo`8000Eoo`03001oogoo02Moo`83h2ioo`03O01oogoo009oo`03D9ioogoo00Ioo`03
ON1oogoo00Aoo`040n007e2N01l8Ool00e2NOomoo`0COol00`?POomoo`0MOol00ggPOomoo`1GOol0
01Eoo`03001oogoo02Uoo`83h2eoo`9l00=oo`03D9ioogoo00Ioo`03ON1oogoo00Aoo`040n007e2N
01l8Ool00e2NOomoo`0COol00`?POomoo`0MOol00ggPOomoo`1FOol001Eoo`03001oogoo02]oo`03
0n1oogoo02aoo`05O01oogooOom@WP08Ool00ggPOomoo`04Ool010?P01m@WP0O1goo00=@WWooOol0
57oo00<3h7ooOol07Goo00=mh7ooOol0EGoo000EOol00`00Oomoo`0/Ool20n0]Ool01G`0Oomoogoo
D9h027oo00=mh7ooOol00goo00D07`?P01m@WP0O00Moo`03D9ioogoo01=oo`030n1oogoo01ioo`03
ON1oogoo05Aoo`005Goo00<007ooOol0;Woo0P?P;7oo00El07ooOomooe2N00Qoo`03ON1oogoo00=o
o`0401l3h00OD9h8Ool00e2NOomoo`0COol00`?POomoo`0NOol2ON1DOol001Eoo`80035oo`030n1o
ogoo02Yoo`05O01oogooOom@WP08Ool00ggPOomoo`03Ool0100O0n1@WP0O1goo00=@WWooOol057oo
00<3h7ooOol07goo00=mh7ooOol0DGoo000EOol00`00Oomoo`0aOol20n0[Ool2O002Ool00e2NOomo
o`06Ool00ggPOomoo`03Ool00`0O0n1@WP08Ool00e2NOomoo`0DOol00`?POomoo`0OOol00ggPOomo
o`1@Ool001Eoo`03001oogoo03=oo`030n1oogoo02Yoo`04O01oogooD9h8Ool00ggPOomoo`03Ool0
0`?PD9h07`07Ool00e2NOomoo`0DOol00`?POomoo`0POol00ggPOomoo`1?Ool001Eoo`03001oogoo
03Aoo`030n1oogoo02Yoo`04O01oogooD9h7Ool00ggPOomoo`03Ool00`0O0n1@WP08Ool00e2NOomo
o`0DOol00`?POomoo`0POol00ggPOomoo`1>Ool001Eoo`03001oogoo03Eoo`83h2]oo`04O01oogoo
D9h7Ool00ggPOomoo`03Ool00`0O0n007`08Ool00e2NOomoo`0DOol00`?POomoo`0POol00ggPOomo
o`1=Ool001Eoo`03001oogoo03Moo`030n1oogoo02Uoo`03O01ooe2N00Qoo`03ON1oogoo009oo`03
01l3h52N00Qoo`03D9ioogoo01Aoo`030n1oogoo025oo`03ON1oogoo04aoo`005Goo00<007ooOol0
>7oo00<3h7ooOol0:Goo00=l07ooD9h027oo00=mh7ooOol00Woo00<07`?P01l027oo00=@WWooOol0
57oo00<3h7ooOol08Goo00=mh7ooOol0Bgoo000EOol00`00Oomoo`0iOol00`?POomoo`0YOol2O000
0e2NOomoo`06Ool01ggPOomoogoo01l3h52N00Qoo`03D9ioogoo01Eoo`030n1oogoo025oo`03ON1o
ogoo04Yoo`005Goo0P00>goo0P?P:goo00=l07ooOol01goo00Mmh7ooOomoo`0O0n007`08Ool00e2N
Oomoo`0EOol00`?POomoo`0QOol00ggPOomoo`19Ool001Eoo`03001oogoo03aoo`030n1oogoo02Uo
o`03O01oogoo00Moo`03ON1oogoo00807`030n1oogoo00Ioo`03D9ioogoo01Eoo`030n1oogoo029o
o`03ON1oogoo04Qoo`005Goo00<007ooOol0?Goo00<3h7ooOol0:Goo00=l07ooOol01Woo00Mmh7oo
Oomoo`0O0n007`08Ool00e2NOomoo`0EOol00`?POomoo`0ROol00ggPOomoo`17Ool001Eoo`03001o
ogoo03ioo`030n1oogoo02Qoo`03D9il07oo00Moo`03ON1oogoo00807`030n1oogoo00Ioo`03D9io
ogoo01Ioo`030n1oogoo029oo`9mh4Moo`005Goo00<007ooOol0?goo00<3h7ooOol0:7oo00=@WW`0
Ool01goo00Imh7ooOol07`?PD9h7Ool00e2NOomoo`0FOol00`?POomoo`0TOol00ggPOomoo`14Ool0
01Eoo`03001oogoo041oo`030n1oogoo02Qoo`03D9il07oo00Ioo`03ON1oogoo00807`030n1oogoo
00Ioo`03D9ioogoo01Ioo`030n1oogoo02Aoo`03ON1oogoo04=oo`005Goo00<007ooOol0@Goo00<3
h7ooOol09goo00=@WWooO0001goo00=mh7ooOol00P0O00<3h7ooOol01Goo00=@WWooOol05goo00<3
h7ooOol097oo00=mh7ooOol0@Woo000EOol00`00Oomoo`12Ool00`?POomoo`0WOol00e2NOoml0007
Ool01GgPOol07`0O0n0027oo00=@WWooOol05Woo00<3h7ooOol09Goo00=mh7ooOol0@Goo000EOol2
0014Ool00`?POomoo`0VOol0152NOomoog`01Woo00=mh7oo01l00P0O00<3h7ooOol01Goo00=@WWoo
Ool05goo00<3h7ooOol09Goo00=mh7ooOol0@7oo000EOol00`00Oomoo`14Ool00`?POomoo`0VOol0
152NOomoog`01Woo00Emh7oo01l07`?P00Qoo`03D9ioogoo01Moo`030n1oogoo02Eoo`03ON1oogoo
03moo`005Goo00<007ooOol0AGoo00<3h7ooOol09Woo00A@WWooOoml00Ioo`05ON007`0O01l3h007
Ool00e2NOomoo`0HOol00`?POomoo`0UOol00ggPOomoo`0nOol001Eoo`03001oogoo04Ioo`030n1o
ogoo02Eoo`05D9ioogooOoml0005Ool01WgPOol07`0OD9h3h0Moo`03D9ioogoo01Moo`030n1oogoo
02Ioo`03ON1oogoo03eoo`005Goo00<007ooOol0Agoo00<3h7ooOol09Goo00A@WWooOoml00Ioo`05
ON007`0O01l3h007Ool00e2NOomoo`0HOol00`?POomoo`0VOol00ggPOomoo`0lOol001Eoo`03001o
ogoo04Qoo`030n1oogoo02Eoo`04D9ioogooO006Ool01GgP01l07e2N0n001goo00=@WWooOol067oo
00<3h7ooOol09Woo00=mh7ooOol0>goo0002Ool20004Ool20004Ool30004Ool00`00Oomoo`19Ool0
0`?POomoo`0TOol01E2NOomoogooO0001Goo00Emh00O01l07`?P00Moo`03D9ioogoo01Qoo`030n1o
ogoo02Moo`03ON1oogoo03Yoo`0000Eoo`00Oomoo`0000=oo`8000Eoo`03001oogoo00=oo`03001o
ogoo04Yoo`030n1oogoo02Aoo`05D9ioogooOoml0005Ool01GgP01l07e2N0n001goo00=@WWooOol0
67oo00<3h7ooOol09goo0WgP>Woo00001Goo001oogoo000027oo100017oo0`00Bgoo00<3h7ooOol0
97oo00E@WWooOomoog`000Eoo`04ON007`0O0n07Ool00e2NOomoo`0IOol00`?POomoo`0XOol00ggP
Oomoo`0gOol00005Ool007ooOol00008Ool00`00Ool00005Ool00`00Oomoo`1;Ool00`?POomoo`0T
Ool00e2NOomoo`02Ool00g`0Oomoo`02Ool01GgP01l07e2N0n001goo00=@WWooOol067oo00<3h7oo
Ool0:Goo00=mh7ooOol0=Woo00001Goo001oogoo000027oo00<007oo00001Goo00<007ooOol0C7oo
00<3h7ooOol097oo00=@WWooOol00Woo00=l07ooOol00Woo00Emh00O01m@WP?P00Ioo`03D9ioogoo
01Uoo`030n1oogoo02Uoo`03ON1oogoo03Eoo`000Woo0P002Woo0P001Goo00<007ooOol0CGoo00<3
h7ooOol08goo00=@WWooOol00goo00=l07ooOol00Woo00Amh00OD9h3h0Ioo`03D9ioogoo01Yoo`03
0n1oogoo02Uoo`03ON1oogoo03Aoo`005Goo00<007ooOol0CWoo00<3h7ooOol08goo00=@WWooOol0
0goo00Ul07ooOomooggP01m@WWoo0n001Woo00=@WWooOol06Goo00<3h7ooOol0:Woo0WgP=7oo000E
Ool00`00Oomoo`1?Ool00`?POomoo`0ROol00e2NOomoo`04Ool027`0OomoogooON007e2N0n06Ool0
0e2NOomoo`0JOol00`?POomoo`0[Ool00ggPOomoo`0aOol001Eoo`03001oogoo04moo`030n1oogoo
029oo`03D9ioogoo00Eoo`08O01oogoo01mmh52NOol3h0Ioo`03D9ioogoo01Yoo`030n1oogoo02]o
o`03ON1oogoo031oo`005Goo00<007ooOol0D7oo00<3h7ooOol08Woo00=@WWooOol01Goo00Ml07oo
01l07ggPD9h3h006Ool00e2NOomoo`0JOol00`?POomoo`0/Ool00ggPOomoo`0_Ool001Eoo`80059o
o`030n1oogoo025oo`03D9ioogoo00Ioo`07O01oo`0OON1@WWoo0n001Woo00=@WWooOol06Woo00<3
h7ooOol0;7oo00=mh7ooOol0;Woo000EOol00`00Oomoo`1BOol00`?POomoo`0QOol00e2NOomoo`05
Ool027`0Ool07`0OON1@WWoo0n05Ool00e2NOomoo`0KOol00`?POomoo`0/Ool00ggPOomoo`0]Ool0
01Eoo`03001oogoo05=oo`030n1oogoo021oo`03D9ioogoo00Ioo`07O01oo`0O01mmh7oo0n001Woo
00=@WWooOol06Woo00<3h7ooOol0;Goo0WgP;Goo000EOol00`00Oomoo`1DOol00`?POomoo`0POol0
0e2NOomoo`06Ool01g`001l07ggPD9ioo`?P00Eoo`03D9ioogoo01]oo`030n1oogoo02ioo`03ON1o
ogoo02Yoo`005Goo00<007ooOol0E7oo00<3h7ooOol087oo00=@WWooOol01goo00Il000O01mmh7oo
0n06Ool00e2NOomoo`0KOol00`?POomoo`0^Ool2ON0ZOol001Eoo`03001oogoo05Eoo`030n1oogoo
021oo`03D9ioogoo00Moo`06O0007`0OON1oo`?P1Goo00=@WWooOol077oo00<3h7ooOol0;goo0WgP
:7oo000EOol00`00Oomoo`1FOol00`?POomoo`0OOol00e2NOomoo`07Ool01P0OO0007e2NON03h0Io
o`03D9ioogoo01]oo`030n1oogoo035oo`03ON1oogoo02Eoo`005Goo00<007ooOol02Woo17gPBGoo
00<3h7ooOol07Woo00=@WWooOol027oo00H07g`0D9imh7oo0n05Ool00e2NOomoo`0LOol00`?POomo
o`0aOol2ON0UOol001Eoo`8000moo`Mmh4=oo`030n1oogoo01ioo`03D9ioogoo00Moo`807`04O01@
WWgP0n06Ool00e2NOomoo`0LOol00`?POomoo`0bOol2ON0SOol001Eoo`03001oogoo01Eoo`Amh3mo
o`030n1oogoo01ioo`03D9ioogoo00Qoo`807`04O01ooggP0n05Ool00e2NOomoo`0LOol00`?POomo
o`0dOol00ggPOomoo`0POol001Eoo`03001oogoo01Uoo`=mh3eoo`030n1oogoo01ioo`03D9ioogoo
00Moo`<07`04O01mh7oo0n05Ool00e2NOomoo`0LOol00`?POomoo`0dOol2ON0POol001Eoo`03001o
ogoo01aoo`=mh3]oo`030n1oogoo01eoo`03D9ioogoo00Qoo`807`04D9il07gP0n05Ool00e2NOomo
o`0MOol00`?POomoo`0eOol2ON0NOol001Eoo`03001oogoo01moo`9mh3Yoo`030n1oogoo01eoo`03
D9ioogoo00Moo`<07`04D9il07gP0n05Ool00e2NOomoo`0LOol00`?POomoo`0gOol2ON0LOol001Eo
o`03001oogoo025oo`=mh3Moo`030n1oogoo01eoo`03D9ioogoo00Moo`<07`04D9ioog`0ON05Ool0
0e2NOomoo`0MOol00`?POomoo`0hOol3ON0IOol001Eoo`03001oogoo02Aoo`9mh3Ioo`030n1oogoo
01eoo`03D9ioogoo00Moo`<07`04D9ioog`00n05Ool00e2NOomoo`0MOol00`?POomoo`0jOol2ON0G
Ool001Eoo`03001oogoo02Ioo`03ON1oogoo03Aoo`030n1oogoo01aoo`03D9ioogoo00Moo`<07`04
D9ioogooO005Ool00e2NOomoo`0MOol00`?POomoo`0lOol2ON0EOol001Eoo`8002Qoo`9mh3Aoo`03
0n1oogoo01aoo`03D9ioogoo00Qoo`807`05D9ioogooOoml0004Ool00e2NOomoo`0NOol00`?POomo
o`0mOol3ON0BOol001Eoo`03001oogoo02Uoo`9mh3=oo`030n1oogoo01aoo`03D9ioogoo00Moo`<0
7`05D9ioogooOoml0004Ool00e2NOomoo`0NOol00`?POomoo`0oOol5ON0=Ool001Eoo`03001oogoo
02]oo`03ON1oogoo035oo`030n1oogoo01]oo`03D9ioogoo00Moo`0401moo`0OD9h3Ool00ggPO01o
o`02Ool00e2NOomoo`0OOol00`?POomoo`13Ool4ON09Ool001Eoo`03001oogoo02aoo`9mh39oo`03
0n1oogoo01]oo`03D9ioogoo00Moo`<07`06D9ioogooOommh7`00goo00=@WWooOol07Woo00<3h7oo
Ool0Agoo0WgP1goo000EOol00`00Oomoo`0^Ool2ON0`Ool00`?POomoo`0KOol00e2NOomoo`07Ool3
01l01e2NOomoogoo0n1mh7`0009oo`03D9ioogoo01moo`030n1oogoo04moo`005Goo00<007ooOol0
<7oo00=mh7ooOol0;Woo00<3h7ooOol06goo00=@WWooOol01goo0`0O00M@WWooOomooggPOoml0002
Ool00e2NOomoo`0OOol00`?POomoo`1>Ool0009oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo035o
o`9mh2moo`030n1oogoo01Yoo`03D9ioogoo00Moo`<07`03D9ioogoo009oo`05ON1oog`0Oom@WP0R
Ool00`?POomoo`1=Ool00005Ool007ooOol00003Ool20003Ool01000Oomoo`0017oo00<007ooOol0
<goo00=mh7ooOol0;7oo00<3h7ooOol06goo00=@WWooOol01goo0`0O00Y@WWooOomoo`?PON1oog`0
Oom@WR9oo`030n1oogoo04aoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool3000dOol2ON0]
Ool00`?POomoo`0JOol00e2NOomoo`07Ool301l00e2NOomoo`02Ool01@?PON1oog`0D9h08Woo00<3
h7ooOol0C7oo00001Goo001oogoo000027oo0`001Goo00<007ooOol0=Woo00=mh7ooOol0:goo00<3
h7ooOol06Woo00=@WWooOol01Woo00D07goo01l07e2N00=oo`060n1mh7ooOoml052N8Woo00<3h7oo
Ool0Bgoo00001Goo001oogoo000027oo00<007ooOol01Goo00<007ooOol0=goo0WgP;7oo00<3h7oo
Ool06Goo00=@WWooOol01goo0`0O00=@WWooOol00Woo00D3h7gPOomoog`002=oo`030n1oogoo04Yo
o`000Woo0P002Woo0`0017oo00<007ooOol0>Goo00=mh7ooOol0:Goo00<3h7ooOol06Goo00=@WWoo
Ool01goo00D07goo01l07e2N00Aoo`050n1mh7ooOoml000SOol00`?POomoo`19Ool001Eoo`03001o
ogoo03Yoo`03ON1oogoo02Uoo`030n1oogoo01Uoo`03D9ioogoo00Moo`<07`03D9ioogoo009oo`06
0n1mh7ooOom@WW`08Woo00<3h7ooOol0BGoo000EOol00`00Oomoo`0kOol2ON0ZOol00`?POomoo`0H
Ool00e2NOomoo`07Ool01@0OOol07`0OD9h017oo00H3h7gPOomooe2NO00ROol00`?POomoo`18Ool0
01Eoo`03001oogoo03eoo`03ON1oogoo02Moo`030n1oogoo01Uoo`03D9ioogoo00Moo`<07`03D9io
ogoo009oo`030n1ooggP009oo`03D9il07oo025oo`030n1oogoo04Moo`005Goo00<007ooOol0?Woo
0WgP:7oo00<3h7ooOol067oo00=@WWooOol01goo00D07goo01l07e2N00Aoo`070n1ooggPOom@WWoo
O0008Woo00<3h7ooOol0AWoo000EOol20011Ool00ggPOomoo`0VOol00`?POomoo`0HOol00e2NOomo
o`07Ool301l00gooD9ioo`03Ool01`?PON1oogooD9ioog`0029oo`030n1oogoo04Eoo`005Goo00<0
07ooOol0@Goo00=mh7ooOol09Goo00<3h7ooOol067oo00=@WWooOol027oo0`0O00=@WWooOol00Woo
00<3h7ooON000Woo00=@WWooO0008Woo00<3h7ooOol0A7oo000EOol00`00Oomoo`12Ool00ggPOomo
o`0UOol00`?POomoo`0HOol00e2NOomoo`07Ool201l00`0001m@WP04Ool01@?POommh7ooD9h00Woo
00=l07ooOol087oo00<3h7ooOol0@goo000EOol00`00Oomoo`13Ool00ggPOomoo`0UOol00`?POomo
o`0GOol00e2NOomoo`08Ool301l00e2NOomoo`02Ool01P?POomooggPOom@WP9oo`03O01oogoo021o
o`030n1oogoo049oo`005Goo00<007ooOol0A7oo0WgP9Woo00<3h7ooOol05goo00=@WWooOol01goo
00D07goo01l07e2N00Aoo`030n1ooggP009oo`04D9ioogooO00ROol00`?POomoo`11Ool001Eoo`03
001oogoo04Ioo`03ON1oogoo02=oo`030n1oogoo01Moo`03D9ioogoo00Qoo`<07`03D9ioogoo00=o
o`050n1ooggPOom@WP03Ool00g`0Oomoo`0POol00`?POomoo`10Ool001Eoo`03001oogoo04Moo`03
ON1oogoo02=oo`030n1oogoo01Moo`03D9ioogoo00Moo`0501l0000O01m@WP05Ool01@?POommh7oo
D9h00goo00=l07ooOol087oo00<3h7ooOol0?goo000EOol00`00Oomoo`18Ool00ggPOomoo`0SOol0
0`?POomoo`0FOol00e2NOomoo`08Ool301l00e2NOomoo`03Ool01@?POomooggPD9h017oo00=l07oo
Ool087oo00<3h7ooOol0?Woo000EOol2001:Ool00ggPOomoo`0ROol00`?POomoo`0GOol00e2NOomo
o`07Ool01@0O00007`0OD9h01Goo00D3h7ooOommh52N00Aoo`9l025oo`030n1oogoo03eoo`005Goo
00<007ooOol0BWoo00=mh7ooOol08Woo00<3h7ooOol05Woo00=@WWooOol027oo0`0O00=@WWooOol0
17oo00D3h7ooON1ooe2N00Eoo`03O01oogoo01moo`030n1oogoo03aoo`005Goo00<007ooOol0Bgoo
0WgP8goo00<3h7ooOol05Goo00=@WWooOol027oo00D07`0001l07e2N00Eoo`050n1oogooON1@WP06
Ool00g`0Oomoo`0OOol00`?POomoo`0kOol001Eoo`03001oogoo04eoo`03ON1oogoo021oo`030n1o
ogoo01Ioo`03D9ioogoo00Qoo`<07`03D9ioogoo00Aoo`050n1oogooON1@WP06Ool00g`0Oomoo`0O
Ool00`?POomoo`0jOol001Eoo`03001oogoo04ioo`03ON1oogoo021oo`030n1oogoo01Eoo`03D9io
ogoo00Qoo`0501l0000O01m@WP06Ool01@?POomooggPD9h01Woo00=l07ooOol07goo0P?P>Woo000E
Ool00`00Oomoo`1?Ool00ggPOomoo`0POol00`?POomoo`0EOol00e2NOomoo`08Ool301l00e2NOomo
o`05Ool010?POommh52N1goo00=l07ooOol087oo00<3h7ooOol0=goo000EOol00`00Oomoo`1@Ool0
0ggPOomoo`0OOol00`?POomoo`0EOol00e2NOomoo`09Ool301l00e2NOomoo`04Ool01@?POomooggP
D9h01goo00=l07ooOol087oo0P?P=goo000EOol00`00Oomoo`1AOol2ON0POol00`?POomoo`0EOol0
0e2NOomoo`08Ool301l00gooD9ioo`05Ool01@?POomooggPD9h01goo00=l07ooOol08Goo00<3h7oo
Ool0=7oo000EOol2001DOol00ggPOomoo`0NOol00`?POomoo`0DOol00e2NOomoo`09Ool301l00goo
D9ioo`05Ool01@?POomooggPD9h01goo00=l07ooOol08Goo0P?P=7oo000EOol00`00Oomoo`1DOol0
0ggPOomoo`0NOol00`?POomoo`0DOol00e2NOomoo`08Ool201l017oo01mooe2N1Goo00H3h7ooOomo
oggPD9h7Ool00g`0Oomoo`0ROol00`?POomoo`0aOol001Eoo`03001oogoo05Eoo`03ON1oogoo01eo
o`030n1oogoo01Eoo`03D9ioogoo00Qoo`807`03Ool07e2N00Ioo`060n1oogooOommh52N1goo00=l
07ooOol08Woo00<3h7ooOol0<7oo000EOol00`00Oomoo`1FOol00ggPOomoo`0MOol00`?POomoo`0E
Ool00e2NOomoo`07Ool01P0O00007goo01m@WPIoo`060n1oogooOommh52N1goo00=l07ooOol08Woo
0P?P<7oo000EOol00`00Oomoo`1GOol00ggPOomoo`0MOol00`?POomoo`0DOol00e2NOomoo`08Ool0
1P0O00007`0OOom@WPIoo`060n1oogooOommh52N1goo0W`097oo00<3h7ooOol0;Goo000EOol00`00
Oomoo`1HOol2ON0NOol00`?POomoo`0DOol00e2NOomoo`08Ool01P0O00007`0OOom@WPIoo`060n1o
ogooOommh52N27oo00=l07ooOol08Woo0P?P;Goo0002Ool20004Ool20004Ool20005Ool00`00Oomo
o`1JOol00ggPOomoo`0KOol00`?POomoo`0EOol00e2NOomoo`08Ool01P0O00007`0OOom@WPIoo`06
0n1oogooOommh52N27oo0W`097oo0P?P:goo00001Goo001oogoo00000goo0P000goo00@007ooOol0
00Aoo`03001oogoo05]oo`03ON1oogoo01]oo`030n1oogoo01Aoo`03D9ioogoo00Uoo`0601l0000O
01mooe2N1Woo00H3h7ooOomooggPD9h9Ool00g`0Oomoo`0SOol20n0YOol00005Ool007ooOol00008
Ool01000Oomoo`0017oo0`00G7oo00=mh7ooOol06goo00<3h7ooOol057oo00=@WWooOol02Goo00D0
7goo01l07e2N00Moo`060n1oogooOommh52N2Goo0W`09Goo0P?P9goo00001Goo001oogoo00002Goo
0P001Goo00<007ooOol0GGoo00=mh7ooOol06goo00<3h7ooOol057oo00=@WWooOol02Goo0P0O00=o
o`0OD9h01goo00H3h7ooOomooggPD9h:Ool00g`0Oomoo`0TOol00`?POomoo`0TOol00005Ool007oo
Ool00008Ool01000Oomoo`0017oo00<007ooOol0GWoo0WgP6goo00<3h7ooOol05Goo00=@WWooOol0
2Goo0`0O00=ooe2NOol01Woo00H3h7ooOomooggPD9h:Ool00g`0Oomoo`0TOol20n0TOol0009oo`80
00Yoo`8000Eoo`03001oogoo061oo`03ON1oogoo01Uoo`030n1oogoo01Aoo`03D9ioogoo00Uoo`06
00007`0O01mooe2N1goo00H3h7ooOomooggPD9h:Ool2O00VOol20n0ROol001Eoo`03001oogoo065o
o`03ON1oogoo01Uoo`030n1oogoo01Aoo`03D9ioogoo00Uoo`0500007`0O01moo`02D9h6Ool01@?P
OomoogooON000U2N2Woo00=l07ooOol09Goo0`?P7goo000EOol00`00Oomoo`1ROol00ggPOomoo`0I
Ool20n0EOol00e2NOomoo`09Ool0100001l07`0O0Woo00=@WWooOol017oo00@3h7ooOomoo`9mh003
D9ioogoo00Qoo`9l02Qoo`<3h1aoo`005Goo00<007ooOol0Hgoo00=mh7ooOol06Woo00<3h7ooOol0
4Woo00=@WWooOol02Woo00<0000O01l00P0O00=ooe2NOol01Goo00<3h7ooOol00Woo00=mh52ND9h0
2Woo00=l07ooOol0:7oo0`?P6Goo000EOol00`00Oomoo`1TOol00ggPOomoo`0JOol00`?POomoo`0B
Ool00e2NOomoo`09Ool2000401l00gooD9i@WP05Ool00`?POomoo`02Ool00ggPOom@WP0:Ool2O00[
Ool30n0FOol001Eoo`8006Ioo`9mh1]oo`030n1oogoo019oo`03D9ioogoo00Uoo`8000D07`03Oom@
WWoo00Aoo`030n1oogoo009oo`9mh09@WPYoo`9l02aoo`D3h15oo`005Goo00<007ooOol0Igoo00=m
h7ooOol06Goo00<3h7ooOol04Woo0U2N2Woo0`00100O00=ooe2NOol017oo0P?P17oo00=mh7ooD9h0
2goo00=l07ooOol0;Woo1`?P2Woo000EOol00`00Oomoo`1XOol2ON0JOol00`?POomoo`0COol00e2N
Oomoo`08Ool3000501l00e2NOomoo`04Ool00`?POomoo`02Ool00ggPOom@WP0;Ool2O00eOol30n07
Ool001Eoo`03001oogoo06Yoo`9mh1Uoo`030n1oogoo01=oo`03D9ioogoo00]oo`0300007`000080
7`9@WP03001oogoo009oo`83h0=oo`04ON1ooe2ND9h;Ool2O00mOol001Eoo`03001oogoo06aoo`03
ON1oogoo01Moo`030n1oogoo01=oo`9@WPeoo`@07`03Oom@WP00008000=oo`040n1oogooOol2ON00
0gooD9ioo`0;Ool00g`0Oomoo`0jOol001Eoo`03001oogoo06eoo`9mh1Qoo`030n1oogoo01Aoo`03
D9ioogoo00aoo`0501moo`0O01m@WP02Ool01000Oomoogoo0P?P0goo00Amh7ooD9i@WP]oo`9l03Yo
o`005Goo00<007ooOol0Kgoo0WgP5goo00<3h7ooOol057oo00=@WWooOol037oo00@07gooOol07`9@
WP03Ool0000000=oo`050n1oogooOommh002Ool3D9h:Ool2O00hOol001Eoo`03001oogoo00Yoo`Ql
05moo`03ON1oogoo01Eoo`030n1oogoo01Aoo`03D9ioogoo00aoo`807`03Ool07`0O009@WP03Ool0
07oo009oo`040n1oogooOol2ON03Ool3D9h9Ool2O00fOol001Eoo`8001=oo`el05=oo`9mh1Ioo`03
0n1oogoo01Aoo`9@WPioo`0301moogoo00807`9@WP80009oo`83h0=oo`9mh0Aoo`9@WPUoo`=l03=o
o`005Goo00<007ooOol07goo2G`0C7oo0WgP5Goo0P?P5Woo00=@WWooOol037oo0`0O0Woo00@07e2N
D9i@WP=oo`030n1oogoo009oo`9mh0Aoo`=@WPUoo`9l035oo`005Goo00<007ooOol0:7oo1g`0Agoo
0WgP5Goo00<3h7ooOol057oo00=@WWooOol03Woo0`0O0Woo00<07e2ND9h00Woo0P?P17oo0WgP1Goo
0e2N27oo0W`0;goo000EOol00`00Oomoo`0_Ool5O014Ool2ON0DOol20n0EOol2D9hAOol301l017oo
01m@WU2N0Woo0`?P0goo00=mh7ooOol01Goo0e2N1goo0g`0;7oo000EOol00`00Oomoo`0dOol5O011
Ool2ON0DOol20n0EOol3D9hAOol301l01000D9i@WU2N0Woo0`?P00=ooggPON0027oo0e2N1goo0g`0
:Goo000EOol00`00Oomoo`0iOol4O00oOol2ON0DOol00`?POomoo`0EOol3D9hAOol401l5D9h20n00
0`00ON1mh0030006Ool3D9h7Ool3O00VOol001Eoo`03001oogoo03eoo`El03aoo`=mh19oo`83h1Qo
o`9@WQ=oo`D07`9@WP<3h0=mh0D000Aoo`E@WPEoo`=l02=oo`005Goo00<007ooOol0@Woo1g`0>7oo
0ggP4Goo0P?P67oo0e2N5Goo100O00A@WP?P0n03h0=mh0H000Eoo`M@WP03Ooml07`000=l01ioo`00
5Goo0P00BWoo1G`0=Woo0ggP47oo00<3h7ooOol067oo152N5Goo100O0`?P0ggP0U2N1@0027oo1U2N
1g`05goo000EOol00`00Oomoo`1>Ool5O00dOol3ON0>Ool30n0KOol7D9hCOol401l010?PON1mh7gP
2E2N3Goo0e2N1W`0152N3Goo000EOol00`00Oomoo`1COol4O00cOol4ON0=Ool30n0OOol6D9hDOol0
0`0OON1mh003ON040n0=D9h90007O003D9h7Ool001Eoo`03001oogoo05Moo`Ul02ioo`Emh0]oo`<3
h29oo`M@WQ=oo`Mmh0X3h0e@WP<000=l00Moo`005Goo00<007ooOol0H7oo2G`0:Woo17gP2Woo0`?P
9Woo5e2N0goo1WgP17oo3@?P1U2N1goo000EOol00`00Oomoo`1YOol7O00WOol9ON04Ool90n0dOol9
D9h7ON0:D9h60n07Ool000eoo`<000Eoo`03001oogoo071ooaIl01Yoo`emh0d3h3Mooa1mh0Moo`00
3Woo00<007ooOol017oo00<007ooOol0QWoo6W`03Goo3GgP6P?P=7oo000>Ool00`00Oomoo`04Ool3
002POomQO007Ool000ioo`03001oogoo00Aoo`03001oogoo0?moo`Uoo`003Woo00<007ooOol017oo
00<007ooOol0ogoo2Goo000=Ool20006Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.66206, -0.0774655, 
  0.0772513, 0.00624848}}]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Compiled \[Rule] True\), \(uses\ compiled\ code\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
Iterating for 20 demes and 3 loci over 100 generations is a factor \
of 25 faster using compiled code\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      StoreExact[\[Psi], hetWfull[0.01, 4], 0.5, {100, 10}, {20, 3}, 
        SymmetricModel \[Rule] False, Compiled \[Rule] True, 
        SortByClass \[Rule] True]; 
      MeanP[\[Psi][100], SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]]\)], "Input",
  CellLabel->"In[218]:="],

Cell[BoxData[
    \({2.`\ 
        Second, {{0.0241625250503635324`, 0.0241625250503635147`, 
          0.0241625250503635324`}, {0.0264124756543803407`, 
          0.0264124756543803318`, 0.0264124756543803407`}, {
          0.0311919671233789941`, 0.0311919671233789941`, 
          0.0311919671233789985`}, {0.0391566398813586591`, 
          0.0391566398813586769`, 0.0391566398813586715`}, {
          0.0515832037889317795`, 0.0515832037889317973`, 
          0.0515832037889317973`}, {0.0709188901454400699`, 
          0.0709188901454401232`, 0.0709188901454401499`}, {
          0.102063324836932212`, 0.1020633248369323`, 
          0.102063324836932323`}, {0.155340709587827952`, 
          0.155340709587828058`, 0.155340709587828111`}, {
          0.250442506076047521`, 0.250442506076047743`, 
          0.250442506076047788`}, {0.405613119229952268`, 
          0.405613119229952445`, 0.405613119229952623`}, {
          0.594386880770047643`, 0.594386880770047909`, 
          0.594386880770047909`}, {0.749557493923952211`, 
          0.749557493923952211`, 0.749557493923952478`}, {
          0.84465929041217187`, 0.844659290412172047`, 
          0.844659290412172047`}, {0.897936675163067832`, 
          0.897936675163067832`, 0.897936675163067832`}, {
          0.929081109854559805`, 0.929081109854559983`, 
          0.929081109854559983`}, {0.948416796211068202`, 
          0.948416796211068202`, 0.948416796211068202`}, {
          0.960843360118641243`, 0.960843360118641243`, 
          0.960843360118641243`}, {0.968808032876621005`, 
          0.968808032876621005`, 0.968808032876621005`}, {
          0.973587524345619748`, 0.973587524345619748`, 
          0.973587524345619748`}, {0.975837474949636529`, 
          0.975837474949636529`, 0.975837474949636529`}}}\)], "Output",
  CellLabel->"Out[218]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      StoreExact[\[Psi], hetWfull[0.01, 4], 0.5, {100, 10}, {20, 3}, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True]; 
      MeanP[\[Psi][100], SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]]\)], "Input",
  CellLabel->"In[219]:="],

Cell[BoxData[
    \({46.350000000000362`\ 
        Second, {{0.0241625250503635502`, 0.0241625250503635191`, 
          0.0241625250503635147`}, {0.0264124756543803629`, 
          0.0264124756543803407`, 0.0264124756543803318`}, {
          0.0311919671233790163`, 0.0311919671233789941`, 
          0.0311919671233789985`}, {0.0391566398813586893`, 
          0.0391566398813586502`, 0.0391566398813586715`}, {
          0.0515832037889318062`, 0.0515832037889317795`, 
          0.0515832037889317884`}, {0.0709188901454401232`, 
          0.0709188901454401054`, 0.0709188901454401143`}, {
          0.1020633248369323`, 0.102063324836932234`, 
          0.102063324836932278`}, {0.155340709587827952`, 
          0.155340709587827863`, 0.155340709587827952`}, {
          0.250442506076047832`, 0.250442506076047743`, 
          0.250442506076047788`}, {0.405613119229952356`, 
          0.405613119229952268`, 0.405613119229952356`}, {
          0.594386880770047643`, 0.594386880770047554`, 
          0.594386880770047643`}, {0.7495574939239523`, 
          0.749557493923952211`, 0.7495574939239523`}, {0.84465929041217187`, 
          0.84465929041217187`, 0.84465929041217187`}, {
          0.897936675163067654`, 0.897936675163067654`, 
          0.897936675163067654`}, {0.929081109854559805`, 
          0.929081109854559805`, 0.929081109854559805`}, {
          0.948416796211068025`, 0.948416796211068025`, 
          0.948416796211068025`}, {0.960843360118641243`, 
          0.960843360118641243`, 0.960843360118641243`}, {
          0.968808032876621005`, 0.968808032876621005`, 
          0.968808032876621005`}, {0.973587524345619748`, 
          0.973587524345619748`, 0.973587524345619748`}, {
          0.975837474949636352`, 0.975837474949636352`, 
          0.975837474949636352`}}}\)], "Output",
  CellLabel->"Out[219]="]
}, Closed]],

Cell[TextData[{
  "The time taken increases very steeply with the number of loci - roughly, \
as ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(3  n\)\)]],
  "; runs are feasible with up to about 6 loci."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        Print[n]; {n, 
          \(Timing[
              StoreExact[\[Psi], hetWfull[0.01, 4], 0.5, {100, 10}, {20, n}, 
                SymmetricModel \[Rule] False, Compiled \[Rule] True, 
                SortByClass \[Rule] True]; 
              MeanP[\[Psi][100], SymmetricModel \[Rule] False, 
                SortByClass \[Rule] True]; ]\)\[LeftDoubleBracket]1
            \[RightDoubleBracket]}, {n, 1, 6}] // TableForm\)], "Input",
  CellLabel->"In[221]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", \(0.5`\ Second\)},
          {"2", \(0.949999999998908606`\ Second\)},
          {"3", \(2.06666666666751552`\ Second\)},
          {"4", \(8.71666666666715173`\ Second\)},
          {"5", \(130.249999999999999`\ Second\)},
          {"6", \(1118.78333333333279`\ Second\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[222]//TableForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{564, 689},
WindowMargins->{{Automatic, -1}, {Automatic, 3}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 79, 0, 36, "SubsectionIcon"],
Cell[1821, 53, 511, 14, 52, "Text"],
Cell[2335, 69, 315, 6, 61, "Input"],
Cell[2653, 77, 105, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[2783, 84, 224, 5, 42, "Input"],
Cell[3010, 91, 684, 17, 83, "Output"]
}, Open  ]],
Cell[3709, 111, 154, 3, 36, "Text"],
Cell[3866, 116, 217, 4, 46, "Input"],

Cell[CellGroupData[{
Cell[4108, 124, 126, 3, 27, "Input"],
Cell[4237, 129, 431, 13, 83, "Output"]
}, Open  ]],
Cell[4683, 145, 378, 6, 64, "Text"],
Cell[5064, 153, 352, 7, 57, "Input"],
Cell[5419, 162, 305, 7, 57, "Input"],

Cell[CellGroupData[{
Cell[5749, 173, 394, 8, 102, "Input"],
Cell[6146, 183, 30699, 861, 184, 8468, 581, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[36860, 1047, 165, 3, 37, "DefinitionBox"],
Cell[37028, 1052, 125, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[37178, 1059, 325, 7, 57, "Input"],
Cell[37506, 1068, 1838, 32, 110, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[39381, 1105, 293, 6, 53, "Input"],
Cell[39677, 1113, 1848, 32, 110, "Output"]
}, Closed]],
Cell[41540, 1148, 218, 6, 34, "Text"],

Cell[CellGroupData[{
Cell[41783, 1158, 492, 10, 72, "Input"],
Cell[42278, 1170, 529, 14, 99, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

