(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7622,        223]*)
(*NotebookOutlinePosition[      8692,        257]*)
(*  CellTagsIndexPosition[      8648,        253]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Utilities`Cumulants`\>", \
{"\<Statistics`DescriptiveStatistics`\>", \n\t\ \ \ \ \ \
"\<Statistics`Common`DistributionsCommon`\>", \
"\<Statistics`DiscreteDistributions`\>", \
"\<Statistics`ContinuousDistributions`\>", \
"\<Utilities`RandomNumbers`\>"}];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["Public parts", "Subsection"],

Cell[BoxData[
    \(\(Cumulant::usage = 
      "\<Cumulant[m,i] returns an algebraic expression for the i'th cumulant, \
in terms of m[1], m[2], etc. Cumulant[m,{i,j,k}] and \
Cumulant[m,{{i,j},{k,l}}] are also defined. \
Cumulant[distribution,i,Distribution->True] returns an algebraic expression \
for the i'th cumulant of a distribution.\>"; \)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(Moment::usage = 
      "\<Moment[k,i] returns an algebraic expression for the i'th non-central \
moment, in terms of the cumulants, k[1], k[2], etc. Moment[k,{i,j,k}] is also \
defined.  Moment[k,{i,j,k},Centred->True] gives the central moment. \
Moment[distribution,i,Distribution->True] returns an algebraic expression for \
the i'th moment of a distribution.\>"; \)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(GeneralizedTransform::usage = 
      "\<GeneralizedTransform[m,i,g,z0] gives the quantities defined by \
applying the function g[] to the generating function, at z0.  For example, \
cumulants are given by GeneralizedTransform[m,i,Log,1]\>"; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Centred::usage = 
      "\<Centred is an option for Moment[],  Cumulant[] and \
GeneralizedTransform[] that gives central moments/cumulants\>"; \)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(Distribution::usage = 
      "\<Distribution is an option for Moment[] and Cumulant[] which \
specifies that a distribution is given as the first parameter.\>"; \)\)], 
  "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Private parts", "Subsection"],

Cell[BoxData[
    \(\(Begin["\<Utilities`Cumulants`Private`\>"];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["Cumulant", "Subsubsection"],

Cell[BoxData[
    \(\(Options[Cumulant] = {Centred \[Rule] False, 
        Distribution \[Rule] False}; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Cumulant[m_, U_List, opts___] := 
      If[\(Distribution /. {opts}\) /. Options[Cumulant], \n\t\t
        Print["\<ERROR: the option Distribution\[Rule]True is not allowed for \
the cumulant of a set, \>", U], \n\t\t
        GeneralizedTransform[m, U, Log, 1, opts]]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Cumulant[m_, i_Integer, opts___] := 
      Module[{t}, \n\t\t
        If[\(Distribution /. {opts}\) /. Options[Cumulant], \n\t\t\ 
          \(\((\(-I\))\)\^i\) D[Log[CharacteristicFunction[m, t]], {t, i}] /. 
              t -> 0 // Factor, \n\t\t
          GeneralizedTransform[m, i, Log, 1, opts]]]; \)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Moment", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[Moment] = {Centred \[Rule] False, 
        Distribution \[Rule] False}; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Moment[c_, U_List, opts___] := 
      If[\(Distribution /. {opts}\) /. Options[Moment], \n\t\t
        Print["\<ERROR: the option Distribution\[Rule]True is not allowed for \
the moment of a set, \>", U], GeneralizedTransform[c, U, Exp, 0, opts]]; 
    \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Moment[c_, i_Integer, opts___] := 
      Module[{t, j, zb}, \n\t\t
        If[\(Distribution /. {opts}\) /. Options[Moment], \n\t\t
          If[\(Centred /. {opts}\) /. Options[Moment], \n\t\t\t\t\t
            zb = Mean[c]; \n\t\t\t\t\t
            Sum[Binomial[i, j] \(\((\(-I\))\)\^j\) 
                  D[CharacteristicFunction[c, t], {t, j}] 
                  \((\(-zb\))\)\^\(i - j\) /. t -> 0, {j, 0, i}], \n\t\t\t\t
            \(\((\(-I\))\)\^i\) D[CharacteristicFunction[c, t], {t, i}] /. 
              t -> 0], GeneralizedTransform[c, i, Exp, 0, opts]]]; \)\)], 
  "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["GeneralizedTransform", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[GeneralizedTransform] = {Centred -> False}; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GeneralizedTransform[c_, i_Integer, g_, f0_, opts___] := 
      Module[{f, z}, \n\t\t
        \(\(D[g[f], {z, i}, NonConstants -> {f}] /. {
                D[f, z, NonConstants \[Rule] {f}] -> c[1], 
                D[f, {z, j_}, NonConstants \[Rule] {f}] -> c[j]}\) /. 
            f -> f0\) /. 
          If[\(Centred /. {opts}\) /. Options[GeneralizedTransform], {
              c[1] -> 0}, {}]]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(GeneralizedTransform[c_, U_List, g_, f0_, opts___] := 
      Module[{f, z}, \n\t\t
        \(\(\(\(Apply[D, Join[{g[f]}, Map[z, U], {NonConstants -> {f}}]] /. 
                  D[f, y__, NonConstants \[Rule] {f}] -> c[{y}]\) /. 
                f -> f0\) //. {a___, {z[x_], n_Integer}, b___} :> 
                Sort[Join[{a}, Table[x, {n}], {b}]]\) /. z[x_] -> x\) /. 
          If[\(Centred /. {opts}\) /. Options[GeneralizedTransform], {
              c[{_}] -> 0}, {}]]; \)\n\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsection"],

Cell["\<\
End[];
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell["EndPackage[];", "Input",
  InitializationCell->True,
  AspectRatioFixed->False]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{732, 553},
WindowMargins->{{Automatic, 31}, {-7, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 362, 8, 75, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2104, 61, 34, 0, 46, "Subsection"],
Cell[2141, 63, 415, 8, 107, "Input",
  InitializationCell->True],
Cell[2559, 73, 458, 8, 123, "Input",
  InitializationCell->True],
Cell[3020, 83, 306, 5, 75, "Input",
  InitializationCell->True],
Cell[3329, 90, 211, 5, 59, "Input",
  InitializationCell->True],
Cell[3543, 97, 229, 5, 59, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3809, 107, 35, 0, 46, "Subsection"],
Cell[3847, 109, 134, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4006, 116, 33, 0, 42, "Subsubsection"],
Cell[4042, 118, 147, 3, 27, "Input",
  InitializationCell->True],
Cell[4192, 123, 334, 6, 75, "Input",
  InitializationCell->True],
Cell[4529, 131, 368, 7, 85, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[4934, 143, 59, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[4996, 146, 145, 3, 27, "Input",
  InitializationCell->True],
Cell[5144, 151, 318, 6, 59, "Input",
  InitializationCell->True],
Cell[5465, 159, 638, 12, 179, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6140, 176, 73, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[6216, 179, 117, 2, 27, "Input",
  InitializationCell->True],
Cell[6336, 183, 465, 9, 75, "Input",
  InitializationCell->True],
Cell[6804, 194, 547, 9, 123, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7400, 209, 28, 0, 30, "Subsection"],
Cell[7431, 211, 87, 5, 42, "Input",
  InitializationCell->True],
Cell[7521, 218, 85, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

